@media (max-width: 1679px) {
  :root {
    --theme-var-single-product-gallery-shift: 0;
    --theme-var-single-product-gallery-shift-indent: 40px;
  }

  .woocommerce.sidebar_hide .post_item_single.single_product_gallery_style_fullwidth div.images,
  .woocommerce-page.sidebar_hide .post_item_single.single_product_gallery_style_fullwidth div.images {
    -webkit-box-sizing: border-box;
    -ms-box-sizing: border-box;
    box-sizing: border-box;
    width: calc( var(--theme-var-single-product-gallery-width) + var(--theme-var-single-product-gallery-shift) - var(--theme-var-single-product-gallery-shift-indent));
    margin-left: calc( -1 * var(--theme-var-single-product-gallery-shift) + var(--theme-var-single-product-gallery-shift-indent));
  }
}
@media (max-width: 1439px) {
  body.woo_extensions_present.sidebar_hide #content div.product div.summary,
  body.woo_extensions_present.sidebar_hide div.product div.summary {
    padding-left: 40px;
  }

  .single_product_details_position_under_summary .woocommerce-tabs,
  .single_product_details_position_under_summary .woocommerce-stacks,
  .single_product_details_position_under_summary .woocommerce-accordion {
    padding-left: 40px;
  }

  .price + .single_product_custom_text_after_price,
  .price + .single_product_custom_text_after_add_to_cart {
    margin-top: -0.7em;
  }
}
@media (max-width: 1279px) {
  /* WooCommerce */
  .woocommerce.sidebar_hide .post_item_single.single_product_gallery_style_fullwidth div.images, .woocommerce.sidebar_hide.single_product_gallery_thumbs_left .post_item_single.single_product_gallery_style_fullwidth div.images.woocommerce-product-gallery--with-thumbs,
  .woocommerce-page.sidebar_hide .post_item_single.single_product_gallery_style_fullwidth div.images,
  .woocommerce-page.sidebar_hide.single_product_gallery_thumbs_left .post_item_single.single_product_gallery_style_fullwidth div.images.woocommerce-product-gallery--with-thumbs {
    width: var(--theme-var-single-product-gallery-width);
    margin-left: 0;
  }

  body.woo_extensions_present #content div.product div.summary,
  body.woo_extensions_present div.product div.summary,
  body.woo_extensions_present div.product div.images,
  body.woo_extensions_present #content div.product div.images {
    margin-bottom: 40px;
  }
  body.woo_extensions_present div.product .woocommerce-tabs ul.tabs,
  body.woo_extensions_present #content div.product .woocommerce-tabs ul.tabs {
    margin: 0 0 30px;
  }

  .woocommerce .single_product_details_position_default #reviews .rating_details ~ #comments {
    margin-top: 50px;
  }

  .single-product .woocommerce-accordion #reviews {
    padding-bottom: 20px;
  }

  .single_product_custom_text_after_price, .single_product_custom_text_after_add_to_cart {
    margin: -0.3em 0 22px;
  }

  .woocommerce #reviews .rating_details .rating_details_table {
    width: 100%;
  }

  .woocommerce .post_item_single .summary > .woocommerce-breadcrumb {
    margin-bottom: 20px;
  }
}
@media (max-width: 1023px) {
  /* WooCommerce */
  .woocommerce.sidebar_show .pantry_woocommerce_filters_button,
  .woocommerce-page.sidebar_show .pantry_woocommerce_filters_button {
    display: flex;
  }
  .woocommerce.sidebar_show.sidebar_as_filters .sidebar > .sidebar_control,
  .woocommerce-page.sidebar_show.sidebar_as_filters .sidebar > .sidebar_control {
    display: none;
  }

  body.sidebar_as_filters .sidebar > .sidebar_close {
    display: block;
  }
  body.sidebar_as_filters .sidebar ~ .sidebar_overlay {
    display: block;
  }

  body.woo_extensions_present #content div.product div.summary,
  body.woo_extensions_present div.product div.summary,
  body.woo_extensions_present div.product div.images,
  body.woo_extensions_present #content div.product div.images {
    margin-bottom: 40px;
  }
  body.woo_extensions_present.sidebar_hide .post_type_product.single_product_details_position_under_summary div.product div.images {
    margin-bottom: 40px;
  }
  body.woo_extensions_present.sidebar_hide .post_type_product.single_product_details_position_under_gallery div.product div.summary {
    margin-bottom: 40px;
  }
  body.woo_extensions_present.sidebar_hide .single_product_details_position_default .woocommerce-tabs {
    padding-top: 10px;
  }
  body.woo_extensions_present.sidebar_hide .single_product_details_position_default .woocommerce-stacks,
  body.woo_extensions_present.sidebar_hide .single_product_details_position_default .woocommerce-accordion {
    padding-top: 0;
  }

  body.woo_extensions_present .post_item_single div.product #comments h2,
  body.woo_extensions_present .post_item_single #review_form #respond #reply-title,
  body.woo_extensions_present .post_item_single #reviews .rating_details .rating_details_title {
    font-size: 20px;
    margin-bottom: 20px;
  }

  .woocommerce .single_product_details_position_default #reviews .rating_details ~ #comments {
    margin-top: 40px;
  }

  .woocommerce.sidebar_hide .single_product_details_position_under_gallery.single_product_summary_sticky .summary,
  .woocommerce-page.sidebar_hide .single_product_details_position_under_gallery.single_product_summary_sticky .summary {
    position: relative;
    top: 0;
  }

  .single_product_details_position_under_gallery .woocommerce-tabs,
  .single_product_details_position_under_gallery .woocommerce-stacks,
  .single_product_details_position_under_gallery .woocommerce-accordion,
  .single_product_details_position_under_summary .woocommerce-tabs,
  .single_product_details_position_under_summary .woocommerce-stacks,
  .single_product_details_position_under_summary .woocommerce-accordion {
    width: 100%;
    padding-left: 0;
    padding-right: 0;
    float: none;
  }

  body.woo_extensions_present.sidebar_hide #content div.product div.summary,
  body.woo_extensions_present.sidebar_hide div.product div.summary {
    width: 100%;
    padding-left: 0;
    padding-right: 0;
    float: none;
  }
}
@media (max-width: 767px) {
  /* WooCommerce */
  body.woo_extensions_present div.product .woocommerce-tabs ul.tabs,
  body.woo_extensions_present #content div.product .woocommerce-tabs ul.tabs {
    margin: 0 0 18px;
  }

  .woocommerce .single_product_details_position_default #reviews .rating_details {
    width: 100%;
  }

  .woocommerce #reviews .rating_details,
  .woocommerce #reviews #comments,
  .woocommerce #reviews #comments + #review_form_wrapper,
  .woocommerce #reviews #comments + .woocommerce-verification-required {
    width: 100%;
    padding: 0;
  }
  .woocommerce #reviews .rating_details .rating_details_table .rating_details_table_row .rating_details_table_cell_mark {
    -webkit-flex-basis: 23%;
    -ms-flex-basis: 23%;
    flex-basis: 23%;
  }
  .woocommerce #reviews .rating_details .rating_details_table .rating_details_table_row .rating_details_table_cell_bar {
    -webkit-flex-basis: 58%;
    -ms-flex-basis: 58%;
    flex-basis: 58%;
  }
  .woocommerce #reviews .rating_details .rating_details_table .rating_details_table_row .rating_details_table_cell_total {
    -webkit-flex-basis: 19%;
    -ms-flex-basis: 19%;
    flex-basis: 19%;
  }

  .pantry_woocommerce_filters_button {
    margin-right: 24px;
  }

  .single_product_bottom_bar_sticky {
    padding: 0.5em;
    flex-direction: column;
  }
  .single_product_bottom_bar_sticky .single_product_bottom_bar_info {
    margin-top: 8px;
  }
  .single_product_bottom_bar_sticky .single_product_bottom_bar_title .single_product_bottom_bar_product_image {
    width: 3em;
    height: 3em;
  }
  .single_product_bottom_bar_sticky .single_product_bottom_bar_title .single_product_bottom_bar_product_title .product_title {
    font-size: 17px;
    margin: 0 0 0 10px;
  }
  .single_product_bottom_bar_sticky .single_product_bottom_bar_info .single_product_bottom_bar_product_price {
    font-size: 16px;
    margin-right: 10px;
  }
  .single_product_bottom_bar_sticky .single_product_bottom_bar_info .single_product_bottom_bar_product_button .button {
    height: 35px;
    line-height: 35px;
    padding: 0 16px 1px;
  }
  .single_product_bottom_bar_sticky .single_product_bottom_bar_info .single_product_bottom_bar_product_button form .quantity {
    display: none;
  }
  .single_product_bottom_bar_sticky .single_product_bottom_bar_info .single_product_bottom_bar_product_button .tinv-wraper {
    margin-left: 5px;
  }
  .single_product_bottom_bar_sticky .single_product_bottom_bar_info .single_product_bottom_bar_product_button .tinv-wraper > .tinvwl_add_to_wishlist_button {
    width: 35px;
    height: 35px;
    line-height: 36px !important;
  }
  .single_product_bottom_bar_sticky .single_product_bottom_bar_info .single_product_bottom_bar_product_button .tinv-wraper > .tinvwl_add_to_wishlist_button:before {
    font-size: 14px !important;
  }

  .woocommerce .summary .woocommerce_extensions_brand {
    margin: -0.1em 0 1.2em 0;
  }

  .single_product_custom_text_after_price,
  .single_product_custom_text_after_add_to_cart {
    margin: -0.3em 0 20px;
  }
  .price + .single_product_custom_text_after_price, .price +
  .single_product_custom_text_after_add_to_cart {
    margin-top: -0.5em;
  }

  .single-product .woocommerce-accordion #reviews {
    padding-bottom: 10px;
  }

  .woocommerce .post_item_single .summary > .woocommerce-breadcrumb {
    margin-bottom: 12px;
  }

  .woocommerce #reviews .rating_details .rating_details_avg {
    font-size: 2.5em;
  }
}
@media (max-width: 600px) {
  /* WooCommerce */
  .pantry_woocommerce_filters_button_wrap {
    width: 100%;
    margin-top: 6px;
    justify-content: space-between;
  }
}
@media (max-width: 479px) {
  /* WooCommerce */
  .single-product .woocommerce-accordion .woocommerce-accordion-title {
    font-size: 21px;
  }

  .woocommerce .single_product_details_position_default #reviews .rating_details ~ #comments {
    margin-top: 30px;
  }

  .single-product .woocommerce-accordion #reviews {
    padding-bottom: 5px;
  }
}

/*# sourceMappingURL=woocommerce-extensions-responsive.css.map */
