/* WooCommerce styles
----------------------------------------------------------------- */
/* Common styles
----------------------------------------------------------------- */
body.woocommerce {
  --theme-var-sidebar_width_min: 250px;
  --theme-var-sidebar: clamp( var(--theme-var-sidebar_width_min, 150px), calc( var(--theme-var-page) * var(--theme-var-sidebar_prc) * var(--theme-var-sidebar_proportional) + var(--theme-var-sidebar_width) * ( 1 - var(--theme-var-sidebar_proportional) ) ), var(--theme-var-sidebar_width_max, 500px) );
  --theme-var-sidebar_gap: clamp( var(--theme-var-sidebar_gap_width_min, 0px), calc( var(--theme-var-page) * var(--theme-var-sidebar_gap_prc) * var(--theme-var-sidebar_proportional) + var(--theme-var-sidebar_gap_width) * ( 1 - var(--theme-var-sidebar_proportional) ) ), var(--theme-var-sidebar_gap_width_max, 100px) );
  --theme-var-sidebar_and_gap: calc( var(--theme-var-sidebar) + var(--theme-var-sidebar_gap) );
  --theme-var-content: calc( var(--theme-var-page) - var(--theme-var-sidebar) - var(--theme-var-sidebar_gap) );
  --theme-var-content_narrow: calc( var(--theme-var-content) * var(--theme-var-koef_narrow) );
  --theme-var-padding_narrow: calc( var(--theme-var-content) * ( 1 - var(--theme-var-koef_narrow) ) );
}

.woocommerce table th, .woocommerce table td {
  border-width: 0;
}

/* Buttons */
body.woocommerce-page form.lost_reset_password .woocommerce-form-row button.button,
.woocommerce #btn-buy,
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button,
.woocommerce #respond input#submit,
.woocommerce .button, .woocommerce-page .button,
.woocommerce a.button,
.woocommerce button.button,
.woocommerce input.button,
.woocommerce input[type="button"], .woocommerce-page input[type="button"],
.woocommerce input[type="submit"], .woocommerce-page input[type="submit"],
.woocommerce ul.products li.product .button,
.woocommerce div.product form.cart .button,
.woocommerce #review_form #respond p.form-submit input[type="submit"],
.woocommerce-page #review_form #respond p.form-submit input[type="submit"],
.woocommerce table.my_account_orders .order-actions .button,
.woocommerce table.cart td.actions .button,
#add_payment_method .wc-proceed-to-checkout a.checkout-button,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button,
.yith-woocompare-widget a.clear-all {
  -webkit-appearance: none;
  cursor: pointer;
  display: inline-flex;
  align-items: center;
  vertical-align: top;
  font-size: var(--theme-font-button_font-size);
  line-height: var(--theme-font-button_line-height);
  font-weight: var(--theme-font-button_font-weight);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  text-transform: var(--theme-font-button_text-transform);
  letter-spacing: var(--theme-font-button_letter-spacing);
  white-space: nowrap;
  height: auto;
  max-width: 100%;
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
  padding: 20px 44px;
  border-width: 0 !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
body.woocommerce-page form.lost_reset_password .woocommerce-form-row button.button.sc_button_shadow,
.woocommerce #btn-buy.sc_button_shadow,
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button.sc_button_shadow,
.woocommerce #respond input#submit.sc_button_shadow,
.woocommerce .button.sc_button_shadow, .woocommerce-page .button.sc_button_shadow,
.woocommerce a.button.sc_button_shadow,
.woocommerce button.button.sc_button_shadow,
.woocommerce input.button.sc_button_shadow,
.woocommerce input[type="button"].sc_button_shadow, .woocommerce-page input[type="button"].sc_button_shadow,
.woocommerce input[type="submit"].sc_button_shadow, .woocommerce-page input[type="submit"].sc_button_shadow,
.woocommerce ul.products li.product .button.sc_button_shadow,
.woocommerce div.product form.cart .button.sc_button_shadow,
.woocommerce #review_form #respond p.form-submit input[type="submit"].sc_button_shadow,
.woocommerce-page #review_form #respond p.form-submit input[type="submit"].sc_button_shadow,
.woocommerce table.my_account_orders .order-actions .button.sc_button_shadow,
.woocommerce table.cart td.actions .button.sc_button_shadow,
#add_payment_method .wc-proceed-to-checkout a.checkout-button.sc_button_shadow,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button.sc_button_shadow,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button.sc_button_shadow,
.yith-woocompare-widget a.clear-all.sc_button_shadow {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_link_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_link_02);
  box-shadow: 0 7px 25px var(--theme-color-text_link_02);
}
body.woocommerce-page form.lost_reset_password .woocommerce-form-row button.button.sc_button_shadow.color_style_dark,
.woocommerce #btn-buy.sc_button_shadow.color_style_dark,
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button.sc_button_shadow.color_style_dark,
.woocommerce #respond input#submit.sc_button_shadow.color_style_dark,
.woocommerce .button.sc_button_shadow.color_style_dark, .woocommerce-page .button.sc_button_shadow.color_style_dark,
.woocommerce a.button.sc_button_shadow.color_style_dark,
.woocommerce button.button.sc_button_shadow.color_style_dark,
.woocommerce input.button.sc_button_shadow.color_style_dark,
.woocommerce input[type="button"].sc_button_shadow.color_style_dark, .woocommerce-page input[type="button"].sc_button_shadow.color_style_dark,
.woocommerce input[type="submit"].sc_button_shadow.color_style_dark, .woocommerce-page input[type="submit"].sc_button_shadow.color_style_dark,
.woocommerce ul.products li.product .button.sc_button_shadow.color_style_dark,
.woocommerce div.product form.cart .button.sc_button_shadow.color_style_dark,
.woocommerce #review_form #respond p.form-submit input[type="submit"].sc_button_shadow.color_style_dark,
.woocommerce-page #review_form #respond p.form-submit input[type="submit"].sc_button_shadow.color_style_dark,
.woocommerce table.my_account_orders .order-actions .button.sc_button_shadow.color_style_dark,
.woocommerce table.cart td.actions .button.sc_button_shadow.color_style_dark,
#add_payment_method .wc-proceed-to-checkout a.checkout-button.sc_button_shadow.color_style_dark,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button.sc_button_shadow.color_style_dark,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button.sc_button_shadow.color_style_dark,
.yith-woocompare-widget a.clear-all.sc_button_shadow.color_style_dark {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_dark_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_dark_02);
  box-shadow: 0 7px 25px var(--theme-color-text_dark_02);
}
body.woocommerce-page form.lost_reset_password .woocommerce-form-row button.button.sc_button_shadow.color_style_link2,
.woocommerce #btn-buy.sc_button_shadow.color_style_link2,
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button.sc_button_shadow.color_style_link2,
.woocommerce #respond input#submit.sc_button_shadow.color_style_link2,
.woocommerce .button.sc_button_shadow.color_style_link2, .woocommerce-page .button.sc_button_shadow.color_style_link2,
.woocommerce a.button.sc_button_shadow.color_style_link2,
.woocommerce button.button.sc_button_shadow.color_style_link2,
.woocommerce input.button.sc_button_shadow.color_style_link2,
.woocommerce input[type="button"].sc_button_shadow.color_style_link2, .woocommerce-page input[type="button"].sc_button_shadow.color_style_link2,
.woocommerce input[type="submit"].sc_button_shadow.color_style_link2, .woocommerce-page input[type="submit"].sc_button_shadow.color_style_link2,
.woocommerce ul.products li.product .button.sc_button_shadow.color_style_link2,
.woocommerce div.product form.cart .button.sc_button_shadow.color_style_link2,
.woocommerce #review_form #respond p.form-submit input[type="submit"].sc_button_shadow.color_style_link2,
.woocommerce-page #review_form #respond p.form-submit input[type="submit"].sc_button_shadow.color_style_link2,
.woocommerce table.my_account_orders .order-actions .button.sc_button_shadow.color_style_link2,
.woocommerce table.cart td.actions .button.sc_button_shadow.color_style_link2,
#add_payment_method .wc-proceed-to-checkout a.checkout-button.sc_button_shadow.color_style_link2,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button.sc_button_shadow.color_style_link2,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button.sc_button_shadow.color_style_link2,
.yith-woocompare-widget a.clear-all.sc_button_shadow.color_style_link2 {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_link2_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_link2_02);
  box-shadow: 0 7px 25px var(--theme-color-text_link2_02);
}
body.woocommerce-page form.lost_reset_password .woocommerce-form-row button.button.sc_button_shadow.color_style_link3,
.woocommerce #btn-buy.sc_button_shadow.color_style_link3,
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button.sc_button_shadow.color_style_link3,
.woocommerce #respond input#submit.sc_button_shadow.color_style_link3,
.woocommerce .button.sc_button_shadow.color_style_link3, .woocommerce-page .button.sc_button_shadow.color_style_link3,
.woocommerce a.button.sc_button_shadow.color_style_link3,
.woocommerce button.button.sc_button_shadow.color_style_link3,
.woocommerce input.button.sc_button_shadow.color_style_link3,
.woocommerce input[type="button"].sc_button_shadow.color_style_link3, .woocommerce-page input[type="button"].sc_button_shadow.color_style_link3,
.woocommerce input[type="submit"].sc_button_shadow.color_style_link3, .woocommerce-page input[type="submit"].sc_button_shadow.color_style_link3,
.woocommerce ul.products li.product .button.sc_button_shadow.color_style_link3,
.woocommerce div.product form.cart .button.sc_button_shadow.color_style_link3,
.woocommerce #review_form #respond p.form-submit input[type="submit"].sc_button_shadow.color_style_link3,
.woocommerce-page #review_form #respond p.form-submit input[type="submit"].sc_button_shadow.color_style_link3,
.woocommerce table.my_account_orders .order-actions .button.sc_button_shadow.color_style_link3,
.woocommerce table.cart td.actions .button.sc_button_shadow.color_style_link3,
#add_payment_method .wc-proceed-to-checkout a.checkout-button.sc_button_shadow.color_style_link3,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button.sc_button_shadow.color_style_link3,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button.sc_button_shadow.color_style_link3,
.yith-woocompare-widget a.clear-all.sc_button_shadow.color_style_link3 {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_link3_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_link3_02);
  box-shadow: 0 7px 25px var(--theme-color-text_link3_02);
}

body.woocommerce-page form.lost_reset_password .woocommerce-form-row button.button:hover,
.woocommerce #btn-buy:hover,
.woocommerce #btn-buy:focus,
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button:hover,
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button:focus,
.woocommerce #respond input#submit:hover,
.woocommerce #respond input#submit:focus,
.woocommerce .button:hover, .woocommerce-page .button:hover,
.woocommerce .button:focus, .woocommerce-page .button:focus,
.woocommerce a.button:hover, .woocommerce-page a.button:hover,
.woocommerce a.button:focus, .woocommerce-page a.button:focus,
.woocommerce button.button:hover, .woocommerce-page button.button:hover,
.woocommerce button.button:focus, .woocommerce-page button.button:focus,
.woocommerce input.button:hover, .woocommerce-page input.button:hover,
.woocommerce input.button:focus, .woocommerce-page input.button:focus,
.woocommerce input[type="button"]:hover, .woocommerce-page input[type="button"]:hover,
.woocommerce input[type="button"]:focus, .woocommerce-page input[type="button"]:focus,
.woocommerce input[type="submit"]:hover, .woocommerce-page input[type="submit"]:hover,
.woocommerce input[type="submit"]:focus, .woocommerce-page input[type="submit"]:focus,
.woocommerce ul.products li.product .button:hover,
.woocommerce ul.products li.product .button:focus,
.woocommerce div.product form.cart .button:hover,
.woocommerce div.product form.cart .button:focus,
.woocommerce #review_form #respond p.form-submit input[type="submit"]:hover,
.woocommerce #review_form #respond p.form-submit input[type="submit"]:focus,
.woocommerce-page #review_form #respond p.form-submit input[type="submit"]:hover,
.woocommerce-page #review_form #respond p.form-submit input[type="submit"]:focus,
.woocommerce table.my_account_orders .order-actions .button:hover,
.woocommerce table.my_account_orders .order-actions .button:focus,
.woocommerce table.cart td.actions .button:hover,
.woocommerce table.cart td.actions .button:focus,
#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover,
#add_payment_method .wc-proceed-to-checkout a.checkout-button:focus,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:focus,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:focus,
.yith-woocompare-widget a.clear-all:hover,
.yith-woocompare-widget a.clear-all:focus {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_hover);
  background-color: var(--theme-color-text_hover);
}

/* Disabled state */
.woocommerce #respond input#submit.disabled,
.woocommerce #respond input#submit:disabled,
.woocommerce #respond input#submit[disabled]:disabled,
.woocommerce a.button.disabled,
.woocommerce a.button:disabled,
.woocommerce a.button[disabled]:disabled,
.woocommerce button.button.disabled,
.woocommerce button.button:disabled,
.woocommerce button.button[disabled]:disabled,
.woocommerce input.button.disabled,
.woocommerce input.button:disabled,
.woocommerce input.button[disabled]:disabled {
  -webkit-appearance: none;
  cursor: pointer;
  display: inline-flex;
  align-items: center;
  vertical-align: top;
  font-size: var(--theme-font-button_font-size);
  line-height: var(--theme-font-button_line-height);
  font-weight: var(--theme-font-button_font-weight);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  text-transform: var(--theme-font-button_text-transform);
  letter-spacing: var(--theme-font-button_letter-spacing);
  white-space: nowrap;
  height: auto;
  max-width: 100%;
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
  padding: 20px 44px;
  border-width: 0 !important;
}
.woocommerce #respond input#submit.disabled.sc_button_shadow,
.woocommerce #respond input#submit:disabled.sc_button_shadow,
.woocommerce #respond input#submit[disabled]:disabled.sc_button_shadow,
.woocommerce a.button.disabled.sc_button_shadow,
.woocommerce a.button:disabled.sc_button_shadow,
.woocommerce a.button[disabled]:disabled.sc_button_shadow,
.woocommerce button.button.disabled.sc_button_shadow,
.woocommerce button.button:disabled.sc_button_shadow,
.woocommerce button.button[disabled]:disabled.sc_button_shadow,
.woocommerce input.button.disabled.sc_button_shadow,
.woocommerce input.button:disabled.sc_button_shadow,
.woocommerce input.button[disabled]:disabled.sc_button_shadow {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_link_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_link_02);
  box-shadow: 0 7px 25px var(--theme-color-text_link_02);
}
.woocommerce #respond input#submit.disabled.sc_button_shadow.color_style_dark,
.woocommerce #respond input#submit:disabled.sc_button_shadow.color_style_dark,
.woocommerce #respond input#submit[disabled]:disabled.sc_button_shadow.color_style_dark,
.woocommerce a.button.disabled.sc_button_shadow.color_style_dark,
.woocommerce a.button:disabled.sc_button_shadow.color_style_dark,
.woocommerce a.button[disabled]:disabled.sc_button_shadow.color_style_dark,
.woocommerce button.button.disabled.sc_button_shadow.color_style_dark,
.woocommerce button.button:disabled.sc_button_shadow.color_style_dark,
.woocommerce button.button[disabled]:disabled.sc_button_shadow.color_style_dark,
.woocommerce input.button.disabled.sc_button_shadow.color_style_dark,
.woocommerce input.button:disabled.sc_button_shadow.color_style_dark,
.woocommerce input.button[disabled]:disabled.sc_button_shadow.color_style_dark {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_dark_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_dark_02);
  box-shadow: 0 7px 25px var(--theme-color-text_dark_02);
}
.woocommerce #respond input#submit.disabled.sc_button_shadow.color_style_link2,
.woocommerce #respond input#submit:disabled.sc_button_shadow.color_style_link2,
.woocommerce #respond input#submit[disabled]:disabled.sc_button_shadow.color_style_link2,
.woocommerce a.button.disabled.sc_button_shadow.color_style_link2,
.woocommerce a.button:disabled.sc_button_shadow.color_style_link2,
.woocommerce a.button[disabled]:disabled.sc_button_shadow.color_style_link2,
.woocommerce button.button.disabled.sc_button_shadow.color_style_link2,
.woocommerce button.button:disabled.sc_button_shadow.color_style_link2,
.woocommerce button.button[disabled]:disabled.sc_button_shadow.color_style_link2,
.woocommerce input.button.disabled.sc_button_shadow.color_style_link2,
.woocommerce input.button:disabled.sc_button_shadow.color_style_link2,
.woocommerce input.button[disabled]:disabled.sc_button_shadow.color_style_link2 {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_link2_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_link2_02);
  box-shadow: 0 7px 25px var(--theme-color-text_link2_02);
}
.woocommerce #respond input#submit.disabled.sc_button_shadow.color_style_link3,
.woocommerce #respond input#submit:disabled.sc_button_shadow.color_style_link3,
.woocommerce #respond input#submit[disabled]:disabled.sc_button_shadow.color_style_link3,
.woocommerce a.button.disabled.sc_button_shadow.color_style_link3,
.woocommerce a.button:disabled.sc_button_shadow.color_style_link3,
.woocommerce a.button[disabled]:disabled.sc_button_shadow.color_style_link3,
.woocommerce button.button.disabled.sc_button_shadow.color_style_link3,
.woocommerce button.button:disabled.sc_button_shadow.color_style_link3,
.woocommerce button.button[disabled]:disabled.sc_button_shadow.color_style_link3,
.woocommerce input.button.disabled.sc_button_shadow.color_style_link3,
.woocommerce input.button:disabled.sc_button_shadow.color_style_link3,
.woocommerce input.button[disabled]:disabled.sc_button_shadow.color_style_link3 {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_link3_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_link3_02);
  box-shadow: 0 7px 25px var(--theme-color-text_link3_02);
}

.woocommerce #respond input#submit.disabled,
.woocommerce #respond input#submit:disabled,
.woocommerce #respond input#submit[disabled]:disabled,
.woocommerce a.button.disabled,
.woocommerce a.button:disabled,
.woocommerce a.button[disabled]:disabled,
.woocommerce button.button.disabled,
.woocommerce button.button:disabled,
.woocommerce button.button[disabled]:disabled,
.woocommerce input.button.disabled,
.woocommerce input.button:disabled,
.woocommerce input.button[disabled]:disabled,
.woocommerce #respond input#submit.disabled:hover,
.woocommerce #respond input#submit:disabled:hover,
.woocommerce #respond input#submit[disabled]:disabled:hover,
.woocommerce a.button.disabled:hover,
.woocommerce a.button:disabled:hover,
.woocommerce a.button[disabled]:disabled:hover,
.woocommerce button.button.disabled:hover,
.woocommerce button.button:disabled:hover,
.woocommerce button.button[disabled]:disabled:hover,
.woocommerce input.button.disabled:hover,
.woocommerce input.button:disabled:hover,
.woocommerce input.button[disabled]:disabled:hover {
  color: var(--theme-color-inverse_link) !important;
  border-color: var(--theme-color-inverse_link) !important;
  background-color: var(--theme-color-text_light) !important;
  -webkit-box-shadow: none !important;
  -ms-box-shadow: none !important;
  box-shadow: none !important;
}

/* Alt buttons */
.woocommerce #respond input#submit.alt,
.woocommerce a.button.alt,
.woocommerce button.button.alt,
.woocommerce input.button.alt {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

.woocommerce #respond input#submit.alt:hover,
.woocommerce #respond input#submit.alt:focus,
.woocommerce a.button.alt:hover,
.woocommerce a.button.alt:focus,
.woocommerce button.button.alt:hover,
.woocommerce button.button.alt:focus,
.woocommerce input.button.alt:hover,
.woocommerce input.button.alt:focus {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_hover);
  background-color: var(--theme-color-text_hover);
}

/* Buttons in widgets */
.widget.woocommerce .button,
.widget.WOOCS_CONVERTER .button,
.widget.yith-woocompare-widget a.button,
.widget.yith-woocompare-widget a.clear-all,
.woocommerce .widget_price_filter .price_slider_amount .button {
  font-size: 15px;
  line-height: 18px;
  padding: 15px 35px;
}

.widget.woocommerce .button + .button {
  margin-left: 3px;
}

[class*="scheme_"].sidebar .woocommerce-message .button,
[class*="scheme_"].sidebar .woocommerce-error .button,
[class*="scheme_"].sidebar .woocommerce-info .button,
[class*="scheme_"].sidebar .widget.woocommerce .button,
[class*="scheme_"].sidebar .widget.woocommerce a.button,
[class*="scheme_"].sidebar .widget.woocommerce button.button,
[class*="scheme_"].sidebar .widget.woocommerce input.button,
[class*="scheme_"].sidebar .widget.woocommerce input[type="button"],
[class*="scheme_"].sidebar .widget.woocommerce input[type="submit"],
[class*="scheme_"].sidebar .widget.WOOCS_CONVERTER .button,
[class*="scheme_"].sidebar .widget.yith-woocompare-widget a.button,
[class*="scheme_"].sidebar .widget_product_search .search_button {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-alter_link);
  background-color: var(--theme-color-alter_link);
}

[class*="scheme_"].sidebar .woocommerce-message .button:hover,
[class*="scheme_"].sidebar .woocommerce-message .button:focus,
[class*="scheme_"].sidebar .woocommerce-error .button:hover,
[class*="scheme_"].sidebar .woocommerce-error .button:focus,
[class*="scheme_"].sidebar .woocommerce-info .button:hover,
[class*="scheme_"].sidebar .woocommerce-info .button:focus,
[class*="scheme_"].sidebar .widget.woocommerce .button:hover,
[class*="scheme_"].sidebar .widget.woocommerce .button:focus,
[class*="scheme_"].sidebar .widget.woocommerce a.button:hover,
[class*="scheme_"].sidebar .widget.woocommerce a.button:focus,
[class*="scheme_"].sidebar .widget.woocommerce button.button:hover,
[class*="scheme_"].sidebar .widget.woocommerce button.button:focus,
[class*="scheme_"].sidebar .widget.woocommerce input.button:hover,
[class*="scheme_"].sidebar .widget.woocommerce input.button:focus,
[class*="scheme_"].sidebar .widget.woocommerce input[type="button"]:hover,
[class*="scheme_"].sidebar .widget.woocommerce input[type="button"]:focus,
[class*="scheme_"].sidebar .widget.woocommerce input[type="submit"]:hover,
[class*="scheme_"].sidebar .widget.woocommerce input[type="submit"]:focus,
[class*="scheme_"].sidebar .widget.WOOCS_CONVERTER .button:hover,
[class*="scheme_"].sidebar .widget.WOOCS_CONVERTER .button:focus,
[class*="scheme_"].sidebar .widget.yith-woocompare-widget a.button:hover,
[class*="scheme_"].sidebar .widget.yith-woocompare-widget a.button:focus,
[class*="scheme_"].sidebar .widget_product_search .search_button:hover,
[class*="scheme_"].sidebar .widget_product_search .search_button:focus {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-alter_hover);
  background-color: var(--theme-color-alter_hover);
}

.single-product div.product .woocommerce-tabs .wc-tabs li a,
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container-single .chosen-single {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.woocommerce ul.products li.product .post_featured.hover_shop_buttons .icons a {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.woocommerce div.product form.cart div.quantity span,
.woocommerce-page div.product form.cart div.quantity span,
.woocommerce .shop_table.cart div.quantity span,
.woocommerce-page .shop_table.cart div.quantity span {
  color: var(--theme-color-input_text);
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.woocommerce div.product form.cart div.quantity span:hover,
.woocommerce-page div.product form.cart div.quantity span:hover,
.woocommerce .shop_table.cart div.quantity span:hover,
.woocommerce-page .shop_table.cart div.quantity span:hover {
  color: var(--theme-color-input_dark);
}

.woocommerce div.product form.cart div.quantity input[type="number"], .woocommerce-page div.product form.cart div.quantity input[type="number"],
.woocommerce .shop_table.cart input[type="number"], .woocommerce-page .shop_table.cart div.quantity input[type="number"] {
  border-color: var(--theme-color-text_link);
}

.woocommerce div.product form.cart div.quantity span.q_inc,
.woocommerce-page div.product form.cart div.quantity span.q_inc,
.woocommerce .shop_table.cart div.quantity span.q_inc,
.woocommerce-page .shop_table.cart div.quantity span.q_inc {
  -webkit-border-radius: 0 30px 0 0;
  -ms-border-radius: 0 30px 0 0;
  border-radius: 0 30px 0 0;
}

.woocommerce div.product form.cart div.quantity span.q_dec,
.woocommerce-page div.product form.cart div.quantity span.q_dec,
.woocommerce .shop_table.cart div.quantity span.q_dec,
.woocommerce-page .shop_table.cart div.quantity span.q_dec {
  -webkit-border-radius: 0 0 30px 0;
  -ms-border-radius: 0 0 30px 0;
  border-radius: 0 0 30px 0;
}

/* Text fields */
.woocommerce table.cart td.actions .coupon .input-text,
.woocommerce #content table.cart td.actions .coupon .input-text,
.woocommerce-page table.cart td.actions .coupon .input-text,
.woocommerce-page #content table.cart td.actions .coupon .input-text {
  padding: 0.6em 0;
  border: none;
  border-bottom-width: 1px;
  border-bottom-style: solid;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

/* Shop Listing
----------------------------------------------------------------- */
.woocommerce ul.products:before, .woocommerce-page ul.products:before,
.woocommerce .products ul:before, .woocommerce-page .products ul:before,
.woocommerce div.product #reviews .comment:before, .woocommerce-page div.product #reviews .comment:before,
.woocommerce #content div.product #reviews .comment:before, .woocommerce-page #content div.product #reviews .comment:before,
.woocommerce .woocommerce-pagination ul.page-numbers:before, .woocommerce-page .woocommerce-pagination ul.page-numbers:before {
  display: none;
}

.woocommerce .list_products_header, .woocommerce-page .list_products_header {
  padding: 0;
  margin-bottom: 2em;
  display: none;
}

.woocommerce .woocommerce-breadcrumb {
  font-size: 15px;
  line-height: 19px;
  color: var(--theme-color-text);
}
.woocommerce .woocommerce-breadcrumb .woocommerce-breadcrumb-delimiter {
  margin: 0 0.3em;
}
.woocommerce .woocommerce-breadcrumb .woocommerce-breadcrumb-delimiter:before {
  content: '/';
}
.woocommerce .woocommerce-breadcrumb a {
  color: var(--theme-color-text);
}
.woocommerce .woocommerce-breadcrumb a:hover {
  color: var(--theme-color-text_dark);
}

.woocommerce .post_item_single .woocommerce-breadcrumb {
  margin: -2em 0 3em;
  display: none;
}

.woocommerce.sidebar_show .post_item_single .woocommerce-breadcrumb {
  margin-top: 0;
}

.woocommerce .post_item_single .summary > .woocommerce-breadcrumb {
  margin-top: -2px;
  margin-bottom: 2em;
}

.woocommerce .page-title {
  margin: 0;
}

.woocommerce ul.products li.product .button,
.woocommerce div.product form.cart .button {
  margin-top: 0;
}

.woocommerce ul.products li.product .add_to_cart:before,
.woocommerce div.product form.cart .button:before {
  content: '\e93d';
  font-family: "fontello";
  margin-right: 0.6em;
  display: none;
}

.woocommerce ul.products li.product.outofstock a[class*="add_to_cart"] {
  display: none;
}

.woocommerce ul.products li.product .outofstock_label {
  position: absolute;
  z-index: 10;
  top: 20px;
  left: 20px;
  background-color: #222733;
  color: #fff;
  text-align: center;
  display: block;
  font-size: 11px;
  font-weight: 700;
  height: 25px;
  line-height: 25px;
  min-height: 25px;
  min-width: 66px;
  width: auto;
  letter-spacing: 0.8px;
  margin: 0;
  padding: 0 18px;
  text-transform: uppercase;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.woocommerce ul.products li.product .outofstock_label + .onsale {
  left: auto;
  right: 20px;
}

.woocommerce .woocommerce-result-count {
  margin: 0 0.3em 0 0;
  font-size: 15px;
  line-height: 22px;
  color: var(--theme-color-text_light);
}

.woocommerce .woocommerce-ordering {
  margin: 0 0 2.8em;
  width: 245px;
}
.woocommerce .woocommerce-ordering .select_container {
  line-height: 1;
}
.woocommerce .woocommerce-ordering .select_container:before {
  content: '';
  display: block;
  position: absolute;
  z-index: 1;
  top: 2px;
  right: 2px;
  bottom: 2px;
  left: auto;
  width: 25px;
}
.woocommerce .woocommerce-ordering .select_container:after {
  content: '\e9e6';
  font-family: "fontello";
  font-size: 10px;
  display: block;
  position: absolute;
  z-index: 2;
  top: 50%;
  right: 0;
  width: 1em;
  height: 1em;
  line-height: 1em;
  text-align: center;
  margin-top: -0.5em;
  color: var(--theme-color-text_dark);
  -webkit-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  transform: rotate(90deg);
}
.woocommerce .woocommerce-ordering select {
  border: none !important;
  background: none !important;
  font-size: 15px;
  line-height: 22px;
  font-weight: inherit;
  color: var(--theme-color-text_dark);
  padding: 0 25px 0 0 !important;
}

.sidebar_show.woocommerce ul.products.columns-4, .sidebar_show.woocommerce-page ul.products.columns-4,
.woocommerce ul.products.columns-5, .woocommerce-page ul.products.columns-5,
.woocommerce ul.products.columns-6, .woocommerce-page ul.products.columns-6,
.woocommerce ul.products.columns-7, .woocommerce-page ul.products.columns-7,
.woocommerce ul.products.columns-8, .woocommerce-page ul.products.columns-8 {
  font-size: 0.9286em;
}

.sidebar_show.woocommerce ul.products.columns-4 a.button, .sidebar_show.woocommerce-page ul.products.columns-4 a.button,
.woocommerce ul.products.columns-5 a.button, .woocommerce-page ul.products.columns-5 a.button,
.woocommerce ul.products.columns-6 a.button, .woocommerce-page ul.products.columns-6 a.button {
  padding: 1em 1.5em;
}

.woocommerce ul.products,
.woocommerce-page ul.products {
  margin-right: -30px;
  margin-bottom: 0;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}

.woocommerce ul.products li.product > .post_item.post_layout_thumbs {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  height: 100%;
}

.woocommerce .products.related ul.products li.product > .post_item.post_layout_thumbs {
  height: auto;
}

.woocommerce ul.products li.product,
.woocommerce ul.products[class*="columns-"] li.product,
.woocommerce[class*="columns-"] ul.products li.product,
.woocommerce-page ul.products li.product,
.woocommerce-page[class*="columns-"] ul.products li.product,
.woocommerce-page ul.products[class*="columns-"] li.product {
  margin: 0;
  clear: none;
  padding: 0 30px 35px 0;
  position: relative;
  width: 50%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.woocommerce.columns-1 ul.products li.product,
.woocommerce ul.products.columns-1 li.product,
.woocommerce ul.products li.product.column-1_1,
.woocommerce .related.products ul.products.columns-1 li.product,
.woocommerce .related.products ul.products li.product.column-1_1,
.woocommerce .upcells.products ul.products li.product.column-1_1,
.woocommerce .upcells.products ul.products.columns-1 li.product,
.woocommerce-page.columns-1 ul.products li.product,
.woocommerce-page ul.products.columns-1 li.product,
.woocommerce-page ul.products li.product.column-1_1,
.woocommerce-page .related.products ul.products.columns-1 li.product,
.woocommerce-page .related.products ul.products li.product.column-1_1,
.woocommerce-page .upcells.products ul.products.columns-1 li.product,
.woocommerce-page .upcells.products ul.products li.product.column-1_1 {
  width: 100%;
}

.woocommerce.columns-2 ul.products li.product,
.woocommerce ul.products.columns-2 li.product,
.woocommerce ul.products li.product.column-1_2,
.woocommerce .related.products ul.products.columns-2 li.product,
.woocommerce .related.products ul.products li.product.column-1_2,
.woocommerce .upcells.products ul.products li.product.column-1_2,
.woocommerce .upcells.products ul.products.columns-2 li.product,
.woocommerce-page.columns-2 ul.products li.product,
.woocommerce-page ul.products.columns-2 li.product,
.woocommerce-page ul.products li.product.column-1_2,
.woocommerce-page .related.products ul.products.columns-2 li.product,
.woocommerce-page .related.products ul.products li.product.column-1_2,
.woocommerce-page .upcells.products ul.products.columns-2 li.product,
.woocommerce-page .upcells.products ul.products li.product.column-1_2 {
  width: 50%;
}

.woocommerce.columns-3 ul.products li.product,
.woocommerce ul.products.columns-3 li.product,
.woocommerce ul.products li.product.column-1_3,
.woocommerce .related.products ul.products.columns-3 li.product,
.woocommerce .related.products ul.products li.product.column-1_3,
.woocommerce .upcells.products ul.products li.product.column-1_3,
.woocommerce .upcells.products ul.products.columns-3 li.product,
.woocommerce-page.columns-3 ul.products li.product,
.woocommerce-page ul.products.columns-3 li.product,
.woocommerce-page ul.products li.product.column-1_3,
.woocommerce-page .related.products ul.products.columns-3 li.product,
.woocommerce-page .related.products ul.products li.product.column-1_3,
.woocommerce-page .upcells.products ul.products.columns-3 li.product,
.woocommerce-page .upcells.products ul.products li.product.column-1_3 {
  width: 33.3333333333%;
}

.woocommerce.columns-4 ul.products li.product,
.woocommerce ul.products.columns-4 li.product,
.woocommerce ul.products li.product.column-1_4,
.woocommerce .related.products ul.products.columns-4 li.product,
.woocommerce .related.products ul.products li.product.column-1_4,
.woocommerce .upcells.products ul.products li.product.column-1_4,
.woocommerce .upcells.products ul.products.columns-4 li.product,
.woocommerce-page.columns-4 ul.products li.product,
.woocommerce-page ul.products.columns-4 li.product,
.woocommerce-page ul.products li.product.column-1_4,
.woocommerce-page .related.products ul.products.columns-4 li.product,
.woocommerce-page .related.products ul.products li.product.column-1_4,
.woocommerce-page .upcells.products ul.products.columns-4 li.product,
.woocommerce-page .upcells.products ul.products li.product.column-1_4 {
  width: 25%;
}

.woocommerce.columns-5 ul.products li.product,
.woocommerce ul.products.columns-5 li.product,
.woocommerce ul.products li.product.column-1_5,
.woocommerce .related.products ul.products.columns-5 li.product,
.woocommerce .related.products ul.products li.product.column-1_5,
.woocommerce .upcells.products ul.products li.product.column-1_5,
.woocommerce .upcells.products ul.products.columns-5 li.product,
.woocommerce-page.columns-5 ul.products li.product,
.woocommerce-page ul.products.columns-5 li.product,
.woocommerce-page ul.products li.product.column-1_5,
.woocommerce-page .related.products ul.products.columns-5 li.product,
.woocommerce-page .related.products ul.products li.product.column-1_5,
.woocommerce-page .upcells.products ul.products.columns-5 li.product,
.woocommerce-page .upcells.products ul.products li.product.column-1_5 {
  width: 20%;
}

.woocommerce.columns-6 ul.products li.product,
.woocommerce ul.products.columns-6 li.product,
.woocommerce ul.products li.product.column-1_6,
.woocommerce .related.products ul.products.columns-6 li.product,
.woocommerce .related.products ul.products li.product.column-1_6,
.woocommerce .upcells.products ul.products li.product.column-1_6,
.woocommerce .upcells.products ul.products.columns-6 li.product,
.woocommerce-page.columns-6 ul.products li.product,
.woocommerce-page ul.products.columns-6 li.product,
.woocommerce-page ul.products li.product.column-1_6,
.woocommerce-page .related.products ul.products.columns-6 li.product,
.woocommerce-page .related.products ul.products li.product.column-1_6,
.woocommerce-page .upcells.products ul.products.columns-6 li.product,
.woocommerce-page .upcells.products ul.products li.product.column-1_6 {
  width: 16.6666666667%;
}

.woocommerce.columns-7 ul.products li.product,
.woocommerce ul.products.columns-7 li.product,
.woocommerce ul.products li.product.column-1_7,
.woocommerce .related.products ul.products.columns-7 li.product,
.woocommerce .related.products ul.products li.product.column-1_7,
.woocommerce .upcells.products ul.products li.product.column-1_7,
.woocommerce .upcells.products ul.products.columns-7 li.product,
.woocommerce-page.columns-7 ul.products li.product,
.woocommerce-page ul.products.columns-7 li.product,
.woocommerce-page ul.products li.product.column-1_7,
.woocommerce-page .related.products ul.products.columns-7 li.product,
.woocommerce-page .related.products ul.products li.product.column-1_7,
.woocommerce-page .upcells.products ul.products.columns-7 li.product,
.woocommerce-page .upcells.products ul.products li.product.column-1_7 {
  width: 14.2857142857%;
}

.woocommerce.columns-8 ul.products li.product,
.woocommerce ul.products.columns-8 li.product,
.woocommerce ul.products li.product.column-1_8,
.woocommerce .related.products ul.products.columns-8 li.product,
.woocommerce .related.products ul.products li.product.column-1_8,
.woocommerce .upcells.products ul.products li.product.column-1_8,
.woocommerce .upcells.products ul.products.columns-8 li.product,
.woocommerce-page.columns-8 ul.products li.product,
.woocommerce-page ul.products.columns-8 li.product,
.woocommerce-page ul.products li.product.column-1_8,
.woocommerce-page .related.products ul.products.columns-8 li.product,
.woocommerce-page .related.products ul.products li.product.column-1_8,
.woocommerce-page .upcells.products ul.products.columns-8 li.product,
.woocommerce-page .upcells.products ul.products li.product.column-1_8 {
  width: 12.5%;
}

.elementor-products-grid .woocommerce ul.products.elementor-grid {
  margin: 0;
}
.elementor-products-grid .woocommerce ul.products.elementor-grid li.product {
  width: 100% !important;
  padding: 0;
}

.woocommerce ul.products li.product-category mark,
.woocommerce-page ul.products li.product-category mark {
  background: none;
}

.woocommerce ul.products li.product .post_item,
.woocommerce-page ul.products li.product .post_item {
  margin-bottom: 0;
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
}

.woocommerce ul.products li.product .post_featured {
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  overflow: hidden;
  margin-bottom: 27px;
  border: none;
}

/* Thumbs mode */
.woocommerce .shop_mode_thumbs ul.products li.product .post_item,
.woocommerce-page .shop_mode_thumbs ul.products li.product .post_item {
  outline: none;
}

.woocommerce .shop_mode_thumbs ul.products li.product .post_item:hover,
.woocommerce-page .shop_mode_thumbs ul.products li.product .post_item:hover {
  outline: none;
}

.woocommerce ul.products li.product a img, .woocommerce-page ul.products li.product a img,
.woocommerce ul.products li.product a:hover img, .woocommerce-page ul.products li.product a:hover img {
  margin: 0;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}

.woocommerce ul.products li.product a img, .woocommerce-page ul.products li.product a img {
  -webkit-transition: opacity 0.3s ease, transform 0.3s ease;
  -ms-transition: opacity 0.3s ease, transform 0.3s ease;
  transition: opacity 0.3s ease, transform 0.3s ease;
}

.woocommerce ul.products li.product .post_featured:hover img,
.woocommerce-page ul.products li.product .post_featured:hover img,
.woocommerce ul.products li.product a:hover img,
.woocommerce-page ul.products li.product a:hover img {
  -webkit-transform: scale(1.1, 1.1);
  -ms-transform: scale(1.1, 1.1);
  transform: scale(1.1, 1.1);
}

.woocommerce ul.products li.product .onsale,
.woocommerce-page ul.products li.product .onsale {
  font-size: 11px;
  font-weight: 700;
  width: auto;
  height: 25px;
  line-height: 25px;
  min-height: 25px;
  min-width: 50px;
  max-width: 55%;
  letter-spacing: 0.8px;
  margin: 0;
  padding: 0 12px;
  left: 20px;
  text-transform: uppercase;
  top: 20px;
  right: auto;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background: var(--theme-color-text_link);
  position: absolute;
  overflow: hidden;
}

.woocommerce ul.products li.product strong {
  margin-top: 0.5em;
}

.woocommerce ul.products li.product .post_data,
.woocommerce-page ul.products li.product .post_data {
  padding: 0;
  text-align: left;
  overflow: hidden;
}
.woocommerce ul.products li.product .post_data .post_data_inner > div + .button.product_type_variable,
.woocommerce ul.products li.product .post_data .post_data_inner > div + .button.product_type_simple,
.woocommerce ul.products li.product .post_data .add_to_cart_wrap,
.woocommerce-page ul.products li.product .post_data .post_data_inner > div + .button.product_type_variable,
.woocommerce-page ul.products li.product .post_data .post_data_inner > div + .button.product_type_simple,
.woocommerce-page ul.products li.product .post_data .add_to_cart_wrap {
  margin-top: 18px;
}
.woocommerce ul.products li.product .post_data .post_data_inner .button,
.woocommerce-page ul.products li.product .post_data .post_data_inner .button {
  padding: 14px 44px;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.woocommerce ul.products li.product .post_data .post_data_inner .button:after,
.woocommerce-page ul.products li.product .post_data .post_data_inner .button:after {
  animation: none;
}
.woocommerce ul.products li.product .post_data .post_data_inner .added_to_cart,
.woocommerce-page ul.products li.product .post_data .post_data_inner .added_to_cart {
  display: block;
  padding: 0;
  margin-top: 0.5em;
}

.woocommerce ul.products li.product.outofstock .post_featured:not(.hover_none) + .post_data .button,
.woocommerce-page ul.products li.product.outofstock .post_featured:not(.hover_none) + .post_data .button,
.woocommerce ul.products li.product .post_featured:not(.hover_none) + .post_data .add_to_cart_button,
.woocommerce-page ul.products li.product .post_featured:not(.hover_none) + .post_data .add_to_cart_button,
.woocommerce ul.products li.product .post_featured:not(.hover_none) + .post_data .button.product_type_external,
.woocommerce-page ul.products li.product .post_featured:not(.hover_none) + .post_data .button.product_type_external,
.woocommerce ul.products li.product .post_featured:not(.hover_none) + .post_data .button.product_type_grouped,
.woocommerce-page ul.products li.product .post_featured:not(.hover_none) + .post_data .button.product_type_grouped {
  display: none;
}

.woocommerce ul.products li.product .post_header a {
  color: var(--theme-color-alter_dark);
}

.woocommerce ul.products li.product .post_header a:hover {
  color: var(--theme-color-alter_link);
}

.woocommerce ul.products li.product .post_header .post_tags {
  font-size: 14px;
  line-height: 1.4em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
  margin-bottom: 0.5em;
}

.woocommerce ul.products li.product .post_header .post_tags,
.woocommerce ul.products li.product .post_header .post_tags a {
  color: var(--theme-color-alter_text);
}

.woocommerce ul.products li.product .post_header .post_tags a:hover {
  color: var(--theme-color-text_hover);
}

.woocommerce ul.products li.product .post_header, .woocommerce-page ul.products li.product .post_header {
  margin-bottom: 0;
}

.woocommerce ul.products li.product .woocommerce-loop-category__title,
.woocommerce ul.products li.product .woocommerce-loop-product__title,
.woocommerce ul.products li.product h3 {
  font-size: 19px;
  line-height: 1.3em;
  font-weight: 700;
  letter-spacing: 0;
  margin-top: 0;
  margin-bottom: 0;
  padding: 0;
}

.search-results .product .price,
.woocommerce ul.products li.product .price,
.woocommerce-page ul.products li.product .price {
  font-size: 18px;
  line-height: 1em;
  font-weight: 700;
  margin: 11px 0 0 0;
}

.search-results .product .price {
  margin: 0 0 11px 0;
}

.woocommerce ul.products.columns-6 li.product .post_featured .icons {
  display: none !important;
}

span.amount {
  line-height: 1em;
}

span.amount > .decimals {
  position: relative;
  display: inline;
  font-size: 0.75em;
  line-height: 1em;
  vertical-align: top;
  margin-left: 0.2em;
}

span.amount > .decimals_separator {
  display: none;
}

.woocommerce div.product p.price,
.woocommerce div.product span.price,
.woocommerce span.amount,
.woocommerce-page span.amount {
  color: var(--theme-color-alter_text);
}

.woocommerce table.shop_table tr.cart-discount td,
.woocommerce table.shop_table td span.amount {
  color: var(--theme-color-alter_text);
}

.woocommerce ul.products li.product .price .decimals,
.woocommerce-page ul.products li.product .price .decimals {
  top: -0.2em;
}

.search-results .product .price ins,
.woocommerce ul.products li.product .price ins {
  text-decoration: none;
  font-weight: inherit;
  font-style: inherit;
}

.search-results .product .price del,
.woocommerce ul.products li.product .price del {
  display: inline-block;
  margin-right: 6px;
  font-size: 1em;
  opacity: 1;
  text-decoration: none;
  position: relative;
}

.search-results .product .price del:before,
.woocommerce ul.products li.product .price del:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 55%;
  left: 0;
  width: 100%;
  height: 1px;
}

.woocommerce ul.products li.product .price,
.woocommerce-page ul.products li.product .price,
.search-results .product .price ins,
.woocommerce ul.products li.product .price ins,
.woocommerce-page ul.products li.product .price ins {
  color: var(--theme-color-alter_text);
}

.search-results .product .price del,
.woocommerce ul.products li.product .price del,
.woocommerce-page ul.products li.product .price del {
  color: var(--theme-color-alter_text);
}

.search-results .product .price del:before,
.woocommerce .price del:before {
  background-color: var(--theme-color-text_light);
}

.search-results .product .price del > span.amount,
aside.woocommerce del,
.woocommerce del, .woocommerce del > span.amount,
.woocommerce del, .woocommerce del > span.amount *,
.woocommerce-page del, .woocommerce-page del > span.amount,
.woocommerce-page del, .woocommerce-page del > span.amount * {
  color: var(--theme-color-text_light) !important;
}

/* Thumbs mode */
.woocommerce .shop_mode_thumbs ul.products li.product .price,
.woocommerce-page .shop_mode_thumbs ul.products li.product .price {
  margin: 11px 0 0;
}

.woocommerce a.added_to_cart,
.woocommerce-page a.added_to_cart {
  padding: 1.3em 0 0 1em;
  vertical-align: top;
  line-height: 1em;
}

.woocommerce #respond input#submit.loading:after, .woocommerce a.button.loading:after, .woocommerce button.button.loading:after, .woocommerce input.button.loading:after {
  display: none;
}

/* Rating stars */
.woocommerce .products .star-rating {
  float: none;
  margin: 0.6em auto -0.6em;
}

.woocommerce ul.products li.product .post_header {
  position: relative;
  overflow: visible;
}

.woocommerce ul.products li.product .star-rating {
  font-size: 14px;
  width: 78px;
  margin: 15px 0 0;
  letter-spacing: 2px;
}

.woocommerce .products .star-rating:before,
.woocommerce .products .star-rating span {
  top: 0;
  left: 1px;
}

.woocommerce .star-rating span:before,
.woocommerce .star-rating:before {
  content: "\e96e\e96e\e96e\e96e\e96e";
  font-family: "fontello";
}

.woocommerce p.stars a,
.star-rating span,
.star-rating:before {
  color: #FFC107;
}

.woocommerce .star-rating:before {
  color: var(--theme-color-text_dark_02);
}

.woocommerce p.stars a:hover {
  color: var(--theme-color-text_link);
}

#review_form #respond p.form-submit input[type="submit"] {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
}

#review_form #respond p.form-submit input[type="submit"]:hover,
#review_form #respond p.form-submit input[type="submit"]:focus {
  color: var(--theme-color-bg_color);
  background-color: var(--theme-color-text_dark);
}

/* Pagination */
.woocommerce-links-more + .woocommerce-pagination {
  display: none;
}

.return-to-shop {
  text-align: center;
}

/* Single product decoration
---------------------------------------------------------------------------- */
/* Messages */
.woocommerce .woocommerce-message,
.woocommerce .woocommerce-info {
  background-color: transparent;
  border: none;
  margin: 0 0 48px 0;
}

.woocommerce form.checkout_coupon,
.woocommerce form.login,
.woocommerce form.register {
  border: none;
  padding: 0;
  margin: 48px auto 0 auto;
  text-align: center;
}

.woocommerce-error,
.woocommerce-info,
.woocommerce-message {
  padding: 0;
  margin: 0;
  text-align: center;
  font-size: 1em;
  font-weight: 400;
  border: none;
  background-color: transparent;
  color: var(--theme-color-text);
}
.woocommerce-error a,
.woocommerce-info a,
.woocommerce-message a {
  font-weight: 500;
  color: var(--theme-color-text_dark);
}
.woocommerce-error a:hover,
.woocommerce-info a:hover,
.woocommerce-message a:hover {
  color: var(--theme-color-text_link);
}

.woocommerce .woocommerce-error {
  text-align: center;
  padding: 35px 0 0 0;
  margin: 0 0 50px 0;
}
.woocommerce .woocommerce-error:before {
  top: 0;
  left: 50%;
  -webkit-transform: translateX(-50%);
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
}

.woocommerce .woocommerce-message:before,
.woocommerce .woocommerce-info:before {
  color: var(--theme-color-alter_dark);
}

.woocommerce .woocommerce-error:before {
  color: var(--theme-color-alter_link);
}

.woocommerce .woocommerce-error .button,
.woocommerce .woocommerce-info .button,
.woocommerce .woocommerce-message .button {
  margin: 0;
  padding: 0;
  display: inline-block;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  -webkit-box-shadow: none !important;
  -ms-box-shadow: none !important;
  box-shadow: none !important;
  background-color: transparent !important;
  float: none;
  color: var(--theme-color-text_link);
  letter-spacing: 0;
  font-size: inherit;
  line-height: inherit;
  margin-right: 5px;
}
.woocommerce .woocommerce-error .button:focus, .woocommerce .woocommerce-error .button:hover,
.woocommerce .woocommerce-info .button:focus,
.woocommerce .woocommerce-info .button:hover,
.woocommerce .woocommerce-message .button:focus,
.woocommerce .woocommerce-message .button:hover {
  color: var(--theme-color-text_hover);
}

.woocommerce .woocommerce-message:before,
.woocommerce .woocommerce-info:before {
  display: none;
}

.woocommerce-checkout .woocommerce-form-coupon-toggle .woocommerce-info {
  margin: 0;
}

.wc-block-components-notice-banner[class*="wc-block"] {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  font-size: 0.9em;
  line-height: 1.4em;
  font-weight: inherit;
  color: var(--theme-color-text);
  background-color: transparent !important;
  margin: 0 0 calc(var(--theme-var-grid_gap) * 2) 0;
}
.wc-block-components-notice-banner[class*="wc-block"].is-error {
  border-color: #FF5B4A;
}
.wc-block-components-notice-banner[class*="wc-block"].is-error > svg {
  background-color: #FF5B4A;
}
.wc-block-components-notice-banner[class*="wc-block"] a {
  color: var(--theme-color-text_dark);
}
.wc-block-components-notice-banner[class*="wc-block"] a:hover, .wc-block-components-notice-banner[class*="wc-block"] a:focus {
  color: var(--theme-color-text_link);
}
.wc-block-components-notice-banner[class*="wc-block"] > .wc-block-components-notice-banner__content .wc-forward {
  display: block;
  width: fit-content;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  font-size: inherit;
  line-height: inherit;
  font-weight: inherit;
  text-transform: inherit;
  letter-spacing: inherit;
  background-color: transparent;
  text-decoration-line: underline;
  opacity: 1;
  color: var(--theme-color-text_dark) !important;
  font-family: inherit;
  margin-left: 5px;
}
@media (max-width: 767px) {
  .wc-block-components-notice-banner[class*="wc-block"] > .wc-block-components-notice-banner__content .wc-forward {
    margin: 0 0 8px 0;
    float: none;
  }
}
.wc-block-components-notice-banner[class*="wc-block"] > .wc-block-components-notice-banner__content .wc-forward:hover, .wc-block-components-notice-banner[class*="wc-block"] > .wc-block-components-notice-banner__content .wc-forward:focus {
  color: var(--theme-color-text_link) !important;
}
.woocommerce-form-coupon-toggle .wc-block-components-notice-banner[class*="wc-block"] {
  margin-bottom: 0;
}

/* coupon */
.woocommerce-form-coupon-toggle {
  margin-bottom: 0;
  padding-bottom: 10px;
}

.woocommerce-form-coupon p {
  font-size: 15px;
  line-height: 1.3em;
  font-weight: 400;
  margin: 23px 0 0 0;
}
.woocommerce-form-coupon .cart-coupon-inner {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  border: 1px solid var(--theme-color-bd_color);
  align-items: center;
  padding-left: 25px;
  height: 55px;
  margin: 0 auto;
  width: 530px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.woocommerce-form-coupon .cart-coupon-inner:before {
  content: '\e9bd';
  font-family: "fontello";
  display: inline-block;
  color: var(--theme-color-text_dark);
  font-size: 22px;
  font-weight: 400;
}
.woocommerce-form-coupon .cart-coupon-inner input {
  padding: 13px 10px;
  font-size: 14px;
  font-weight: 400;
  line-height: normal;
  border: none;
  flex: 1 auto;
  width: 100%;
  margin-right: 155px;
}
.woocommerce-form-coupon .cart-coupon-inner button {
  display: inline-flex;
  width: 155px;
  padding: 0;
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  background: none;
  align-items: center;
  justify-content: center;
  font-size: 15px;
  color: var(--theme-color-text_dark);
  background-color: var(--theme-color-bg_color) !important;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.woocommerce-form-coupon .cart-coupon-inner button:focus, .woocommerce-form-coupon .cart-coupon-inner button:hover {
  color: var(--theme-color-text_link);
}
.woocommerce-form-coupon .cart-coupon-inner button:before {
  content: "";
  display: block;
  height: 22px;
  width: 1px;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 0;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  background: var(--theme-color-bd_color);
}

/* Title */
.woocommerce div.product .product_title {
  margin: -0.15em 0 0.55em;
  font-size: var(--theme-font-h3_font-size);
  line-height: var(--theme-font-h3_line-height);
  font-weight: var(--theme-font-h3_font-weight);
  letter-spacing: var(--theme-font-h3_letter-spacing);
}

/* Des */
.woocommerce div.product .woocommerce-product-details__short-description {
  margin-bottom: 40px;
}
.woocommerce div.product .woocommerce-product-details__short-description p:last-child {
  margin: 0;
}

/* Price */
.woocommerce div.product p.price,
.woocommerce div.product span.price {
  position: relative;
  font-size: 24px;
  font-weight: 700;
  color: var(--theme-color-text_link);
}
.woocommerce div.product p.price span.amount,
.woocommerce div.product span.price span.amount {
  color: var(--theme-color-text_link);
}
.woocommerce div.product p.price .woocommerce-Price-currencySymbol,
.woocommerce div.product span.price .woocommerce-Price-currencySymbol {
  letter-spacing: 2px;
}

.woocommerce div.product p.price {
  margin: 0 0 35px;
}

.woocommerce div.product span.price ins,
.woocommerce div.product p.price ins {
  text-decoration: none;
  font-style: normal;
  font-weight: 700;
}

/* Images and thumbnails */
.woocommerce, .woocommerce-page {
  --theme-var-single-product-gallery-width: 56%;
}

.woocommerce-main-image {
  position: relative;
  display: block;
}

.woocommerce div.product div.images,
.woocommerce #content div.product div.images,
.woocommerce-page div.product div.images,
.woocommerce-page #content div.product div.images {
  margin-bottom: 6.5em;
}

.woocommerce.sidebar_show div.product div.images, .woocommerce-page.sidebar_show div.product div.images,
.woocommerce.sidebar_show #content div.product div.images, .woocommerce-page.sidebar_show #content div.product div.images {
  width: 100%;
  float: none;
  margin-bottom: 60px;
}

.woocommerce.sidebar_hide div.product div.images, .woocommerce-page.sidebar_hide div.product div.images,
.woocommerce.sidebar_hide #content div.product div.images, .woocommerce-page.sidebar_hide #content div.product div.images {
  width: var(--theme-var-single-product-gallery-width);
  float: left;
}

.woocommerce div.product div.images img {
  border: none;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.woocommerce div.product div.images .woocommerce-product-gallery__image:first-child {
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.woocommerce div.product div.images .woocommerce-product-gallery__image:nth-child(n+2) {
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

/* Built-in images slider */
.woocommerce div.product div.images .flex-viewport {
  border: none;
}
.woocommerce div.product div.images .woocommerce-product-gallery__wrapper {
  max-width: none;
  display: block;
}
.woocommerce div.product div.images .woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image:first-child {
  margin-bottom: 0;
}
.woocommerce div.product div.images .woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image:nth-child(n+2) {
  padding: 0;
}
.woocommerce div.product div.images .woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image img {
  border: none;
}
.woocommerce div.product div.images .flex-control-thumbs li {
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.woocommerce div.product div.images img {
  border-color: var(--theme-color-bd_color);
}
.woocommerce div.product div.images a:hover img {
  border-color: var(--theme-color-text_link);
}

.woocommerce div.product div.images .woocommerce-product-gallery__trigger {
  display: block;
  overflow: hidden;
  color: #000000 !important;
  background-color: #ffffff !important;
  letter-spacing: 0 !important;
  cursor: pointer;
  text-align: center;
  border: none !important;
  margin: 0 !important;
  width: 47px;
  height: 47px;
  line-height: 48px !important;
  -webkit-border-radius: 50% !important;
  -ms-border-radius: 50% !important;
  border-radius: 50% !important;
  -webkit-transition: all 0.2s ease !important;
  -ms-transition: all 0.2s ease !important;
  transition: all 0.2s ease !important;
  -webkit-box-shadow: 0 0 30px 0 rgba(0, 0, 0, 0.06);
  -ms-box-shadow: 0 0 30px 0 rgba(0, 0, 0, 0.06);
  box-shadow: 0 0 30px 0 rgba(0, 0, 0, 0.06);
  position: absolute;
  visibility: visible !important;
  pointer-events: auto !important;
  top: 20px;
  right: 20px;
  opacity: 1 !important;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger:after {
  display: none !important;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger:before {
  content: '\e9a6';
  font-family: "fontello";
  border: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  position: static;
  font-size: 18px;
  width: 100%;
  height: 100%;
  text-indent: 0;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger:hover {
  color: var(--theme-color-text_link) !important;
}

.woocommerce div.product div.images {
  position: relative;
  overflow: hidden;
  padding-left: 150px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.woocommerce div.product div.images.woocommerce-product-gallery--without-thumbs {
  padding-left: 0 !important;
}
.woocommerce div.product div.images .flex-control-thumbs {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  margin: 0;
  width: 150px;
  padding: 0 50px 0 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  height: 100%;
  overflow-x: hidden;
  overflow-y: auto;
  /* Scrollbar decoration */
  scrollbar-width: thin;
}
.woocommerce div.product div.images .flex-control-thumbs::-webkit-scrollbar {
  width: 8px;
}
.woocommerce div.product div.images .flex-control-thumbs::-webkit-scrollbar-track {
  background: var(--theme-color-alter_bg_color);
}
.woocommerce div.product div.images .flex-control-thumbs::-webkit-scrollbar-thumb {
  background-color: var(--theme-color-alter_bd_color);
}
.woocommerce div.product div.images .flex-control-thumbs li {
  padding: 0 0 20px 0;
  display: block;
  width: 100%;
}
.woocommerce div.product div.images .flex-control-thumbs li:last-child {
  padding-bottom: 0 !important;
}

.woocommerce div.product .summary span.onsale {
  font-size: 11px;
  line-height: 15px;
  font-weight: 700;
  margin: 0 0 30px;
  padding: 5px 15px;
  display: table;
  text-transform: uppercase;
  pointer-events: none;
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
  width: auto;
  min-width: 50px;
  max-width: 200px;
  height: auto;
  min-height: auto;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  letter-spacing: 0.8px;
  position: static;
}

body:not(.trx_addons_present) div.product span.onsale {
  line-height: 16px;
}

.woocommerce div.product div.thumbnails > div,
.woocommerce div.product div.thumbnails > ul {
  max-height: 15em;
}

.woocommerce #content div.product div.thumbnails a, .woocommerce div.product div.thumbnails a,
.woocommerce-page #content div.product div.thumbnails a, .woocommerce-page div.product div.thumbnails a {
  margin-right: 1.5%;
  width: 18.5%;
  position: relative;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.woocommerce #content div.product div.thumbnails a:hover, .woocommerce div.product div.thumbnails a:hover,
.woocommerce-page #content div.product div.thumbnails a:hover, .woocommerce-page div.product div.thumbnails a:hover {
  border-style: solid;
}

.woocommerce #content div.product div.thumbnails.columns-4 a, .woocommerce div.product div.thumbnails.columns-4 a,
.woocommerce-page #content div.product div.thumbnails.columns-4 a, .woocommerce-page div.product div.thumbnails.columns-4 a {
  margin-right: 2.6666%;
  width: 23%;
}

.woocommerce #content div.product div.thumbnails.columns-3 a, .woocommerce div.product div.thumbnails.columns-3 a,
.woocommerce-page #content div.product div.thumbnails.columns-3 a, .woocommerce-page div.product div.thumbnails.columns-3 a {
  margin-right: 3.5%;
  width: 31%;
}

.woocommerce #content div.product div.thumbnails a:before, .woocommerce div.product div.thumbnails a:before, .woocommerce-page #content div.product div.thumbnails a:before, .woocommerce-page div.product div.thumbnails a:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.woocommerce #content div.product div.thumbnails a:hover:before, .woocommerce div.product div.thumbnails a:hover:before, .woocommerce-page #content div.product div.thumbnails a:hover:before, .woocommerce-page div.product div.thumbnails a:hover:before {
  background-color: rgba(255, 255, 255, 0.4);
}

.woocommerce #content div.product div.thumbnails a.first, .woocommerce div.product div.thumbnails a.first, .woocommerce-page #content div.product div.thumbnails a.first, .woocommerce-page div.product div.thumbnails a.first {
  clear: none;
}

.woocommerce #content div.product div.thumbnails a.last, .woocommerce div.product div.thumbnails a.last, .woocommerce-page #content div.product div.thumbnails a.last, .woocommerce-page div.product div.thumbnails a.last {
  margin-right: 0;
}

.woocommerce #content div.product div.thumbnails a:nth-child(4n+1), .woocommerce div.product div.thumbnails a:nth-child(4n+1), .woocommerce-page #content div.product div.thumbnails a:nth-child(4n+1), .woocommerce-page div.product div.thumbnails a:nth-child(4n+1) {
  clear: both;
}

.woocommerce div.product div.images .flex-control-thumbs li img {
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}

div.pp_woocommerce .pp_arrow_next, div.pp_woocommerce .pp_arrow_previous {
  margin-top: 4px;
}

.pswp {
  z-index: 10000;
}

/* Product summary */
.woocommerce #content div.product div.summary,
.woocommerce div.product div.summary, .woocommerce-page #content div.product div.summary,
.woocommerce-page div.product div.summary {
  margin-bottom: 6.5em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.woocommerce.sidebar_show #content div.product div.summary,
.woocommerce.sidebar_show div.product div.summary, .woocommerce-page.sidebar_show #content div.product div.summary,
.woocommerce-page.sidebar_show div.product div.summary {
  width: 100%;
  float: none;
  padding-left: 0;
  padding-right: 0;
}
.woocommerce.sidebar_hide #content div.product div.summary,
.woocommerce.sidebar_hide div.product div.summary, .woocommerce-page.sidebar_hide #content div.product div.summary,
.woocommerce-page.sidebar_hide div.product div.summary {
  width: calc( 100% - var(--theme-var-single-product-gallery-width) );
  padding-left: 60px;
  float: right;
}
.woocommerce #content div.product div.summary:after,
.woocommerce div.product div.summary:after, .woocommerce-page #content div.product div.summary:after,
.woocommerce-page div.product div.summary:after {
  content: ' ';
  float: none;
  clear: both;
  width: 100%;
  height: 0;
  display: block;
}

.single-product div.product .woocommerce-tabs ul.wc-tabs li a {
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
}
.single-product div.product .woocommerce-tabs ul.wc-tabs li:not(.active) a:hover,
.single-product div.product .woocommerce-tabs ul.wc-tabs li.active a {
  color: var(--theme-color-alter_dark);
  background-color: transparent;
  border-color: var(--theme-color-alter_dark);
}

.single-product div.product .woocommerce-tabs .panel {
  color: var(--theme-color-text);
}

/* Additional info */
.woocommerce div.product div.summary .woocommerce-product-details__additional-information h2,
.woocommerce div.product .woocommerce-stack-additional_information h2, .woocommerce-page div.product div.summary .woocommerce-product-details__additional-information h2,
.woocommerce-page div.product .woocommerce-stack-additional_information h2 {
  display: none;
}
.woocommerce div.product div.summary .woocommerce-product-details__additional-information table, .woocommerce div.product div.summary .woocommerce-product-details__additional-information th, .woocommerce div.product div.summary .woocommerce-product-details__additional-information td,
.woocommerce div.product .woocommerce-stack-additional_information table,
.woocommerce div.product .woocommerce-stack-additional_information th,
.woocommerce div.product .woocommerce-stack-additional_information td, .woocommerce-page div.product div.summary .woocommerce-product-details__additional-information table, .woocommerce-page div.product div.summary .woocommerce-product-details__additional-information th, .woocommerce-page div.product div.summary .woocommerce-product-details__additional-information td,
.woocommerce-page div.product .woocommerce-stack-additional_information table,
.woocommerce-page div.product .woocommerce-stack-additional_information th,
.woocommerce-page div.product .woocommerce-stack-additional_information td {
  background-color: transparent !important;
  text-transform: none;
  padding: 0;
  border: none;
  width: auto;
  font-weight: inherit;
  font-style: normal;
}
.woocommerce div.product div.summary .woocommerce-product-details__additional-information th,
.woocommerce div.product .woocommerce-stack-additional_information th, .woocommerce-page div.product div.summary .woocommerce-product-details__additional-information th,
.woocommerce-page div.product .woocommerce-stack-additional_information th {
  padding-right: 1em;
}
.woocommerce div.product div.summary .woocommerce-product-details__additional-information th:after,
.woocommerce div.product .woocommerce-stack-additional_information th:after, .woocommerce-page div.product div.summary .woocommerce-product-details__additional-information th:after,
.woocommerce-page div.product .woocommerce-stack-additional_information th:after {
  content: ':';
}
.woocommerce div.product div.summary .woocommerce-product-details__additional-information p,
.woocommerce div.product .woocommerce-stack-additional_information p, .woocommerce-page div.product div.summary .woocommerce-product-details__additional-information p,
.woocommerce-page div.product .woocommerce-stack-additional_information p {
  padding: 0;
}

/* Meta: SKU, tags, categories, ID */
.woocommerce .product_meta span {
  display: block;
  font-weight: 700;
  font-size: 16px;
  line-height: 1.3em;
  color: var(--theme-color-text_dark);
}
.woocommerce .product_meta span span {
  display: inline;
}
.woocommerce .product_meta span + span {
  margin-top: 10px;
}
.woocommerce .product_meta span > a,
.woocommerce .product_meta span > span {
  letter-spacing: 0;
  color: var(--theme-color-text);
  font-size: 15px;
  font-weight: 400;
}
.woocommerce .product_meta span a:hover {
  color: var(--theme-color-text_link);
}

.woocommerce div.product .summary .stock {
  font-size: 19px;
  line-height: 24px;
  font-weight: 500;
  text-decoration: none;
  text-transform: none;
  letter-spacing: 0;
  display: inline-block;
  color: var(--theme-color-text_dark);
  position: relative;
  margin-bottom: 40px;
}
.woocommerce div.product .summary .stock:after {
  content: "";
  display: block;
  height: 1px;
  width: 100%;
  margin-top: 5px;
  border-bottom: 1px solid var(--theme-color-text_link);
  -webkit-box-shadow: 0 9px 16px rgba(0, 0, 0, 0.2);
  -ms-box-shadow: 0 9px 16px rgba(0, 0, 0, 0.2);
  box-shadow: 0 9px 16px rgba(0, 0, 0, 0.2);
}

/* Add to cart */
.woocommerce div.product form.cart, .woocommerce #content div.product form.cart, .woocommerce-page div.product form.cart, .woocommerce-page #content div.product form.cart {
  padding: 0;
  margin-bottom: 44px;
}

.single_product_bottom_bar_sticky div.quantity,
.woocommerce div.product form.cart div.quantity,
.woocommerce-page div.product form.cart div.quantity,
.woocommerce .shop_table.cart div.quantity,
.woocommerce-page .shop_table.cart div.quantity {
  margin: 0 10px 0 0;
  width: 130px;
  height: 55px;
  position: relative;
}
.single_product_bottom_bar_sticky div.quantity span,
.woocommerce div.product form.cart div.quantity span,
.woocommerce-page div.product form.cart div.quantity span,
.woocommerce .shop_table.cart div.quantity span,
.woocommerce-page .shop_table.cart div.quantity span {
  display: block;
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  right: 1px;
  top: 1px;
  width: 39px;
  height: 50%;
  line-height: 1.95em;
  text-align: left;
  cursor: pointer;
  padding-left: 5px;
}
.single_product_bottom_bar_sticky div.quantity span:before,
.woocommerce div.product form.cart div.quantity span:before,
.woocommerce-page div.product form.cart div.quantity span:before,
.woocommerce .shop_table.cart div.quantity span:before,
.woocommerce-page .shop_table.cart div.quantity span:before {
  font-family: "fontello";
  font-weight: 400;
}
.single_product_bottom_bar_sticky div.quantity span.q_dec,
.woocommerce div.product form.cart div.quantity span.q_dec,
.woocommerce-page div.product form.cart div.quantity span.q_dec,
.woocommerce .shop_table.cart div.quantity span.q_dec,
.woocommerce-page .shop_table.cart div.quantity span.q_dec {
  top: auto;
  bottom: 1px;
  border-top: none;
  line-height: 1.6em;
}
.single_product_bottom_bar_sticky div.quantity span.q_inc:before,
.woocommerce div.product form.cart div.quantity span.q_inc:before,
.woocommerce-page div.product form.cart div.quantity span.q_inc:before,
.woocommerce .shop_table.cart div.quantity span.q_inc:before,
.woocommerce-page .shop_table.cart div.quantity span.q_inc:before {
  content: '\e835';
}
.single_product_bottom_bar_sticky div.quantity span.q_dec:before,
.woocommerce div.product form.cart div.quantity span.q_dec:before,
.woocommerce-page div.product form.cart div.quantity span.q_dec:before,
.woocommerce .shop_table.cart div.quantity span.q_dec:before,
.woocommerce-page .shop_table.cart div.quantity span.q_dec:before {
  content: '\e828';
}
.single_product_bottom_bar_sticky div.quantity input[type="number"],
.woocommerce div.product form.cart div.quantity input[type="number"],
.woocommerce-page div.product form.cart div.quantity input[type="number"],
.woocommerce .shop_table.cart div.quantity input[type="number"],
.woocommerce-page .shop_table.cart div.quantity input[type="number"] {
  width: 100%;
  height: 100%;
  padding: 0 48px 0 25px;
  text-align: left;
  font-size: 16px;
  font-weight: 400;
  color: var(--theme-color-input_text);
  border: 1px solid var(--theme-color-input_bd_color) !important;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  -moz-appearance: textfield;
  appearance: textfield;
}
.single_product_bottom_bar_sticky div.quantity input[type="number"]::-webkit-inner-spin-button,
.single_product_bottom_bar_sticky div.quantity input[type="number"]::-webkit-outer-spin-button,
.woocommerce div.product form.cart div.quantity input[type="number"]::-webkit-inner-spin-button,
.woocommerce div.product form.cart div.quantity input[type="number"]::-webkit-outer-spin-button,
.woocommerce-page div.product form.cart div.quantity input[type="number"]::-webkit-inner-spin-button,
.woocommerce-page div.product form.cart div.quantity input[type="number"]::-webkit-outer-spin-button,
.woocommerce .shop_table.cart div.quantity input[type="number"]::-webkit-inner-spin-button,
.woocommerce .shop_table.cart div.quantity input[type="number"]::-webkit-outer-spin-button,
.woocommerce-page .shop_table.cart div.quantity input[type="number"]::-webkit-inner-spin-button,
.woocommerce-page .shop_table.cart div.quantity input[type="number"]::-webkit-outer-spin-button {
  -webkit-appearance: none;
  margin: 0;
}

.woocommerce .shop_table.cart div.quantity, .woocommerce-page .shop_table.cart div.quantity {
  margin: 0;
  width: 7em;
  font-size: 1rem;
}

/* Grouped product */
.woocommerce div.product form.cart .group_table {
  margin-bottom: 1.8em;
}

.woocommerce div.product form.cart .group_table td {
  padding: 1.8em 1em;
  vertical-align: middle;
  font-size: 0.9em;
}
.woocommerce div.product form.cart .group_table td .stock {
  font-size: 0.9em;
  margin: 0;
  display: table-cell;
}
.woocommerce div.product form.cart .group_table td .stock:after {
  margin-top: 2px;
}

/* Product variations */
.woocommerce div.product form.cart .variations {
  margin-bottom: 34px;
}
.woocommerce div.product form.cart .variations .select_container {
  max-width: 300px;
}
.woocommerce div.product form.cart .variations th,
.woocommerce div.product form.cart .variations td {
  display: block;
  width: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  padding: 0 0 13px;
  background-color: transparent;
  text-align: left;
  line-height: 1.2em;
}
.woocommerce div.product form.cart .variations tr:last-child td.value {
  padding-bottom: 0;
}

.woocommerce div.product form.cart .variations tr + tr .label {
  padding: 17px 0 13px 0;
}

.woocommerce div.product form.cart .variations .label {
  font-weight: 700;
  font-size: 16px;
  line-height: 1.2em;
  vertical-align: middle;
  color: var(--theme-color-text_dark);
}

.woocommerce div.product form.cart .variations label {
  font-weight: 700;
}

.woocommerce div.product form.cart .reset_variations {
  font-style: italic;
  font-size: 1em;
  letter-spacing: 0;
}

.woocommerce-variation-price {
  margin: 0;
}

.woocommerce-variation-price .price {
  padding-bottom: 25px;
  display: inline-block;
}

.woocommerce td.product-name dl.variation dd,
.woocommerce td.product-name dl.variation dt {
  font-size: 14px;
  line-height: 1.25em;
  font-weight: var(--theme-font-p_font-weight);
  padding: 0;
  margin: 0;
  color: var(--theme-color-text);
}
.woocommerce td.product-name dl.variation dd *,
.woocommerce td.product-name dl.variation dt * {
  color: inherit;
}

.woocommerce td.product-name dl.variation dt {
  padding-top: 0.4em;
  padding-right: 0.4em;
}

.woocommerce td.product-name dl.variation dd {
  padding-top: 0.4em;
}

.woocommerce .reset_variations {
  display: none !important;
}

/* Wishlist and compare */
.woocommerce .product .summary > .yith-wcwl-add-to-wishlist {
  float: left;
  width: auto;
  margin-top: 0;
  margin-bottom: 2em;
}

.woocommerce .product .summary > .compare {
  float: left;
  margin-bottom: 2em;
  margin-right: 2em;
}

.woocommerce .product .summary div.woocommerce-tabs + .compare,
.woocommerce .product .summary div.woocommerce-tabs + .compare + .yith-wcwl-add-to-wishlist,
.woocommerce .product .summary div.woocommerce-product-gallery__image + .compare,
.woocommerce .product .summary div.woocommerce-product-gallery__image + .compare + .yith-wcwl-add-to-wishlist {
  margin-top: 2em;
  margin-bottom: 0;
}

.woocommerce .product .yith-wcwl-add-to-wishlist {
  margin: 0;
}

.woocommerce .product .compare:before,
.woocommerce .product .yith-wcwl-add-to-wishlist .add_to_wishlist:before,
.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistaddedbrowse > a:before,
.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistexistsbrowse > a:before {
  content: '\e8a8';
  font-family: "fontello";
  margin-right: 0.2em;
}

.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistaddedbrowse > a:before {
  content: '\e8aa';
}

.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistexistsbrowse > a:before {
  content: '\e8aa';
}

.woocommerce .product .compare:before {
  content: '\e8e7';
  margin-right: 0.5em;
}

.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistaddedbrowse,
.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistexistsbrowse {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}

.woocommerce .product .yith-wcwl-add-to-wishlist .feedback,
.woocommerce .product .yith-wcwl-add-to-wishlist .feedback {
  order: 2;
  margin: 0 0 0 0.5em;
  font-size: 0.923em;
}

.woocommerce .product .yith-wcwl-add-to-wishlist .feedback:before,
.woocommerce .product .yith-wcwl-add-to-wishlist .feedback:before {
  content: '(';
}

.woocommerce .product .yith-wcwl-add-to-wishlist .feedback:after,
.woocommerce .product .yith-wcwl-add-to-wishlist .feedback:after {
  content: ')';
}

.woocommerce .product .summary ~ .yith-wcwl-add-to-wishlist {
  margin-top: 2em;
}

.woocommerce ul.products li.product .yith-wcwl-add-to-wishlist .feedback {
  display: none;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image > .yith-wcwl-add-to-wishlist {
  display: none;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist {
  position: static;
  left: auto;
  top: auto;
  margin: 0;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist i,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist .yith-wcwl-icon {
  display: none;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist .feedback + a,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist .add_to_wishlist,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist .disabled_item,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist .open-pretty-photo {
  font-size: 1em;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap {
  position: absolute;
  z-index: 2000;
  top: 1em;
  left: 1em;
  -webkit-transform: translateX(-60%);
  -ms-transform: translateX(-60%);
  transform: translateX(-60%);
  -webkit-transition: -webkit-transform 0.3s ease, opacity 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease, opacity 0.3s ease;
  transition: transform 0.3s ease, opacity 0.3s ease;
  opacity: 0;
  border: 1px solid var(--theme-color-extra_bd_color);
  background-color: var(--theme-color-extra_bg_color);
}

.woocommerce .related.products ul.products li.product.add-to-wishlist-before_image .post_item .yith_buttons_wrap {
  top: -1em;
  -webkit-transform: translateX(-200%);
  -ms-transform: translateX(-200%);
  transform: translateX(-200%);
}

.woocommerce .related.products ul.products li.product.add-to-wishlist-before_image .post_item:hover .yith_buttons_wrap {
  -webkit-transform: translateX(-60%);
  -ms-transform: translateX(-60%);
  transform: translateX(-60%);
}

.mobile_layout.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap,
.woocommerce ul.products li.product.add-to-wishlist-before_image .post_item:hover .yith_buttons_wrap {
  -webkit-transform: translateX(0);
  -ms-transform: translateX(0);
  transform: translateX(0);
  opacity: 1;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > :nth-child(n+1) {
  border-top: 1px dotted var(--theme-color-extra_bd_color);
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist {
  margin: 0;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist > div {
  position: relative;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist > div > img {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  margin: 0;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > a,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist > div > a {
  display: block;
  position: relative;
  z-index: 2;
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > a:before,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist > div > a:before {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist > div > span {
  display: none !important;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a {
  color: var(--theme-color-extra_link);
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a:hover {
  color: var(--theme-color-extra_hover);
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a > .tooltip {
  display: inline-block;
  vertical-align: top;
  pointer-events: none;
  padding: 6px 10px;
  font-size: 12px;
  line-height: 16px;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 100%;
  margin-left: 10px;
  white-space: nowrap;
  -webkit-transform: translateX(20px);
  -ms-transform: translateX(20px);
  transform: translateX(20px);
  opacity: 0;
  -webkit-transition: -webkit-transform 0.3s ease, opacity 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease, opacity 0.3s ease;
  transition: transform 0.3s ease, opacity 0.3s ease;
  border-width: 0;
  color: var(--theme-color-extra_text);
  background-color: var(--theme-color-extra_bg_color);
  border-color: var(--theme-color-extra_bg_color);
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a > .tooltip:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 50%;
  left: -7px;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  border-style: solid;
  border-width: 0 0 4px 7px;
  border-bottom-color: inherit;
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a:hover > .tooltip {
  -webkit-transform: translateX(0);
  -ms-transform: translateX(0);
  transform: translateX(0);
  opacity: 1;
}

.woocommerce ul.products.columns-5 li.product.add-to-wishlist-before_image .yith_buttons_wrap .tooltip,
.woocommerce ul.products.columns-6 li.product.add-to-wishlist-before_image .yith_buttons_wrap .tooltip {
  padding: 3px 6px;
  font-size: 10px;
  line-height: 14px;
}

.woocommerce.single-product ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap {
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bg_color);
}

.woocommerce.single-product ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > :nth-child(n+1) {
  border-color: var(--theme-color-alter_bd_color);
}

.woocommerce.single-product ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a {
  color: var(--theme-color-alter_link);
}

.woocommerce.single-product ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a:hover {
  color: var(--theme-color-alter_hover);
}

.woocommerce.single-product ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a > .tooltip {
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
  border-color: var(--theme-color-alter_bg_color);
}

.woocommerce ul.products li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap,
.woocommerce ul.products li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.woocommerce ul.products li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist,
.woocommerce ul.products li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist {
  margin-left: 1em;
}

.woocommerce ul.products li.product.add-to-wishlist-before_add_to_cart .add_to_cart_wrap + .yith_buttons_wrap,
.woocommerce ul.products li.product.add-to-wishlist-after_add_to_cart .add_to_cart_wrap + .yith_buttons_wrap {
  margin-top: 1em;
}

.woocommerce ul.products.columns-4 li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap, .woocommerce ul.products.columns-4 li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap,
.woocommerce ul.products.columns-5 li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap,
.woocommerce ul.products.columns-5 li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap,
.woocommerce ul.products.columns-6 li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap,
.woocommerce ul.products.columns-6 li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap,
.woocommerce ul.products.columns-7 li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap,
.woocommerce ul.products.columns-7 li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap,
.woocommerce ul.products.columns-8 li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap,
.woocommerce ul.products.columns-8 li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap {
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}
.woocommerce ul.products.columns-4 li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist, .woocommerce ul.products.columns-4 li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist,
.woocommerce ul.products.columns-5 li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist,
.woocommerce ul.products.columns-5 li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist,
.woocommerce ul.products.columns-6 li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist,
.woocommerce ul.products.columns-6 li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist,
.woocommerce ul.products.columns-7 li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist,
.woocommerce ul.products.columns-7 li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist,
.woocommerce ul.products.columns-8 li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist,
.woocommerce ul.products.columns-8 li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist {
  margin-left: 0;
}

.woocommerce.yith-wcwl-form .wishlist-title > h2 {
  margin: 0;
}
.woocommerce.yith-wcwl-form .hidden-title-form a.hide-title-form {
  vertical-align: top;
}
.woocommerce.yith-wcwl-form table.wishlist_table {
  font-size: 1em;
}
.woocommerce.yith-wcwl-form table.wishlist_table td.product-add-to-cart a {
  display: inline-block !important;
}
.woocommerce.yith-wcwl-form .yith_wcwl_wishlist_footer .yith-wcwl-share {
  margin: 0;
  float: none;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.woocommerce.yith-wcwl-form .yith_wcwl_wishlist_footer .yith-wcwl-share h4.yith-wcwl-share-title {
  font-size: 1em;
  margin-right: 1em;
}
.woocommerce.yith-wcwl-form .yith_wcwl_wishlist_footer .yith-wcwl-share li a {
  min-width: 0;
  min-height: 0;
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
}
.woocommerce.yith-wcwl-form .yith_wcwl_wishlist_footer .yith-wcwl-share li a:hover {
  color: var(--theme-color-alter_link);
  background-color: var(--theme-color-alter_bg_hover);
}

/* Product meta */
.woocommerce div.product .product_meta {
  clear: both;
}

/* Tabs */
.woocommerce div.product .woocommerce-tabs ul.tabs, .woocommerce #content div.product .woocommerce-tabs ul.tabs, .woocommerce-page div.product .woocommerce-tabs ul.tabs, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs {
  padding-left: 0;
  margin: 0 0 55px;
}
.woocommerce div.product .woocommerce-tabs ul.tabs:before, .woocommerce #content div.product .woocommerce-tabs ul.tabs:before, .woocommerce-page div.product .woocommerce-tabs ul.tabs:before, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs:before {
  border-width: 0;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li,
.woocommerce #content div.product .woocommerce-tabs ul.tabs li,
.woocommerce-page div.product .woocommerce-tabs ul.tabs li,
.woocommerce-page #content div.product .woocommerce-tabs ul.tabs li {
  background: transparent;
  border: none;
  padding: 3px 6px;
  margin: 0 -6px;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li.active,
.woocommerce #content div.product .woocommerce-tabs ul.tabs li.active,
.woocommerce-page div.product .woocommerce-tabs ul.tabs li.active,
.woocommerce-page #content div.product .woocommerce-tabs ul.tabs li.active {
  background: transparent;
  border: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li:before, .woocommerce #content div.product .woocommerce-tabs ul.tabs li:before, .woocommerce-page div.product .woocommerce-tabs ul.tabs li:before, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs li:before,
.woocommerce div.product .woocommerce-tabs ul.tabs li:after, .woocommerce #content div.product .woocommerce-tabs ul.tabs li:after, .woocommerce-page div.product .woocommerce-tabs ul.tabs li:after, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs li:after {
  display: none;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li.active a, .woocommerce #content div.product .woocommerce-tabs ul.tabs li.active a, .woocommerce-page div.product .woocommerce-tabs ul.tabs li.active a, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs li.active a {
  text-shadow: inherit;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li a, .woocommerce #content div.product .woocommerce-tabs ul.tabs li a, .woocommerce-page div.product .woocommerce-tabs ul.tabs li a, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs li a {
  font-weight: 700;
  padding: 21px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  min-width: 278px;
  font-size: 13px;
  line-height: 16px;
  text-transform: uppercase;
  letter-spacing: 1px;
  border-top: 2px solid transparent;
  text-align: center;
}

.woocommerce div.product .woocommerce-tabs .panel, .woocommerce #content div.product .woocommerce-tabs .panel, .woocommerce-page div.product .woocommerce-tabs .panel, .woocommerce-page #content div.product .woocommerce-tabs .panel {
  border: none;
  margin: 0;
  padding: 0;
  display: none;
}

.woocommerce div.product .woocommerce-tabs h2, .woocommerce #content div.product .woocommerce-tabs h2, .woocommerce-page div.product .woocommerce-tabs h2, .woocommerce-page #content div.product .woocommerce-tabs h2 {
  margin: 0 0 1em;
  font-size: 25px;
  font-weight: 700;
  line-height: 1.2em;
  letter-spacing: 0;
}

.woocommerce div.product .woocommerce-tabs h3, .woocommerce #content div.product .woocommerce-tabs h3, .woocommerce-page div.product .woocommerce-tabs h3, .woocommerce-page #content div.product .woocommerce-tabs h3 {
  font-size: 1.5385em;
  margin-bottom: 0.25em !important;
  letter-spacing: 1px;
}

.woocommerce div.product .woocommerce-tabs p, .woocommerce #content div.product .woocommerce-tabs p, .woocommerce-page div.product .woocommerce-tabs p, .woocommerce-page #content div.product .woocommerce-tabs p {
  margin: 0;
}
.woocommerce div.product .woocommerce-tabs p + p, .woocommerce #content div.product .woocommerce-tabs p + p, .woocommerce-page div.product .woocommerce-tabs p + p, .woocommerce-page #content div.product .woocommerce-tabs p + p {
  margin-top: 0.5em;
}

.woocommerce div.product .woocommerce-tabs #tab-description h2 {
  display: none;
}

/* Additional attributes */
.woocommerce table.shop_attributes {
  border-style: solid;
  border-color: var(--theme-color-bd_color);
}
.woocommerce table.shop_attributes th, .woocommerce table.shop_attributes td {
  font-weight: 400;
  text-align: left;
  font-size: 15px;
  border-style: solid;
  border-color: var(--theme-color-bd_color);
}

.woocommerce table.shop_attributes tr:nth-child(2n+1) > * {
  background-color: var(--theme-color-alter_bg_color_04);
}

.woocommerce table.shop_attributes tr:nth-child(2n) > *,
.woocommerce table.shop_attributes tr.alt > * {
  background-color: var(--theme-color-alter_bg_color_02);
}

.woocommerce table.shop_attributes th {
  font-size: 16px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
}

/* Stars */
.woocommerce div.product .woocommerce-product-rating, .woocommerce-page div.product .woocommerce-product-rating {
  float: right;
  margin: 0;
}
.woocommerce div.product .woocommerce-product-rating .star-rating, .woocommerce-page div.product .woocommerce-product-rating .star-rating {
  margin-top: 8px;
  margin-bottom: 8px;
}

.woocommerce .woocommerce-product-rating .woocommerce-review-link, .woocommerce-page .woocommerce-product-rating .woocommerce-review-link {
  display: none;
}

.woocommerce .woocommerce-product-rating .star-rating,
.woocommerce-page .woocommerce-product-rating .star-rating {
  margin-top: 10px;
  margin-bottom: 4px;
  margin-right: 0;
}

.woocommerce .star-rating,
.woocommerce-page .star-rating {
  width: 88px;
  height: 1.2em;
  margin-top: 4px;
  margin-bottom: 4px;
  font-size: 14px;
  letter-spacing: 4px;
}

/* Users reviews */
.woocommerce #reviews {
  display: block;
  margin-left: calc( -1 * var(--theme-var-grid_gap) / 2 );
  margin-right: calc( -1 * var(--theme-var-grid_gap) / 2 );
  overflow: visible;
}

.woocommerce #reviews #comments,
.woocommerce #comments + #review_form_wrapper {
  float: left;
  width: 50%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  padding-left: calc( var(--theme-var-grid_gap) / 2 );
  padding-right: calc( var(--theme-var-grid_gap) / 2 );
}

.woocommerce #reviews #comments ol.commentlist {
  padding: 0;
  font-style: inherit;
  font-weight: inherit;
}

.woocommerce #reviews #comments ol.commentlist ul.children {
  padding: 0;
  margin: 0 0 0 4em;
}

.woocommerce #reviews #comments ol.commentlist li {
  margin-bottom: 0;
}

.woocommerce #reviews #comments ol.commentlist li + li,
.woocommerce #reviews #comments ol.commentlist ul.children {
  padding-top: 1.5em;
  margin-top: 1.5em;
  border-top: 1px solid var(--theme-color-bd_color);
}

.woocommerce .woocommerce-tabs .form-submit {
  display: block;
}

.woocommerce #reviews #comments ol.commentlist li img.avatar,
.woocommerce-page #reviews #comments ol.commentlist li img.avatar {
  background: none;
  border: none;
  padding: 0;
  position: static;
  width: 60px;
  float: left;
  margin: 0 20px 10px 0;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}

.woocommerce #reviews #comments ol.commentlist li .comment-text,
.woocommerce-page #reviews #comments ol.commentlist li .comment-text {
  margin: 0;
  padding: 0 0 24px;
  border: 0;
  position: relative;
  overflow: hidden;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text .star-rating,
.woocommerce-page #reviews #comments ol.commentlist li .comment-text .star-rating {
  position: absolute;
  left: 0;
  bottom: 0;
  margin-bottom: 0;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text .description,
.woocommerce-page #reviews #comments ol.commentlist li .comment-text .description {
  font-size: 15px;
}

.woocommerce #reviews #comments ol.commentlist li .comment-text p, .woocommerce-page #reviews #comments ol.commentlist li .comment-text p {
  margin: 0;
}

.woocommerce #reviews #comments ol.commentlist li .comment-text p + p, .woocommerce-page #reviews #comments ol.commentlist li .comment-text p + p {
  margin-top: 0.3em;
}

.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta, .woocommerce-page #reviews #comments ol.commentlist li .comment-text p.meta {
  margin: -2px 10px 4px 0;
  display: inline-block;
  vertical-align: middle;
  color: var(--theme-color-alter_text);
  font-size: 12px;
  line-height: 20px;
  font-weight: 400;
}

.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta strong, .woocommerce-page #reviews #comments ol.commentlist li .comment-text p.meta strong {
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 23px;
  font-weight: 700;
}

.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta time, .woocommerce-page #reviews #comments ol.commentlist li .comment-text p.meta time {
  font-style: normal;
  letter-spacing: 0;
}

.woocommerce .comment-form .comment-form-comment label,
.woocommerce .comment-form .comment-form-rating label,
.woocommerce .comment-form .comment-form-author label,
.woocommerce .comment-form .comment-form-email label {
  display: block;
  font-weight: 700;
  font-size: 1em;
  color: var(--theme-color-text_dark);
}

.woocommerce #review_form #respond .form-submit {
  margin-bottom: 0;
}

.woocommerce #review_form #respond input[type="text"],
.woocommerce #review_form #respond input[type="number"],
.woocommerce #review_form #respond input[type="email"],
.woocommerce #review_form #respond textarea,
.woocommerce-page #review_form #respond input[type="text"],
.woocommerce-page #review_form #respond input[type="number"],
.woocommerce-page #review_form #respond input[type="email"],
.woocommerce-page #review_form #respond textarea {
  width: 100%;
  -webkit-box-shadow: 0 15px 15px -14px rgba(0, 0, 0, 0.018);
  -ms-box-shadow: 0 15px 15px -14px rgba(0, 0, 0, 0.018);
  box-shadow: 0 15px 15px -14px rgba(0, 0, 0, 0.018);
}

.woocommerce #review_form #respond textarea, .woocommerce-page #review_form #respond textarea {
  height: 6em;
  min-height: 5em;
  overflow: auto;
}

.woocommerce #review_form #respond #reply-title {
  font-size: 25px;
  line-height: 1.2em;
  font-weight: 700;
  letter-spacing: 0;
  margin-bottom: 0.8em;
  display: inline-block;
  color: var(--theme-color-text_dark);
}

.woocommerce .comment-form .comment-form-rating,
.woocommerce #review_form #respond p {
  margin: 0 0 1.4em;
}

.woocommerce #review_form #respond .form-submit {
  margin-top: 40px;
}

.woocommerce #review_form #respond p.comment-form-rating,
.woocommerce #review_form #respond p.comment-form-rating .stars {
  margin-bottom: 0;
}

.woocommerce #review_form #respond p.stars {
  margin-bottom: 0;
  margin-top: 7px;
}

.woocommerce .comment-form .comment-form-author label,
.woocommerce .comment-form .comment-form-email label {
  display: block;
}

/* Related products */
.single-product .related,
.single-product .upsells {
  margin-top: 4.4em;
  clear: both;
}
.single-product .related ul.products,
.single-product .upsells ul.products {
  margin-bottom: -25px;
}

.single-product .related h2,
.single-product .upsells h2 {
  margin-bottom: 55px;
  text-align: left;
  margin-top: 0;
  margin-left: -1px;
}

.single-product ul.products li.product .post_item {
  padding: 0;
  position: relative;
}
.single-product ul.products li.product .post_item .price *,
.single-product ul.products li.product .post_item .price {
  color: var(--theme-color-alter_text);
}

.single-product .footer_copyright_wrap {
  outline: none;
}

.single-product .footer_logo_wrap + .footer_copyright_wrap,
.single-product .footer_socials_wrap + .footer_copyright_wrap,
.single-product .footer_menu_wrap + .footer_copyright_wrap {
  margin-top: 0;
}

.woocommerce .related ul li.product, .woocommerce .related ul.products li.product, .woocommerce .upsells.products ul li.product, .woocommerce .upsells.products ul.products li.product, .woocommerce-page .related ul li.product, .woocommerce-page .related ul.products li.product, .woocommerce-page .upsells.products ul li.product, .woocommerce-page .upsells.products ul.products li.product {
  border: none;
  box-shadow: none;
}

/* Cross-sells */
.woocommerce .cart-collaterals,
.woocommerce-page .cart-collaterals {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
}
.woocommerce .cart-collaterals .cross-sells,
.woocommerce-page .cart-collaterals .cross-sells {
  order: 2;
  float: none;
  width: 100%;
}
.woocommerce .cart-collaterals .cart_totals,
.woocommerce-page .cart-collaterals .cart_totals {
  order: 1;
  float: none;
}

/* Group Table */
.woocommerce div.product form.cart .group_table td.woocommerce-grouped-product-list-item__label a,
.woocommerce-page div.product form.cart .group_table td.woocommerce-grouped-product-list-item__label a {
  font-weight: 500;
}

.woocommerce div.product form.cart .group_table td.woocommerce-grouped-product-list-item__price span.amount,
.woocommerce-page div.product form.cart .group_table td.woocommerce-grouped-product-list-item__price span.amount {
  font-weight: 400;
}

/* Widgets decoration
---------------------------------------------------------------*/
/* Cart & Products list */
.woocommerce a.remove {
  margin-top: 0.5em;
  text-align: center;
  position: relative;
  overflow: hidden;
  width: 1.2em;
  height: 1.2em;
  line-height: 1.2em;
  text-indent: -100px;
  font-size: 9px !important;
  font-weight: 400 !important;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.woocommerce a.remove:before {
  display: none !important;
}
.woocommerce a.remove:after {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1;
  content: '\e9e1';
  font-family: "fontello";
  line-height: inherit;
  text-align: center;
  border: none;
  text-indent: 0;
  width: 100%;
  height: 100%;
  color: var(--theme-color-alter_light);
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.woocommerce a.remove:hover:after {
  color: var(--theme-color-text_link);
}

.woocommerce a.remove,
.woocommerce a.remove:hover {
  color: #e05100 !important;
  background-color: transparent !important;
}

.woocommerce table.shop_table {
  border-collapse: collapse;
  margin-bottom: 2em;
  border: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.woocommerce table.shop_table td {
  border-color: var(--theme-color-bd_color) !important;
  background: transparent;
}

.woocommerce table.shop_table th {
  border-color: var(--theme-color-alter_bg_color) !important;
  background-color: var(--theme-color-alter_bg_color) !important;
}

.woocommerce table.shop_table tfoot th,
.woocommerce-page table.shop_table tfoot th {
  color: var(--theme-color-text_dark);
  border-color: transparent !important;
  background-color: transparent;
}

.woocommerce table.shop_table tr:first-child th {
  border-style: solid;
  border-width: 0 0 1px 0 !important;
}

.woocommerce table.shop_table tr:nth-child(n+1) th:first-child,
.woocommerce table.shop_table tr:nth-child(n+1) td:first-child,
.woocommerce table.shop_table td {
  border-style: solid;
  border-width: 1px 0;
}

.woocommerce table.account-orders-table.shop_table tbody tr:first-child td:first-child {
  border-top: 1px solid;
}

.woocommerce table.account-orders-table.shop_table tr:nth-child(n+1) th:first-child,
.woocommerce table.account-orders-table.shop_table tr:nth-child(n+1) td:first-child,
.woocommerce table.account-orders-table.shop_table td {
  border-width: 1px 0;
}

.woocommerce .shop_table p {
  margin: 0;
}

.woocommerce .shop_table a.remove {
  margin: 0;
  font-weight: 400;
}

.woocommerce ul.product_list_widget li,
.woocommerce-page ul.product_list_widget li {
  padding: 10px 0 1em;
  overflow: hidden;
}

.woocommerce.widget_shopping_cart ul.cart_list li {
  padding: 10px 0 20px 0;
  overflow: hidden;
}

.woocommerce ul.cart_list li dl:after,
.woocommerce ul.product_list_widget li dl:after {
  clear: none;
}

.woocommerce ul.cart_list li:before,
.woocommerce-page ul.cart_list li:before,
.woocommerce ul.product_list_widget li:before,
.woocommerce-page ul.product_list_widget li:before {
  display: none;
}

ul.cart_list li > b {
  color: var(--theme-color-text_dark);
}

.woocommerce ul.cart_list li > b,
.woocommerce ul.cart_list li a,
.woocommerce-page ul.cart_list li a,
.woocommerce ul.product_list_widget li a,
.woocommerce-page ul.product_list_widget li a {
  font-weight: 700;
  font-size: 17px;
}

.woocommerce .widget_shopping_cart .cart_list li a.remove,
.woocommerce.widget_shopping_cart .cart_list li a.remove {
  position: absolute;
  right: 0;
  top: 0;
  left: auto;
  margin: 0 !important;
}

.woocommerce ul.cart_list li,
.woocommerce-page ul.cart_list li,
.woocommerce ul.product_list_widget li,
.woocommerce-page ul.product_list_widget li {
  padding-top: 10px;
}

.woocommerce ul.cart_list li img,
.woocommerce-page ul.cart_list li img,
.woocommerce ul.product_list_widget li img,
.woocommerce-page ul.product_list_widget li img {
  float: left;
  margin: -10px 20px 10px 0;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  width: 81px;
  height: 81px;
  object-fit: cover;
}

.woocommerce ul.cart_list li img,
.woocommerce-page ul.cart_list li img {
  margin-right: 20px;
}

.woocommerce ul.cart_list li dl,
.woocommerce-page ul.cart_list li dl,
.woocommerce ul.product_list_widget li dl,
.woocommerce-page ul.product_list_widget li dl {
  overflow: hidden;
  font-size: 14px;
  line-height: 1.5em;
  font-weight: var(--theme-font-p_font-weight);
  margin-top: 4px;
  padding-left: 8px;
  border-left-width: 1px;
  border-color: var(--theme-color-bd_color);
}

.woocommerce ul.cart_list li dl dd,
.woocommerce ul.cart_list li dl dt,
.woocommerce ul.product_list_widget li dl dd,
.woocommerce ul.product_list_widget li dl dt {
  padding: 0;
  margin: 0;
}

.woocommerce ul.product_list_widget li dl dt,
.woocommerce-page ul.product_list_widget li dl dt {
  margin-right: 0.3em;
  font-weight: var(--theme-font-p_font-weight);
}

.woocommerce ul.product_list_widget li dl dt:before,
.woocommerce-page ul.product_list_widget li dl dt:before {
  content: ' ';
  display: block;
  width: 100%;
  height: 0;
}

.woocommerce ul.cart_list li dl dd,
.woocommerce-page ul.cart_list li dl dd,
.woocommerce ul.product_list_widget li dl dd,
.woocommerce-page ul.product_list_widget li dl dd {
  margin-right: 2em;
}

.woocommerce.widget_shopping_cart .quantity,
.woocommerce-page.widget_shopping_cart .quantity,
.woocommerce .widget_shopping_cart .quantity,
.woocommerce-page .widget_shopping_cart .quantity {
  margin: 3px 0 0;
  display: inline-block;
  font-size: 18px;
  font-weight: 500;
}

.woocommerce .quantity input.qty,
.woocommerce-page .quantity input.qty,
.woocommerce #content .quantity input.qty,
.woocommerce-page #content .quantity input.qty {
  color: var(--theme-color-input_dark);
}

.woocommerce ul.cart_list li > .amount,
.woocommerce-page ul.cart_list li > .amount,
.woocommerce ul.product_list_widget li > .amount,
.woocommerce-page ul.product_list_widget li > .amount,
.woocommerce ul.cart_list li span .amount,
.woocommerce-page ul.cart_list li span .amount,
.woocommerce ul.product_list_widget li span .amount,
.woocommerce-page ul.product_list_widget li span .amount,
.woocommerce ul.cart_list li ins .amount,
.woocommerce-page ul.cart_list li ins .amount,
.woocommerce ul.product_list_widget li ins .amount,
.woocommerce-page ul.product_list_widget li ins .amount,
.woocommerce ul.cart_list li del,
.woocommerce-page ul.cart_list li del,
.woocommerce ul.product_list_widget li del,
.woocommerce-page ul.product_list_widget li del {
  font-size: 18px;
  font-weight: 500;
}

footer .product_list_widget li a + span.amount {
  margin-top: 10px;
  display: inline-block;
}

.woocommerce ul.cart_list li ins,
.woocommerce-page ul.cart_list li ins,
.woocommerce ul.product_list_widget li ins,
.woocommerce-page ul.product_list_widget li ins {
  text-decoration: none;
  font-style: normal;
}

.woocommerce ul.cart_list li .star-rating,
.woocommerce ul.product_list_widget li .star-rating {
  margin-bottom: 0;
}

.woocommerce .widget_shopping_cart .total, .woocommerce.widget_shopping_cart .total {
  border: none;
}

.woocommerce.widget_shopping_cart .total,
.woocommerce-page.widget_shopping_cart .total,
.woocommerce .widget_shopping_cart .total,
.woocommerce-page .widget_shopping_cart .total {
  font-size: 19px;
  font-weight: 700;
  padding: 4px 0 0;
  color: var(--theme-color-text_dark);
}
.woocommerce.widget_shopping_cart .total strong,
.woocommerce-page.widget_shopping_cart .total strong,
.woocommerce .widget_shopping_cart .total strong,
.woocommerce-page .widget_shopping_cart .total strong {
  font-weight: 700;
}

.woocommerce.widget_shopping_cart .total .amount,
.woocommerce-page.widget_shopping_cart .total .amount,
.woocommerce .widget_shopping_cart .total .amount,
.woocommerce-page .widget_shopping_cart .total .amount {
  font-size: 19px;
  font-weight: 700;
  color: var(--theme-color-text_link);
}

.woocommerce .widget_shopping_cart .buttons,
.woocommerce.widget_shopping_cart .buttons {
  margin-top: 33px;
}

.woocommerce .widget_shopping_cart .buttons a,
.woocommerce.widget_shopping_cart .buttons a {
  margin-right: 10px;
  margin-bottom: 10px;
  width: calc(50% - 5px);
  font-size: 15px;
  line-height: 18px;
  padding: 15px;
  text-align: center;
  display: inline-block;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.woocommerce .widget_shopping_cart .buttons a + a,
.woocommerce.widget_shopping_cart .buttons a + a {
  margin-left: 0 !important;
  margin-right: 0 !important;
}
.woocommerce .widget_shopping_cart .buttons a.checkout,
.woocommerce.widget_shopping_cart .buttons a.checkout {
  border: 2px solid var(--theme-color-text_dark) !important;
  color: var(--theme-color-text_dark) !important;
  background: none !important;
  -webkit-box-shadow: none !important;
  -ms-box-shadow: none !important;
  box-shadow: none !important;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  padding: 13px;
}
.woocommerce .widget_shopping_cart .buttons a.checkout:hover,
.woocommerce.widget_shopping_cart .buttons a.checkout:hover {
  border: 2px solid var(--theme-color-text_link) !important;
  color: var(--theme-color-text_link) !important;
}

/* Active filters */
.woocommerce .widget_layered_nav_filters > ul > li {
  padding: 0 0.625em 0.5em 0;
  display: block;
}

.woocommerce .widget_layered_nav_filters > ul > li:before {
  display: none;
}

.woocommerce .widget_layered_nav ul {
  padding-left: 1.2em;
}

.woocommerce .widget_layered_nav_filters > ul > li a,
.woocommerce .widget_layered_nav ul li.chosen a,
.woocommerce-page .widget_layered_nav ul li.chosen a {
  background-color: transparent;
  border: none;
  padding: 0;
}

.widget_layered_nav ul li.chosen a {
  color: var(--theme-color-text_dark);
}

/* Average Rating */
.woocommerce .widget_rating_filter ul li .star-rating {
  vertical-align: middle;
}

/* Price filter */
.woocommerce .widget_price_filter .ui-slider .ui-slider-range,
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
  background-color: var(--theme-color-text_link3);
}

.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
  margin-bottom: 13px;
  margin-left: 0;
  margin-right: 0;
  height: 6px;
  background: var(--theme-color-alter_bg_hover);
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  width: 12px;
  height: 12px;
  margin-left: -6px;
  top: -3px;
  opacity: 0;
}

.woocommerce .widget_price_filter .ui-slider-horizontal .ui-slider-range {
  height: 6px;
  top: 0;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.woocommerce .widget_price_filter .price_slider_amount {
  font-size: 16px;
  line-height: 1.5em;
  text-align: left;
  font-weight: 400;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column-reverse;
  align-items: flex-start;
}
.woocommerce .widget_price_filter .price_slider_amount .price_label {
  color: var(--theme-color-text_light);
}

.woocommerce .widget_price_filter .price_slider_amount span {
  font-weight: 400;
}

.widget_price_filter .price_label span {
  color: var(--theme-color-text_light);
}

.woocommerce .widget_price_filter .price_slider_amount .button {
  float: none;
  position: relative;
  margin-top: 23px;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.woocommerce .widget_price_filter .price_slider_amount .button:after {
  content: '\e908';
  font-family: "fontello";
  font-weight: 400;
  display: inline-block;
  margin: 0 -5px 0 26px;
}

/* Product search */
/* This widget's styles see in the style.css in the section 'Widget: Search' */
.widget_product_search form:after {
  color: var(--theme-color-input_light);
}

.widget_product_search form:hover:after {
  color: var(--theme-color-input_dark);
}

/* Rating filter */
.woocommerce.widget_rating_filter ul li:before {
  display: none !important;
}

/* Product title in widgets */
aside.woocommerce .product-title,
aside.woocommerce .mini_cart_item > a:not(.remove) {
  display: block;
  line-height: 1.3em;
}

/* Results */
.search-no-results.woocommerce .woocommerce-message:last-child,
.search-no-results.woocommerce .woocommerce-info:last-child, .search-no-results.woocommerce-page .woocommerce-message:last-child,
.search-no-results.woocommerce-page .woocommerce-info:last-child {
  margin: 0;
  padding: 20px;
}

/* Currency Switcher */
.widget.WOOCS_CONVERTER .woocs_converter_shortcode > * {
  vertical-align: middle;
}

.widget.WOOCS_CONVERTER .woocs_converter_shortcode .select_container {
  display: inline-block;
  width: 43%;
  margin-right: 0.3em;
}

.widget.WOOCS_CONVERTER .woocs_converter_shortcode .select_container + .select_container {
  margin-left: 0.3em;
  margin-right: 0;
}

.widget.WOOCS_CONVERTER .button {
  margin-top: 1em;
}

.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container-single .chosen-single {
  height: auto;
  padding: 1em 0 1em 1em;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  color: var(--theme-color-input_text);
  background: var(--theme-color-input_bg_color);
}

.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container-single .chosen-single:hover {
  color: var(--theme-color-input_dark);
  background: var(--theme-color-input_bg_hover);
}

.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container-single .chosen-single div {
  background: none;
}

.widget.WOOCS_SELECTOR .chosen-container-single .chosen-drop {
  margin-top: 1px;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  -webkit-border-radius: 4px;
  -ms-border-radius: 4px;
  border-radius: 4px;
}

.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container .chosen-drop {
  color: var(--theme-color-input_dark);
  background: var(--theme-color-input_bg_hover);
  border-color: var(--theme-color-input_bd_hover);
}

.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container .chosen-results li {
  background-position: right center !important;
  color: var(--theme-color-input_dark);
}

.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container .chosen-results li:hover,
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container .chosen-results li.highlighted,
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container .chosen-results li.result-selected {
  color: var(--theme-color-alter_link) !important;
}

/* YITH Second image */
.yith_magnifier_zoom_wrap .yith_magnifier_zoom_magnifier {
  border-color: var(--theme-color-bd_color);
}

/* YITH Compare */
.yith-woocompare-widget ul.products-list {
  padding-left: 0;
}

.yith-woocompare-widget ul.products-list li:before {
  display: none;
}

.yith-woocompare-widget ul.products-list li .remove {
  margin-top: 0;
}

.yith-woocompare-widget a.compare {
  float: left;
}

.yith-woocompare-widget a.clear-all {
  display: inline-block;
  float: right;
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-alter_link);
}

.yith-woocompare-widget a.clear-all:hover {
  color: var(--theme-color-inverse_hover);
  background-color: var(--theme-color-alter_hover);
}

/* Cart
--------------------------------------------------------------------- */
.woocommerce .woocommerce-cart-form table.shop_table_responsive tr.woocommerce-cart-form__cart-item td {
  vertical-align: middle;
}

div.product form.cart div.quantity > label {
  outline: none;
}

.woocommerce .quantity input.qty, .woocommerce #content .quantity input.qty, .woocommerce-page .quantity input.qty, .woocommerce-page #content .quantity input.qty {
  font-weight: 400;
  padding-left: 0.75em;
  padding-right: 0;
  width: 4em;
  font-size: 0.8421em;
  line-height: 1em;
}

#add_payment_method table.cart img, .woocommerce-cart table.cart img, .woocommerce-checkout table.cart img {
  width: 40px;
}

.woocommerce table.cart .product-name, .woocommerce #content table.cart .product-name, .woocommerce-page table.cart .product-name, .woocommerce-page #content table.cart .product-name {
  text-align: left !important;
}

.woocommerce table.cart th, .woocommerce #content table.cart th, .woocommerce-page table.cart th, .woocommerce-page #content table.cart th {
  font-size: 17px;
  line-height: 1.3em;
  font-weight: 700;
  color: var(--theme-color-text_dark);
}

.woocommerce table.cart th, .woocommerce #content table.cart th, .woocommerce-page table.cart th, .woocommerce-page #content table.cart th,
.woocommerce table.cart td, .woocommerce #content table.cart td, .woocommerce-page table.cart td, .woocommerce-page #content table.cart td {
  padding: 12px;
  text-align: left;
}

.woocommerce table.cart td.actions,
.woocommerce-page table.cart td.actions,
.woocommerce #content table.cart td.actions,
.woocommerce-page #content table.cart td.actions {
  border-bottom: none !important;
  padding-top: 1em;
}

.woocommerce table.cart td.actions .coupon .input-text,
.woocommerce-page table.cart td.actions .coupon .input-text,
.woocommerce #content table.cart td.actions .coupon .input-text,
.woocommerce-page #content table.cart td.actions .coupon .input-text {
  width: 10.7em;
  margin-right: 0.3em;
}

.woocommerce table.cart td.actions .coupon + .button,
.woocommerce-page table.cart td.actions .coupon + .button,
.woocommerce #content table.cart td.actions .coupon + .button,
.woocommerce-page #content table.cart td.actions .coupon + .button {
  float: right;
}

.woocommerce table.shop_table tfoot th,
.woocommerce-page table.shop_table tfoot th {
  text-align: center;
}

.woocommerce .cart-collaterals h2,
.woocommerce-page .cart-collaterals h2 {
  font-size: 24px;
  line-height: 1.3em;
  font-weight: 700;
  margin: 2.2em 0 1em;
}

.woocommerce table.shop_table .cart-subtotal .amount, .woocommerce-page table.shop_table .cart-subtotal .amount,
.woocommerce table.shop_table .shipping td, .woocommerce-page table.shop_table .shipping td {
  color: var(--theme-color-text_dark);
}

.woocommerce table.cart td + td a,
.woocommerce-page table.cart td + td a,
.woocommerce #content table.cart td + td a,
.woocommerce-page #content table.cart td + td a,
.woocommerce table.cart td + td span,
.woocommerce-page table.cart td + td span,
.woocommerce #content table.cart td + td span,
.woocommerce-page #content table.cart td + td span {
  color: var(--theme-color-text_dark);
}

.woocommerce table.cart td + td a:hover,
.woocommerce-page table.cart td + td a:hover,
.woocommerce #content table.cart td + td a:hover,
.woocommerce-page #content table.cart td + td a:hover {
  color: var(--theme-color-text_link);
}

#add_payment_method table.cart td.actions .coupon .input-text,
.woocommerce-cart table.cart td.actions .coupon .input-text,
.woocommerce-checkout table.cart td.actions .coupon .input-text {
  border-color: var(--theme-color-input_bd_color);
}

.woocommerce table.cart td.actions .input-text, .woocommerce-page table.cart td.actions .input-text {
  width: 100px;
}

.woocommerce ul#shipping_method li {
  padding-left: 0;
  text-indent: 0;
  margin: 0.1em 0;
}

.woocommerce .cart-collaterals .woocommerce-shipping-calculator .shipping-calculator-form,
.woocommerce-page .cart-collaterals .woocommerce-shipping-calculator .shipping-calculator-form {
  margin: 1em 0;
}

.woocommerce .cart-collaterals .shipping_calculator .shipping-calculator-button:after,
.woocommerce-page .cart-collaterals .shipping_calculator .shipping-calculator-button:after {
  font-size: 1em;
  font-weight: 400;
}

#add_payment_method .wc-proceed-to-checkout a.checkout-button,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button {
  display: block;
}

.woocommerce-shipping-calculator .select2-container.select2-container--default .select2-selection .select2-selection__arrow {
  display: none;
}

.woocommerce-shipping-calculator .select_container:before {
  top: 2px;
  right: 2px;
  bottom: 2px;
}

/* Scrollbar decoration */
.sc_layouts_cart_widget ul.product_list_widget {
  overflow-x: hidden;
  overflow-y: auto;
  scrollbar-width: thin;
}
.sc_layouts_cart_widget ul.product_list_widget::-webkit-scrollbar {
  width: 6px;
}
.sc_layouts_cart_widget ul.product_list_widget::-webkit-scrollbar-track {
  background: var(--theme-color-alter_dark);
}
.sc_layouts_cart_widget ul.product_list_widget::-webkit-scrollbar-thumb {
  background-color: var(--theme-color-alter_bd_color);
}

/* Login */
.woocommerce-form-login p:not([class]) {
  text-align: left;
}
.woocommerce-form-login .form-row {
  margin-bottom: 25px !important;
  text-align: left;
}
.woocommerce-form-login .form-row .woocommerce-form-login__rememberme {
  display: block;
}
.woocommerce-form-login .lost_password {
  text-align: left;
  font-size: 16px;
}

.woocommerce-checkout .woocommerce-form-login {
  max-width: 70%;
  margin-left: auto;
  margin-right: auto;
}

/* Checkout
--------------------------------------------------------------------------*/
.woocommerce form .form-row {
  padding: 0;
  margin-bottom: 47px;
}

.woocommerce form .form-row label, .woocommerce-page form .form-row label {
  line-height: 1.5em;
  font-size: 16px;
  font-weight: 700;
  margin-bottom: 15px;
  color: var(--theme-color-text_dark);
}

.woocommerce form .form-row label.inline {
  margin-left: 1em;
}

.woocommerce form .form-row input.input-text, .woocommerce form .form-row textarea {
  line-height: 1.4855em;
  -webkit-box-shadow: 0 15px 15px -14px rgba(0, 0, 0, 0.018);
  -ms-box-shadow: 0 15px 15px -14px rgba(0, 0, 0, 0.018);
  box-shadow: 0 15px 15px -14px rgba(0, 0, 0, 0.018);
}

#commentform input.input-text,
#commentform textarea,
.woocommerce .select2-selection {
  -webkit-box-shadow: 0 15px 15px -14px rgba(0, 0, 0, 0.018);
  -ms-box-shadow: 0 15px 15px -14px rgba(0, 0, 0, 0.018);
  box-shadow: 0 15px 15px -14px rgba(0, 0, 0, 0.018);
}

.woocommerce-checkout.checkout h3 {
  margin-bottom: 38px;
  margin-top: 0;
}

.woocommerce .checkout input[type="checkbox"] {
  display: inline;
  position: static !important;
  clip: auto;
}

.woocommerce .checkout .col-2 h3#ship-to-different-address label, .woocommerce-page .checkout .col-2 h3#ship-to-different-address label {
  display: inline-block;
}

.woocommerce form .form-row input.input-text, .woocommerce form .form-row textarea, .woocommerce-page form .form-row input.input-text, .woocommerce-page form .form-row textarea {
  font-weight: 400;
}

.woocommerce .checkout table.shop_table {
  margin-bottom: 3em;
}

.woocommerce .checkout table.shop_table th, .woocommerce .checkout table.shop_table td {
  text-align: left;
}

.woocommerce .checkout table.shop_table tfoot th {
  text-align: right;
}

.woocommerce .checkout table.shop_table tfoot td,
.woocommerce .checkout table.shop_table tfoot th {
  font-weight: 400;
}

.woocommerce table.shop_table .cart-subtotal .amount, .woocommerce-page table.shop_table .cart-subtotal .amount,
.woocommerce table.shop_table .shipping td, .woocommerce-page table.shop_table .shipping td {
  font-weight: 400;
}

.woocommerce .cart-collaterals .shipping_calculator, .woocommerce-page .cart-collaterals .shipping_calculator {
  clear: none;
  float: left;
  margin-bottom: 30px;
}

.woocommerce .checkout #order_review,
.woocommerce-page .checkout #order_review {
  margin-bottom: 3em;
}

.woocommerce .checkout #order_review .order-total .amount,
.woocommerce-page .checkout #order_review .order-total .amount {
  letter-spacing: 0;
}

.woocommerce .checkout #order_review .payment_methods li,
.woocommerce-page .checkout #order_review .payment_methods li {
  list-style: none;
}

.woocommerce .checkout #order_review .payment_methods li label,
.woocommerce-page .checkout #order_review .payment_methods li label {
  display: inline-block;
}

#add_payment_method #payment ul.payment_methods li img,
.woocommerce-checkout #payment ul.payment_methods li img {
  margin: -5px 0.5em 0;
  max-height: 30px;
}

#add_payment_method #payment div.payment_box:before,
.woocommerce-cart #payment div.payment_box:before,
.woocommerce-checkout #payment div.payment_box:before {
  border-color: transparent;
}

.woocommerce-checkout #payment div.payment_box:after {
  top: 0;
}

#add_payment_method #payment,
.woocommerce-cart #payment,
.woocommerce-checkout #payment {
  background-color: transparent;
}

#add_payment_method #payment .payment_method_paypal .about_paypal,
.woocommerce-cart #payment .payment_method_paypal .about_paypal,
.woocommerce-checkout #payment .payment_method_paypal .about_paypal {
  line-height: 1.7em;
  float: none;
}

.woocommerce ul.order_details {
  padding-left: 0;
}

.woocommerce .order_details.woocommerce-thankyou-order-details {
  padding: 25px;
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
  text-transform: none;
}
.woocommerce .order_details.woocommerce-thankyou-order-details .amount,
.woocommerce .order_details.woocommerce-thankyou-order-details .amount * {
  color: var(--theme-color-alter_dark);
}

.woocommerce .order_details.woocommerce-thankyou-order-details li strong {
  font-weight: 400;
  margin-top: 3px;
  line-height: 1.3em;
  color: var(--theme-color-alter_dark);
}

.woocommerce .shop_table.order_details th,
.woocommerce .shop_table.customer_details th {
  text-align: left;
}

.woocommerce .shop_table.order_details tfoot th {
  text-align: right;
}

.woocommerce .shop_table.order_details td.product-name strong {
  font-style: normal;
}

.woocommerce .order_details li,
.woocommerce-page .order_details li {
  font-size: 1em;
  line-height: 1em;
  list-style: none;
}

.woocommerce .order_details li strong,
.woocommerce-page .order_details li strong {
  color: var(--theme-color-text_dark);
}
.woocommerce .order_details li strong .amount,
.woocommerce-page .order_details li strong .amount {
  color: var(--theme-color-text_dark);
}

.woocommerce .woocommerce-customer-details address {
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.woocommerce form .form-row #createaccount {
  margin-right: 4px;
  vertical-align: middle;
}

.woocommerce form .form-row input[type="radio"] + label:before,
.woocommerce form .form-row input[type="checkbox"] + label:before {
  top: 10px;
}

.woocommerce form .woocommerce-checkout-payment .wpgdprc-checkbox label {
  position: relative;
  font-size: 14px;
  line-height: 22px !important;
  font-weight: 400;
  margin-bottom: 0;
  padding-left: 1.8em;
  display: inline-block;
  vertical-align: top;
  color: var(--theme-color-text);
}
.woocommerce form .woocommerce-checkout-payment .wpgdprc-checkbox label abbr.required {
  color: #FF5B4A !important;
}
.woocommerce form .woocommerce-checkout-payment .wpgdprc-checkbox.woocommerce-invalid label {
  color: var(--theme-color-text) !important;
}
.woocommerce form .woocommerce-checkout-payment .wpgdprc-checkbox.woocommerce-validated label {
  color: var(--theme-color-text_dark);
}

.woocommerce-form-login .woocommerce-form__input-checkbox,
.woocommerce-terms-and-conditions-wrapper .woocommerce-form__input-checkbox {
  display: inline;
}

.woocommerce-terms-and-conditions-wrapper p {
  margin-bottom: 0.5em;
}

.woocommerce-form-login label.woocommerce-form-login__rememberme,
.woocommerce-terms-and-conditions-wrapper label {
  padding-left: 1.15em;
  position: relative;
}

.woocommerce-form-login label.woocommerce-form-login__rememberme {
  margin-bottom: 20px;
  padding-left: 1.8em;
  position: relative;
  font-size: 14px !important;
  line-height: 22px !important;
  font-weight: 400 !important;
  color: var(--theme-color-text) !important;
}

.woocommerce-form-login label.woocommerce-form-login__rememberme input[type="checkbox"],
.woocommerce-terms-and-conditions-wrapper label input[type="checkbox"] {
  position: static !important;
  clip: auto;
  width: 0;
  outline: 0 !important;
  -webkit-appearance: none;
  -moz-appearance: none;
}

.woocommerce-form-login label.woocommerce-form-login__rememberme input[type="checkbox"]:before,
.woocommerce-terms-and-conditions-wrapper label input[type="checkbox"]:before {
  content: '';
  font-family: "fontello";
  display: block;
  text-align: center;
  border: 1px solid var(--theme-color-bd_color);
  font-size: 7px;
  width: 16px;
  height: 16px;
  line-height: 15px;
  position: absolute;
  z-index: 1;
  top: 0.45em;
  left: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 4px;
  -ms-border-radius: 4px;
  border-radius: 4px;
  color: var(--theme-color-text_dark);
  cursor: pointer;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.woocommerce-form-login label.woocommerce-form-login__rememberme:hover input[type="checkbox"]:before {
  border-color: var(--theme-color-text_dark) !important;
}

.woocommerce-form-login label.woocommerce-form-login__rememberme input[type="checkbox"]:checked:before,
.woocommerce-terms-and-conditions-wrapper label input[type="checkbox"]:checked:before {
  content: '\e9f6';
}

.ua_ie .woocommerce-form-login label.woocommerce-form-login__rememberme,
.ua_ie .woocommerce-terms-and-conditions-wrapper label {
  padding-left: 0;
}

.ua_ie .woocommerce-form-login input[type="checkbox"],
.ua_ie .woocommerce-terms-and-conditions-wrapper input[type="checkbox"] {
  width: auto;
}

.ua_ie .woocommerce-form-login input[type="checkbox"]:before,
.ua_ie .woocommerce-terms-and-conditions-wrapper input[type="checkbox"]:before {
  display: none;
}

/* My Account
--------------------------------------------------------------------------*/
.woocommerce form .form-row label.inline input[type="checkbox"] {
  display: inline;
  position: relative !important;
  clip: auto;
  top: 2px;
}

.woocommerce-account h2,
.woocommerce-account .address .title h3 {
  margin: 1em 0 0.4em;
}

.woocommerce-MyAccount-content .woocommerce-message,
.woocommerce-MyAccount-content .woocommerce-info {
  margin: 0 0 20px 0;
  text-align: left;
}

.woocommerce-MyAccount-navigation,
.woocommerce-MyAccount-content .woocommerce-Address-title a {
  font-size: 1em;
  line-height: 1.3em;
  font-weight: 500;
}

.woocommerce-account .woocommerce-MyAccount-navigation {
  width: 20%;
  float: left;
  border-color: var(--theme-color-bd_color);
}

.woocommerce-MyAccount-navigation ul {
  padding: 0;
  margin: 0;
  list-style-type: none;
}

.woocommerce-MyAccount-navigation ul li {
  padding: 0;
  margin: 0;
  border-color: var(--theme-color-bd_color);
}

.woocommerce-MyAccount-navigation ul li + li {
  border-top: 1px solid var(--theme-color-bd_color);
}

.woocommerce-MyAccount-navigation ul li a {
  display: block;
  padding: 1em 0;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}

.woocommerce-MyAccount-navigation ul li:first-child a {
  padding-top: 0.5em;
}

.woocommerce-MyAccount-navigation li.is-active a {
  color: var(--theme-color-text_link);
}

.woocommerce-account .addresses .title h3 {
  font-size: 1.2em;
  line-height: 1.1em;
  margin-bottom: 0.7em;
}

.woocommerce table.my_account_orders {
  font-size: 1em;
}

.woocommerce table.shop_table tfoot td,
.woocommerce table.shop_table tfoot th {
  font-weight: 400;
}

.woocommerce table.shop_table tfoot tr:last-child td {
  font-weight: 700;
}

.woocommerce-account .woocommerce-MyAccount-content {
  width: 75%;
  float: right;
}

.woocommerce-MyAccount-content .my_account_orders th {
  text-align: left;
}
.woocommerce-MyAccount-content .my_account_orders .button {
  padding: 0;
  background-color: transparent !important;
  color: var(--theme-color-text_link);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.woocommerce-MyAccount-content .my_account_orders .button + .button:before {
  content: '|';
  display: inline-block;
  line-height: inherit;
  margin: 0 0.5em;
}
.woocommerce-MyAccount-content .my_account_orders .button:hover,
.woocommerce-MyAccount-content .my_account_orders .button:focus {
  color: var(--theme-color-text_hover);
}
.woocommerce-MyAccount-content .woocommerce-Address-title {
  position: relative;
}
.woocommerce-MyAccount-content .woocommerce-Address-title h3 {
  display: inline-block;
  margin-top: 0.5em;
}
.woocommerce-MyAccount-content .woocommerce-Address-title a {
  margin: 0 0 0 5px;
  text-decoration: underline;
  font-size: 1em;
  line-height: 1.2em;
}
.woocommerce-MyAccount-content .woocommerce-EditAccountForm fieldset {
  padding: 1em 1.5em;
  border: 1px solid var(--theme-color-bd_color);
  margin: 2em 0;
}
.woocommerce-MyAccount-content .woocommerce-EditAccountForm fieldset legend {
  padding: 0 0.2em;
}

.woocommerce table.my_account_orders td, .woocommerce table.my_account_orders th {
  padding: 10px 8px;
}

.woocommerce table.my_account_orders th {
  font-weight: 500;
  line-height: 1.5em;
  border: none !important;
  color: var(--theme-color-extra_dark) !important;
  background-color: var(--theme-color-extra_bg_color) !important;
}

.woocommerce form.checkout_coupon, .woocommerce form.login, .woocommerce form.register {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.woocommerce .woocommerce-MyAccount-content h3 {
  margin-top: 0;
}

.woocommerce .woocommerce-address-fields .select_container:before {
  top: 2px;
  right: 2px;
}

.woocommerce .woocommerce-address-fields .select2-container--default .select2-selection--single .select2-selection__arrow {
  display: none;
}

/* Responsive tables
----------------------------------------------------------------- */
.woocommerce table.shop_table_responsive tr td td:before,
.woocommerce-page table.shop_table_responsive tr td td:before {
  color: var(--theme-color-text_dark);
  font-weight: 700;
}

.woocommerce table.shop_table_responsive thead, .woocommerce-page table.shop_table_responsive thead {
  display: table-row-group;
}

.woocommerce table.shop_table_responsive tr, .woocommerce-page table.shop_table_responsive tr {
  display: table-row;
}

.woocommerce table.shop_table_responsive tr td, .woocommerce-page table.shop_table_responsive tr td {
  display: table-cell;
  text-align: left !important;
  vertical-align: top;
}

.woocommerce table.shop_table_responsive tr td.product-price, .woocommerce-page table.shop_table_responsive tr td.product-price,
.woocommerce table.shop_table_responsive tr td.product-quantity, .woocommerce-page table.shop_table_responsive tr td.product-quantity,
.woocommerce table.shop_table_responsive tr td.product-subtotal, .woocommerce-page table.shop_table_responsive tr td.product-subtotal {
  text-align: left !important;
}

.woocommerce table.shop_table_responsive tr td:before, .woocommerce-page table.shop_table_responsive tr td:before {
  display: none;
}

/* wishlist */
ul.products li.product .tinvwl_add_to_wishlist_button {
  margin-top: 1em;
}

.tinvwl_add_to_wishlist_button.tinvwl-add-hide {
  visibility: visible !important;
}

/* wishlist list */
.tinv-wishlist .tinvwl-table-manage-list td.product-stock p {
  text-align: left;
}
.tinv-wishlist .tinvwl-table-manage-list td.product-stock p .tinvwl-txt {
  display: block;
}
.tinv-wishlist .tinv-header {
  display: none;
}
.tinv-wishlist th {
  background-color: var(--theme-color-alter_bg_color) !important;
}
.tinv-wishlist td {
  background-color: transparent !important;
}
.tinv-wishlist table th,
.tinv-wishlist table td {
  padding: 30px;
  text-align: left;
  border: none !important;
  color: var(--theme-color-text_dark);
  font-size: 19px;
  line-height: 1.3em;
  font-weight: 700;
}
.tinv-wishlist table th .variation,
.tinv-wishlist table td .variation {
  font-weight: 400;
  font-size: 14px;
  color: var(--theme-color-text);
}
.tinv-wishlist table th a,
.tinv-wishlist table td a {
  color: var(--theme-color-text_dark);
}
.tinv-wishlist table th a:hover,
.tinv-wishlist table td a:hover {
  color: var(--theme-color-text_link);
}
.tinv-wishlist table th del,
.tinv-wishlist table th .amount,
.tinv-wishlist table th .amount *,
.tinv-wishlist table td del,
.tinv-wishlist table td .amount,
.tinv-wishlist table td .amount * {
  color: var(--theme-color-text_dark) !important;
}
.tinv-wishlist tr + tr {
  border-top: 1px solid var(--theme-color-bd_color);
}
.tinv-wishlist .product-thumbnail {
  min-width: 100px;
  width: 120px;
  padding-right: 0;
  padding-left: 0;
}
.tinv-wishlist .product-thumbnail img {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  object-fit: cover;
  aspect-ratio: 1;
}
.tinv-wishlist .product-remove button {
  margin: 0;
  width: 27px;
  height: 27px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  padding: 0;
  border: 0;
  background-color: transparent !important;
  color: var(--theme-color-text_light);
  font-size: 14px;
}
.tinv-wishlist .product-remove button:hover {
  color: var(--theme-color-text_link);
}
.tinv-wishlist .product-remove button .ftinvwl:before {
  display: block;
  content: '\e9e1' !important;
  font-family: "fontello";
  line-height: 1;
  text-align: center;
  border: none;
  text-indent: 0;
  width: 100%;
  height: 100%;
}
.tinv-wishlist .product-stock i {
  display: none;
}
.tinv-wishlist .product-remove {
  padding-left: 10px;
}
.tinv-wishlist .product-action {
  width: auto;
  text-align: right;
}
.tinv-wishlist .product-action .button {
  width: auto;
}
.tinv-wishlist .product-action .button i {
  font-weight: 400;
}
.tinv-wishlist tfoot tr {
  border-top: 1px solid var(--theme-color-bd_color);
}
.tinv-wishlist tfoot tr .tinvwl-input-group {
  border-collapse: collapse;
}
.tinv-wishlist tfoot tr td {
  padding: 70px 0 0 0;
}
.tinv-wishlist tfoot tr button {
  padding-top: 0 !important;
  padding-bottom: 0 !important;
  height: 55px !important;
  line-height: 55px !important;
}
.tinv-wishlist tfoot tr button .tinvwl-mobile {
  margin-left: 5px;
}
.tinv-wishlist tfoot tr .select_container {
  overflow: hidden;
}
.tinv-wishlist tfoot tr .tinvwl-to-left:not(:empty) {
  min-height: 1px;
}
.tinv-wishlist td.product-name dl.variation dd {
  padding-top: 0.4em;
}
.tinv-wishlist td.product-name dl.variation dt {
  padding-top: 0.4em;
  padding-right: 0.4em;
}
.tinv-wishlist .social-buttons {
  margin-top: 60px;
}
.tinv-wishlist .social-buttons > span {
  margin-right: 15px;
}
.tinv-wishlist .tinv-lists-nav {
  margin: 10px -5px;
}
.tinv-wishlist .tinv-lists-nav > * {
  flex: unset;
  margin: 5px !important;
}
.tinv-wishlist .tinv-lists-nav > span {
  font-size: 0.9rem;
  line-height: 1rem;
  font-weight: 500;
  color: var(--theme-color-text_dark);
}
.tinv-wishlist .tinv-lists-nav .button {
  width: 35px;
  height: 35px;
  line-height: 35px;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  float: none;
  padding: 0;
}
.tinv-wishlist .tinv-lists-nav .button i {
  margin: 0;
  text-indent: 2px;
}
.tinv-wishlist .tinv-lists-nav .button.tinv-prev i {
  text-indent: -2px;
}
.tinv-wishlist .tinv-lists-nav .button span {
  display: none;
}

.tinvwl-input-group .form-control {
  height: 55px;
  padding: 0 25px;
  border: 1px solid var(--theme-color-input_bd_color);
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.tinvwl-input-group .select_container + .tinvwl-input-group-btn {
  padding-left: 10px;
}

.tinvwl-input-group .select_container:after {
  width: 3em;
}

/* Cart */
.sc_layouts_cart {
  z-index: 2001;
}

.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget {
  text-align: left;
  position: absolute;
  z-index: 2;
  top: 65px;
  left: -2em;
  width: 330px;
  padding: 45px 30px;
  border: none;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_layouts_column_align_right .sc_layouts_cart:not(.modern) .sc_layouts_cart_widget {
  right: -2em;
  left: auto;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget:after {
  display: none;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .woocommerce-mini-cart__empty-message {
  text-align: center;
  position: relative;
  font-size: 18px;
  line-height: 1.3em;
  padding: 3.8em 0;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .woocommerce-mini-cart__empty-message:before {
  display: block;
  text-align: center;
  width: 100%;
  content: '\e9f4';
  font-family: "fontello";
  font-size: 28px;
  margin-bottom: 25px;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget a.remove {
  display: inline-block !important;
  top: 2px !important;
  font-size: 9px !important;
  right: 3px !important;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .widget_shopping_cart {
  position: relative;
  z-index: 2;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .widget_shopping_cart ul.cart_list {
  padding-bottom: 10px;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .widget_shopping_cart ul.cart_list li {
  padding: 10px 13px 10px 0;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .widget_shopping_cart ul.cart_list li img {
  margin-right: 17px;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .widget_shopping_cart .buttons {
  margin-top: 28px;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .widget_shopping_cart .buttons a {
  margin-right: 8px;
  width: calc(49.9% - 4px);
  font-size: 14px;
  line-height: 18px;
  padding: 11px;
  margin-bottom: 0 !important;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .widget_shopping_cart .buttons a.checkout {
  padding: 9px;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .total {
  padding-top: 20px !important;
  margin-top: 0;
  border-top: 1px solid var(--theme-color-extra_bd_color) !important;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .sc_layouts_cart_widget_close {
  cursor: auto;
  width: 100%;
  height: 100%;
  position: fixed;
  left: 0;
  top: 0;
  z-index: 1;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget .sc_layouts_cart_widget_close .sc_layouts_cart_widget_close_icon {
  display: none;
}

/* cart panel */
.sc_layouts_cart_panel .sc_layouts_panel_close.trx_addons_button_close {
  top: 15px;
  right: 10px;
  width: 30px;
  height: 30px;
  line-height: 30px;
}
.sc_layouts_cart_panel .sc_layouts_panel_close.trx_addons_button_close .trx_addons_button_close_icon {
  font-size: 11px;
}
.sc_layouts_cart_panel .sc_layouts_cart_panel_header {
  padding: 15px;
  background-color: transparent;
  border-bottom: 1px solid var(--theme-color-alter_bd_color);
}
.sc_layouts_cart_panel .sc_layouts_cart_panel_header .sc_layouts_cart_panel_title {
  font-size: 1.3em;
  line-height: 1.3em;
}
.sc_layouts_cart_panel .sc_layouts_cart_panel_widget .widget_shopping_cart .widget_shopping_cart_content {
  margin-right: 0;
  overflow-y: auto;
  overflow-x: hidden;
  /* Scrollbar decoration */
  scrollbar-width: thin;
}
.sc_layouts_cart_panel .sc_layouts_cart_panel_widget .widget_shopping_cart .widget_shopping_cart_content::-webkit-scrollbar {
  width: 6px;
}
.sc_layouts_cart_panel .sc_layouts_cart_panel_widget .widget_shopping_cart .widget_shopping_cart_content::-webkit-scrollbar-track {
  background: var(--theme-color-alter_bd_color);
}
.sc_layouts_cart_panel .sc_layouts_cart_panel_widget .widget_shopping_cart .widget_shopping_cart_content::-webkit-scrollbar-thumb {
  background-color: var(--theme-color-text_dark);
}
.sc_layouts_cart_panel .sc_layouts_cart_panel_widget .widget_shopping_cart .widget_shopping_cart_content .total:after {
  content: "";
  display: block;
  background-color: var(--theme-color-alter_bg_color);
  position: absolute;
  z-index: -1;
  top: 0;
  right: 0;
  bottom: -1000%;
  left: 0;
}
.sc_layouts_cart_panel .sc_layouts_cart_panel_widget .widget_shopping_cart ul.cart_list li {
  padding: 10px 15px 10px 0;
  margin-right: 5px;
}
.sc_layouts_cart_panel .sc_layouts_cart_panel_widget .widget_shopping_cart ul.cart_list li img {
  width: inherit;
}

/* cart modern */
.sc_layouts_cart.modern .sc_layouts_cart_widget {
  text-align: left;
  position: fixed;
  z-index: 2;
  top: 0;
  bottom: 0;
  height: 100%;
  left: auto;
  right: 0;
  width: 490px;
  padding: 118px 50px 75px;
  border: none;
  opacity: 0.7 !important;
  display: block !important;
  -webkit-transform: translateX(495px);
  -ms-transform: translateX(495px);
  transform: translateX(495px);
  -webkit-transition: all 0.4s ease-in-out !important;
  -ms-transition: all 0.4s ease-in-out !important;
  transition: all 0.4s ease-in-out !important;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: var(--theme-color-alter_bg_color) !important;
  color: var(--theme-color-alter_dark) !important;
  -webkit-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -ms-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  box-shadow: 0 0 0 rgba(0, 0, 0, 0);
}
.sc_layouts_cart.modern .sc_layouts_cart_widget ul.cart_list li a,
.sc_layouts_cart.modern .sc_layouts_cart_widget .total,
.sc_layouts_cart.modern .sc_layouts_cart_widget .total *,
.sc_layouts_cart.modern .sc_layouts_cart_widget .quantity,
.sc_layouts_cart.modern .sc_layouts_cart_widget .quantity * {
  color: var(--theme-color-alter_dark) !important;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart_content .buttons a.checkout {
  border: none !important;
  color: var(--theme-color-inverse_hover) !important;
  background-color: var(--theme-color-alter_dark) !important;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart_content .buttons a.checkout:hover {
  color: var(--theme-color-inverse_link) !important;
  background-color: var(--theme-color-alter_link) !important;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .sc_layouts_cart_widget .cart_list {
  max-height: 100%;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget:after {
  display: none;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .sc_layouts_item_text {
  font-size: 28px;
  margin: 0;
  position: absolute;
  left: 50px;
  top: 40px;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .sc_layouts_cart_widget_close {
  width: 2rem;
  height: 2rem;
  line-height: 2rem;
  text-align: center;
  font-size: 16px;
  right: 43px;
  top: 43px;
  color: var(--theme-color-alter_dark);
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .woocommerce-mini-cart__empty-message {
  text-align: center;
  position: relative;
  font-size: 18px;
  line-height: 1.3em;
  padding: 0;
  margin: auto;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .woocommerce-mini-cart__empty-message:before {
  display: block;
  text-align: center;
  width: 100%;
  content: '\e9f4';
  font-family: "fontello";
  font-size: 28px;
  margin-bottom: 25px;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget a.remove {
  display: block !important;
  top: 15px !important;
  font-size: 14px !important;
  margin: 0 !important;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget a.remove:after {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart {
  position: relative;
  z-index: 2;
  padding: 0;
  height: 100%;
  font-size: 1em;
  border-top: 1px solid var(--theme-color-bd_color);
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart .widget_shopping_cart_content {
  height: 100%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart ul.cart_list {
  margin-bottom: auto;
  margin-top: 0;
  padding-top: 38px;
  max-height: 100%;
  overflow-y: auto;
  overflow-x: hidden;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart ul.cart_list li {
  padding: 10px 20px 10px 0;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart ul.cart_list li img {
  margin-right: 22px;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart .buttons {
  margin-top: 33px;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart .buttons a {
  border: none !important;
  margin-right: 20px;
  width: calc(50% - 10px);
  font-size: 15px;
  line-height: 55px;
  height: 55px !important;
  padding: 0 10px;
  margin-bottom: 0 !important;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  -webkit-box-shadow: none !important;
  -ms-box-shadow: none !important;
  box-shadow: none !important;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart .buttons a:not(.checkout) {
  color: var(--theme-color-alter_dark) !important;
  background-color: var(--theme-color-alter_bg_hover) !important;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .widget_shopping_cart .buttons a:not(.checkout):hover {
  color: var(--theme-color-inverse_link) !important;
  background-color: var(--theme-color-alter_link) !important;
}
.sc_layouts_cart.modern .sc_layouts_cart_widget .total {
  padding-top: 33px !important;
  margin-top: 0;
  border-top: 1px solid #0F0F0F !important;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: space-between;
}

.sc_layouts_cart.sc_layouts_cart_opened.modern .sc_layouts_cart_widget {
  -webkit-transform: translateX(0px);
  -ms-transform: translateX(0px);
  transform: translateX(0px);
  opacity: 1 !important;
  -webkit-box-shadow: 0 3px 66px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 3px 66px rgba(0, 0, 0, 0.05);
  box-shadow: 0 3px 66px rgba(0, 0, 0, 0.05);
}

/* Wishlist */
body.woosq-open .tinv-wishlist .tinv-modal.tinv-modal-open {
  z-index: 999999 !important;
}

.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button.button {
  margin-bottom: 0 !important;
  margin-top: 10px !important;
  text-align: center;
  display: inline-block;
  padding: 15px;
}
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button.button .tinvwl_button_close i {
  display: none;
}

.tinv-wishlist .tinv-modal .icon_big_heart_check,
.tinv-wishlist .tinv-modal .icon_big_times,
.tinv-wishlist .tinv-modal img {
  margin-bottom: 15px !important;
}

.tinv-wishlist .tinvwl_added_to_wishlist .tinv-txt {
  margin-bottom: 10px;
}

.tinv-wishlist .tinv-modal .tinvwl-buttons-group {
  margin-top: 10px;
}
.tinv-wishlist .tinv-modal .tinvwl-buttons-group button > i {
  line-height: 0;
}

.tinv-wishlist .tinv-modal .tinv-modal-inner {
  padding: 35px;
  background-color: var(--theme-color-bg_color);
}

.single_product_bottom_bar_product_button .tinv-wraper,
.woocommerce div.product form.cart .tinv-wraper {
  float: left;
  display: inline-block;
  pointer-events: all;
  font-size: 17px !important;
}
.single_product_bottom_bar_product_button .tinv-wraper .tinvwl_add_to_wishlist_button.tinvwl-add-hide,
.woocommerce div.product form.cart .tinv-wraper .tinvwl_add_to_wishlist_button.tinvwl-add-hide {
  visibility: visible !important;
}
.single_product_bottom_bar_product_button .tinv-wraper > *,
.woocommerce div.product form.cart .tinv-wraper > * {
  display: none;
}
.single_product_bottom_bar_product_button .tinv-wraper > .tinvwl_add_to_wishlist_button,
.woocommerce div.product form.cart .tinv-wraper > .tinvwl_add_to_wishlist_button {
  display: block;
  overflow: hidden;
  color: #000000 !important;
  background-color: #ffffff !important;
  letter-spacing: 0 !important;
  cursor: pointer;
  text-align: center;
  border: none !important;
  margin: 0 !important;
  width: 55px;
  height: 55px;
  line-height: 56px !important;
  -webkit-border-radius: 50% !important;
  -ms-border-radius: 50% !important;
  border-radius: 50% !important;
  -webkit-transition: all 0.2s ease !important;
  -ms-transition: all 0.2s ease !important;
  transition: all 0.2s ease !important;
  -webkit-box-shadow: 0 0 30px 0 rgba(0, 0, 0, 0.06);
  -ms-box-shadow: 0 0 30px 0 rgba(0, 0, 0, 0.06);
  box-shadow: 0 0 30px 0 rgba(0, 0, 0, 0.06);
  position: relative;
  visibility: visible !important;
  pointer-events: auto !important;
  top: 0;
  opacity: 1 !important;
}
.single_product_bottom_bar_product_button .tinv-wraper > .tinvwl_add_to_wishlist_button .tinvwl_add_to_wishlist-text,
.woocommerce div.product form.cart .tinv-wraper > .tinvwl_add_to_wishlist_button .tinvwl_add_to_wishlist-text {
  display: none;
}
.single_product_bottom_bar_product_button .tinv-wraper > .tinvwl_add_to_wishlist_button:before,
.woocommerce div.product form.cart .tinv-wraper > .tinvwl_add_to_wishlist_button:before {
  display: block !important;
  content: '\e9cc' !important;
  font-family: "fontello" !important;
  margin: 0 !important;
  font-size: 16px !important;
  line-height: inherit !important;
  vertical-align: middle !important;
  padding: 0 !important;
  height: 100% !important;
  width: 100% !important;
  text-align: center !important;
}
.single_product_bottom_bar_product_button .tinv-wraper > .tinvwl_add_to_wishlist_button.tinvwl-product-in-list:before,
.woocommerce div.product form.cart .tinv-wraper > .tinvwl_add_to_wishlist_button.tinvwl-product-in-list:before {
  content: '\ea05' !important;
}
.single_product_bottom_bar_product_button .tinv-wraper > .tinvwl_add_to_wishlist_button:hover,
.woocommerce div.product form.cart .tinv-wraper > .tinvwl_add_to_wishlist_button:hover {
  color: var(--theme-color-text_link) !important;
}

.woocommerce div.product form.cart .single_add_to_cart_button {
  height: 55px;
  line-height: 1em !important;
  padding: 0 55px !important;
  margin-right: 10px;
  white-space: normal;
}

.pswp__caption .pswp__caption__center {
  text-align: center;
}

/* cart form */
.woocommerce .woocommerce-cart-form table.shop_table th,
.woocommerce .woocommerce-cart-form table.shop_table td {
  padding: 30px 0;
}
.woocommerce .woocommerce-cart-form table.shop_table th:first-child,
.woocommerce .woocommerce-cart-form table.shop_table td:first-child {
  padding-left: 25px;
}
.woocommerce .woocommerce-cart-form table.shop_table .cart-coupon {
  border: none !important;
  padding-left: 0 !important;
}
.woocommerce .woocommerce-cart-form table.shop_table td.product-name {
  width: 40%;
  padding-right: 10px;
}
.woocommerce .woocommerce-cart-form table.shop_table .product-name-inner {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  align-items: center;
}
.woocommerce .woocommerce-cart-form table.shop_table .product-name-inner .product-info {
  flex-grow: 1;
}
.woocommerce .woocommerce-cart-form table.shop_table .product-name-inner > a {
  flex: 0 0 auto;
}
.woocommerce .woocommerce-cart-form table.shop_table .product-name img {
  width: 80px;
  height: 80px;
  object-fit: cover;
  aspect-ratio: 1;
  margin-right: 25px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.woocommerce .woocommerce-cart-form table.shop_table .product-info > b {
  color: var(--theme-color-text_dark);
  font-weight: inherit;
}
.woocommerce .woocommerce-cart-form table.shop_table tbody {
  font-size: 19px;
  line-height: 1.3em;
  font-weight: 700;
  color: var(--theme-color-text_dark);
}
.woocommerce .woocommerce-cart-form table.shop_table tbody td {
  font-size: 19px;
  line-height: 1.3em;
}
.woocommerce .woocommerce-cart-form table.shop_table tbody a {
  color: var(--theme-color-text_dark);
}
.woocommerce .woocommerce-cart-form table.shop_table tbody a:hover {
  color: var(--theme-color-text_link);
}
.woocommerce .woocommerce-cart-form table.shop_table tbody span.amount,
.woocommerce .woocommerce-cart-form table.shop_table tbody span.amount .woocommerce-Price-currencySymbol {
  color: var(--theme-color-text_dark);
}
.woocommerce .woocommerce-cart-form table.shop_table tbody .product-price span.amount {
  font-weight: 700;
}
.woocommerce .woocommerce-cart-form table.shop_table tbody a.remove {
  font-size: 18px !important;
}
.woocommerce .woocommerce-cart-form table.shop_table td.actions {
  text-align: right !important;
  padding-right: 0 !important;
  border: none !important;
}
.woocommerce .woocommerce-cart-form table.shop_table td.actions,
.woocommerce .woocommerce-cart-form table.shop_table td.cart-coupon {
  padding-top: 78px;
  padding-bottom: 0;
}
.woocommerce .woocommerce-cart-form table.shop_table .cart-coupon-inner {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  border: 1px solid var(--theme-color-bd_color);
  align-items: center;
  padding-left: 25px;
  height: 55px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.woocommerce .woocommerce-cart-form table.shop_table .cart-coupon-inner:before {
  content: '\e9bd';
  font-family: "fontello";
  display: inline-block;
  color: var(--theme-color-text_dark);
  font-size: 22px;
  font-weight: 400;
}
.woocommerce .woocommerce-cart-form table.shop_table .cart-coupon-inner input {
  padding: 13px 10px;
  font-size: 14px;
  font-weight: 400;
  line-height: normal;
  border: none;
  flex: 1 auto;
  width: 100%;
  margin-right: 155px;
}
.woocommerce .woocommerce-cart-form table.shop_table .cart-coupon-inner button {
  display: inline-flex;
  width: 155px;
  padding: 0;
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  background: none;
  align-items: center;
  justify-content: center;
  font-size: 15px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-text_dark);
  background-color: var(--theme-color-bg_color);
}
.woocommerce .woocommerce-cart-form table.shop_table .cart-coupon-inner button:focus, .woocommerce .woocommerce-cart-form table.shop_table .cart-coupon-inner button:hover {
  color: var(--theme-color-text_link);
}
.woocommerce .woocommerce-cart-form table.shop_table .cart-coupon-inner button:before {
  content: "";
  display: block;
  height: 22px;
  width: 1px;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 0;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  left: 2px;
  background: var(--theme-color-bd_color);
}
.woocommerce .woocommerce-cart-form table.shop_table .woo-actions-inner .button {
  height: 55px;
  padding: 0 42px;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
}
.woocommerce .woocommerce-cart-form table.shop_table .woo-actions-inner .button.continue_shopping {
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  background-color: var(--theme-color-alter_bg_color);
  color: var(--theme-color-text_dark);
}
.woocommerce .woocommerce-cart-form table.shop_table .woo-actions-inner .button.continue_shopping:hover {
  background-color: var(--theme-color-text_dark);
  color: var(--theme-color-inverse_hover);
}
.woocommerce .woocommerce-cart-form table.shop_table .woo-actions-inner button.button {
  background-color: var(--theme-color-text_dark);
  color: var(--theme-color-inverse_hover);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.woocommerce .woocommerce-cart-form table.shop_table .woo-actions-inner button.button:focus, .woocommerce .woocommerce-cart-form table.shop_table .woo-actions-inner button.button:hover {
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
}
.woocommerce .woocommerce-cart-form table.shop_table .woo-actions-inner .button + .button {
  margin-left: 13px;
}

.woocommerce #content table.cart img, .woocommerce table.cart img,
.woocommerce-page #content table.cart img, .woocommerce-page table.cart img {
  height: auto;
}

.woocommerce #content table.cart td.actions,
.woocommerce table.cart td.actions,
.woocommerce-page #content table.cart td.actions,
.woocommerce-page table.cart td.actions {
  text-align: right;
}

/* cart_totals */
.woocommerce .cart_totals .wc-proceed-to-checkout {
  padding: 1.9em 0 0;
}
.woocommerce .cart_totals .wc-proceed-to-checkout .checkout-button {
  margin: 0;
}

.woocommerce .cart_totals table.shop_table tr td,
.woocommerce .cart_totals table.shop_table tr th {
  border: 1px solid var(--theme-color-bd_color) !important;
}
.woocommerce .cart_totals table.shop_table tr td {
  font-size: 17px;
}
.woocommerce .cart_totals table.shop_table tr th {
  background-color: var(--theme-color-alter_bg_color);
  color: var(--theme-color-alter_dark);
  font-size: 17px;
  font-weight: 700;
  line-height: 1.3em;
}

.woocommerce .cart-collaterals .cart-subtotal .amount,
.woocommerce-page .cart-collaterals .cart-subtotal .amount {
  font-weight: 700 !important;
}

.woocommerce .cart-collaterals .order-total span.amount {
  color: var(--theme-color-alter_dark);
}
.woocommerce .cart-collaterals .order-total strong {
  font-weight: 700;
}

#add_payment_method .cart-collaterals .shipping-calculator-button:after,
.woocommerce-cart .cart-collaterals .shipping-calculator-button:after,
.woocommerce-checkout .cart-collaterals .shipping-calculator-button:after {
  display: none;
}

.woocommerce .cart-collaterals .cart_totals table {
  border-collapse: collapse;
}

.woocommerce .cart-collaterals .cart_totals table td,
.woocommerce-page .cart-collaterals .cart_totals table td {
  padding: 24px 28px;
  vertical-align: middle;
}

.woocommerce .cart-collaterals .cart_totals table th,
.woocommerce-page .cart-collaterals .cart_totals table th {
  padding: 24px;
  font-weight: 500;
  text-align: left;
  vertical-align: middle;
}

.woocommerce .cart-collaterals .cart_totals table select,
.woocommerce-page .cart-collaterals .cart_totals table select {
  font-size: 1em;
  color: var(--theme-color-input_text);
  background-color: var(--theme-color-input_bg_color);
}

.woocommerce .cart-collaterals .cart_totals table select:focus,
.woocommerce-page .cart-collaterals .cart_totals table select:focus {
  color: var(--theme-color-input_dark);
  background-color: var(--theme-color-input_bg_hover);
}

.woocommerce .cart-collaterals .shipping_calculator .shipping-calculator-button:after,
.woocommerce-page .cart-collaterals .shipping_calculator .shipping-calculator-button:after {
  color: var(--theme-color-text_dark);
}

/* Status Bar */
.woocommerce-checkout .woocommerce_status_bar {
  margin-top: 100px;
}

.woocommerce-checkout .woocommerce-order .woocommerce_status_bar {
  margin-top: 0;
}

.woocommerce_status_bar {
  font-size: 17px;
  font-weight: 700;
  line-height: 1.3em;
  color: var(--theme-color-text_dark);
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  justify-content: center;
  padding: 0;
  margin-bottom: 100px;
}
.woocommerce_status_bar > div {
  padding: 0 70px;
  position: relative;
}
.woocommerce_status_bar > div.bar_cart:after, .woocommerce_status_bar > div.bar_payment:after {
  content: '\e9df';
  font-family: "fontello";
  display: inline-block;
  color: var(--theme-color-text_dark_02);
  font-weight: 400;
  font-size: 11px;
  position: absolute;
  z-index: 1;
  top: 50%;
  right: 0;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  width: 20px;
  text-align: center;
  right: -10px;
}
.woocommerce_status_bar .num {
  width: 34px;
  height: 34px;
  line-height: 31px;
  font-size: 16px;
  text-align: center;
  display: inline-block;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background-color: var(--theme-color-text_dark);
  color: var(--theme-color-bg_color);
  margin-right: 16px;
}
.woocommerce_status_bar .active .num {
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
}

.woocommerce-checkout .woocommerce-order .woocommerce_status_bar .num {
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
}

.woocommerce form .form-row.woocommerce-invalid label {
  color: #FF5B4A !important;
}
.woocommerce form .form-row.woocommerce-invalid label .required {
  color: #FF5B4A !important;
}

.woocommerce form .form-row.woocommerce-invalid .select2-container,
.woocommerce form .form-row.woocommerce-invalid input.input-text,
.woocommerce form .form-row.woocommerce-invalid .select2-selection,
.woocommerce form .form-row.woocommerce-invalid .select2-selection__rendered,
.woocommerce form .form-row.woocommerce-invalid select {
  border-color: #FF5B4A !important;
}

.woocommerce form .form-row .required {
  color: #FF5B4A !important;
}

/* checkout */
.woocommerce form .form-row-first,
.woocommerce form .form-row-last,
.woocommerce-page form .form-row-first,
.woocommerce-page form .form-row-last {
  width: calc(50% - 15px);
}

h3#ship-to-different-address label > span {
  font-size: 19px;
  line-height: 1em;
  font-weight: 500;
  padding-left: 28px;
}

form.woocommerce-checkout {
  overflow: hidden;
}
form.woocommerce-checkout > h3#order_review_heading {
  overflow: hidden;
  margin: 0;
  padding-bottom: 34px;
  font-size: 35px;
  line-height: 1.2em;
}
form.woocommerce-checkout label {
  font-size: 19px;
  line-height: 1.1em !important;
  font-weight: 500;
  margin-bottom: 15px;
  color: var(--theme-color-text_dark);
}
form.woocommerce-checkout label .required {
  color: var(--theme-color-text_dark) !important;
}
form.woocommerce-checkout h3.ship-to-different-address {
  margin: 0;
  line-height: 1.2em;
}
form.woocommerce-checkout #customer_details {
  width: 60%;
  float: left;
  overflow: hidden;
  padding-right: 140px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
form.woocommerce-checkout #customer_details .col-1,
form.woocommerce-checkout #customer_details .col-2 {
  width: 100%;
  float: none;
}
form.woocommerce-checkout #customer_details .woocommerce-billing-fields h3 {
  font-size: 47px;
  line-height: 1.1em;
}
form.woocommerce-checkout #order_review {
  width: 40%;
  float: right;
}
form.woocommerce-checkout #order_review #order_review_heading {
  padding-top: 0;
  margin-top: 0;
  overflow: hidden;
}

.shop_table_checkout_review {
  padding: 18px 50px;
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
}
.shop_table_checkout_review table {
  width: 100%;
  margin: 0;
}
.shop_table_checkout_review table th,
.shop_table_checkout_review table td {
  font-size: 17px;
  line-height: 1.3em;
  font-weight: 700;
  background: transparent !important;
  padding: 25px 0;
  color: var(--theme-color-alter_dark);
  text-align: right;
}
.shop_table_checkout_review table th strong,
.shop_table_checkout_review table td strong {
  font-weight: 700;
}
.shop_table_checkout_review table th span.amount,
.shop_table_checkout_review table th *,
.shop_table_checkout_review table td span.amount,
.shop_table_checkout_review table td * {
  color: var(--theme-color-alter_dark);
}
.shop_table_checkout_review table td:last-child {
  padding-left: 8px;
}
.shop_table_checkout_review table tr > th:first-child,
.shop_table_checkout_review table tr > td:first-child {
  text-align: left;
}
.shop_table_checkout_review table tr + tr {
  border-top: 1px solid var(--theme-color-alter_bd_color);
}
.shop_table_checkout_review table tr.order-total *,
.shop_table_checkout_review table tr.order-total span.amount {
  color: var(--theme-color-alter_link);
}
.shop_table_checkout_review table tr ul#shipping_method li label {
  font-size: 17px;
  line-height: 1.3em;
  font-weight: 700;
}

.shop_table_order_details {
  padding: 18px 50px;
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
}
.shop_table_order_details table.shop_table {
  width: 100%;
  margin: 0;
}
.shop_table_order_details table.shop_table .wc-item-meta {
  margin-top: 5px;
}
.shop_table_order_details table.shop_table .wc-item-meta li {
  font-size: 0.9em;
  line-height: 1.5em;
}
.shop_table_order_details table.shop_table th,
.shop_table_order_details table.shop_table td {
  font-size: 17px;
  line-height: 1.3em;
  font-weight: 500;
  background: transparent !important;
  padding: 25px 0;
  color: var(--theme-color-alter_dark);
  text-align: right;
}
.shop_table_order_details table.shop_table th strong,
.shop_table_order_details table.shop_table td strong {
  font-weight: 500;
}
.shop_table_order_details table.shop_table th span.amount,
.shop_table_order_details table.shop_table th *,
.shop_table_order_details table.shop_table td span.amount,
.shop_table_order_details table.shop_table td * {
  color: var(--theme-color-alter_dark);
}
.shop_table_order_details table.shop_table tr > th:first-child,
.shop_table_order_details table.shop_table tr > td:first-child {
  text-align: left;
}
.shop_table_order_details table.shop_table tr + tr {
  border-top: 1px solid var(--theme-color-alter_bd_color);
}
.shop_table_order_details table.shop_table tr.order-total *,
.shop_table_order_details table.shop_table tr.order-total span.amount {
  color: var(--theme-color-alter_link);
}
.shop_table_order_details table.shop_table tr:last-child td {
  border-bottom: none !important;
}

.woocommerce .woocommerce-order-details {
  margin-bottom: 60px;
}
.woocommerce .woocommerce-order-details .order-again {
  margin-top: var(--theme-var-grid_gap);
}

.woocommerce-customer-details .woocommerce-column__title,
.woocommerce-order-details .woocommerce-order-details__title {
  margin: 0;
  padding-bottom: 30px;
  font-size: 35px;
  line-height: 1.2em;
}

.woocommerce .woocommerce-customer-details address {
  border-width: 1px !important;
  border-color: var(--theme-color-alter_bd_color);
  padding: 30px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

/* Payment */
#add_payment_method #payment ul.payment_methods, .woocommerce-cart #payment ul.payment_methods, .woocommerce-checkout #payment ul.payment_methods {
  padding: 18px 50px;
  border: none;
}

#add_payment_method #payment ul.payment_methods li, .woocommerce-cart #payment ul.payment_methods li, .woocommerce-checkout #payment ul.payment_methods li {
  line-height: 1;
}

#add_payment_method #payment div.form-row, .woocommerce-cart #payment div.form-row, .woocommerce-checkout #payment div.form-row {
  padding: 5px 50px 50px;
  font-size: 14px;
  font-weight: 400;
  line-height: 1.6em;
  color: var(--theme-color-alter_text);
  text-align: left;
}

.woocommerce #payment #place_order,
.woocommerce-page #payment #place_order {
  float: left;
}

.woocommerce form .form-row label.checkbox,
.woocommerce-page form .form-row label.checkbox {
  display: inline-block;
  padding-left: 1.8em;
}

#payment {
  margin: 48px 0 0 0;
}
#payment .place-order,
#payment .wc_payment_methods {
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
  border: none;
}
#payment .place-order .woocommerce-terms-and-conditions-wrapper p {
  margin: 0 0 27px;
}
#payment .place-order .woocommerce-terms-and-conditions-wrapper p .woocommerce-privacy-policy-link {
  color: var(--theme-color-alter_link);
  border-bottom: 1px solid var(--theme-color-alter_link);
  display: inline-block;
  line-height: 1em;
}
#payment #order_review_heading_payment {
  margin: 0;
  padding-bottom: 35px;
  font-size: 35px;
  line-height: 1.2em;
}
#payment ul.methods div.payment_box {
  padding: 0;
  margin: 4px 0 0 0;
  font-size: 15px;
  line-height: 1.7em;
  color: var(--theme-color-alter_text);
  background-color: transparent;
  font-weight: 400;
}
#payment ul.methods label {
  font-size: 17px;
  line-height: 1.3em !important;
  font-weight: 700;
  margin-bottom: 0;
}
#payment ul.methods li {
  padding: 23px 0;
  font-weight: 400;
}
#payment ul.methods li:last-child {
  border-bottom: 1px dashed var(--theme-color-alter_bd_color);
}
#payment ul.methods li + li {
  border-top: 1px solid var(--theme-color-alter_bd_color);
}

body.woocommerce-checkout #payment h3 + div.place-order {
  padding: 0;
  background-color: transparent;
}
body.woocommerce-checkout #payment h3 + div.place-order .button {
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}

/* Stripe */
.woocommerce-checkout #payment .payment_method_stripe div.form-row {
  padding: 0;
}
.woocommerce-checkout #payment .payment_method_stripe .wc-credit-card-form .wc-stripe-elements-field,
.woocommerce-checkout #payment .payment_method_stripe .wc-credit-card-form .wc-stripe-iban-element-field {
  padding: 0.6em 0;
  margin: 0;
  border: none;
  border-bottom-width: 1px;
  border-bottom-style: solid;
  border-color: var(--theme-color-input_bd_color);
  background-color: var(--theme-color-input_bg_color);
}
.woocommerce-checkout #payment .payment_method_stripe .wc-credit-card-form .wc-stripe-elements-field iframe {
  min-height: auto;
}
.woocommerce-checkout #payment .payment_method_stripe .wc-credit-card-form label {
  font-size: 14px;
  line-height: 20px;
  font-weight: 600;
  padding-left: 0;
}
.woocommerce-checkout #payment .payment_method_stripe .wc-credit-card-form .stripe-source-errors ul li {
  font-size: 15px;
  line-height: 21px;
  padding: 0;
  text-align: center;
}
.woocommerce-checkout #payment .payment_method_stripe .wc-credit-card-form .stripe-source-errors ul li:last-child {
  border-bottom: none;
}
.woocommerce-checkout #payment .payment_method_stripe .wc-credit-card-form + fieldset {
  padding: 0;
}
.woocommerce-checkout #payment .payment_method_stripe #wc-stripe-new-payment-method {
  display: none;
}
.woocommerce-checkout #payment .payment_method_stripe #wc-stripe-new-payment-method + label {
  display: inline-block !important;
  font-size: 14px;
  line-height: 1.5em !important;
  font-weight: inherit;
  color: var(--theme-color-text);
}
.woocommerce-checkout #payment .payment_method_stripe #wc-stripe-new-payment-method + label:before {
  top: 0.5em;
}

/* Attributes */
.woocommerce table.shop_attributes th {
  padding: 10px;
  background: none !important;
}

.woocommerce table.shop_attributes td {
  font-style: normal;
  background: none !important;
}

/* Extended slider */
.sc_extended_products .woocommerce .sc_extended_products_slider ul.products li.product {
  padding-bottom: 0 !important;
}

.sc_extended_products .slider_outer_centered .slider-slide {
  -webkit-transition: all 0.35s ease-in-out;
  -ms-transition: all 0.35s ease-in-out;
  transition: all 0.35s ease-in-out;
}
.sc_extended_products .slider_outer_centered .slider-slide:not([class*="next"]):not([class*="active"]):not([class*="prev"]) {
  opacity: 0.35;
}

/* Extended Default */
.sc_extended_products_default .woocommerce ul.products li.product {
  padding-bottom: 55px;
}
.sc_extended_products_default .woocommerce.columns-5 ul.products li.product,
.sc_extended_products_default .woocommerce.columns-6 ul.products li.product,
.sc_extended_products_default .woocommerce.columns-7 ul.products li.product,
.sc_extended_products_default .woocommerce.columns-8 ul.products li.product {
  padding-bottom: 45px;
}

/* Extended Centered */
.woocommerce ul.products.products_style_centered li.product {
  padding-bottom: 55px;
}
.woocommerce ul.products.products_style_centered li.product .star-rating {
  margin-left: auto;
  margin-right: auto;
}
.woocommerce ul.products.products_style_centered li.product .post_data {
  text-align: center;
}

/* Extended Simple */
.woocommerce ul.products.products_style_simple li.product {
  padding-bottom: 30px;
}
.woocommerce ul.products.products_style_simple li.product > .post_item.post_layout_thumbs {
  height: auto;
}
.woocommerce ul.products.products_style_simple li.product .post_featured {
  margin-bottom: 0 !important;
}
.woocommerce ul.products.products_style_simple li.product .post_data {
  padding: 26px 15px;
}
.woocommerce ul.products.products_style_simple li.product .post_data .price {
  opacity: 1;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap {
  margin: 0 0 -20px;
  height: 27px;
}
.woocommerce ul.products.products_style_simple li.product .post_data .post_header + .add_to_cart_wrap {
  margin: 29px 0 -22px 0;
}
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap .added_to_cart,
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap .button {
  display: inline-block !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  padding: 0 0 7px 0;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background: none !important;
  color: var(--theme-color-text_dark);
  line-height: 20px;
  font-size: 16px;
  font-weight: 700;
  margin: 0;
  opacity: 0;
  position: relative;
}
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap .added_to_cart.added,
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap .button.added {
  display: none !important;
}
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap .added_to_cart:after,
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap .button:after {
  position: absolute;
  bottom: 0;
  top: auto;
  left: 0;
  content: "";
  display: block;
  width: 100%;
  height: 2px;
  background-color: var(--theme-color-text_dark);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  animation: none;
  font-weight: 400;
}
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap .added_to_cart:hover,
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap .button:hover {
  color: var(--theme-color-text_dark);
}
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap .added_to_cart:hover:after,
.woocommerce ul.products.products_style_simple li.product .post_data .add_to_cart_wrap .button:hover:after {
  bottom: 4px;
  background-color: var(--theme-color-text_dark);
}
.woocommerce ul.products.products_style_simple li.product .post_data p.price,
.woocommerce ul.products.products_style_simple li.product .post_data span.price,
.woocommerce ul.products.products_style_simple li.product .post_data span.amount {
  color: var(--theme-color-text_dark);
}
.woocommerce ul.products.products_style_simple li.product .post_item {
  -webkit-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -ms-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce ul.products.products_style_simple li.product .post_item:hover {
  -webkit-box-shadow: 0 3px 26px rgba(0, 0, 0, 0.04);
  -ms-box-shadow: 0 3px 26px rgba(0, 0, 0, 0.04);
  box-shadow: 0 3px 26px rgba(0, 0, 0, 0.04);
}
.woocommerce ul.products.products_style_simple li.product .post_item:hover .woocommerce-loop-product__title a {
  color: var(--theme-color-text_light);
}
.woocommerce ul.products.products_style_simple li.product .post_item:hover .price {
  opacity: 0;
}
.woocommerce ul.products.products_style_simple li.product .post_item:hover .add_to_cart_wrap .button,
.woocommerce ul.products.products_style_simple li.product .post_item:hover .add_to_cart_wrap .added_to_cart {
  margin-top: -22px;
  opacity: 1;
}
.woocommerce ul.products.products_style_simple li.product .post_item:hover .add_to_cart_wrap .button.loading {
  opacity: 0.5 !important;
}
.woocommerce ul.products.products_style_simple li.product .post_item .woocommerce-loop-product__title a:hover {
  color: var(--theme-color-text_dark);
}
.woocommerce ul.products.products_style_simple li.product .star-rating {
  margin-left: auto;
  margin-right: auto;
  display: none;
}
.woocommerce ul.products.products_style_simple li.product .post_data {
  text-align: center;
}

/* Extended Hovered */
.woocommerce ul.products.products_style_hovered li.product {
  padding-bottom: 30px;
}
.woocommerce ul.products.products_style_hovered li.product .post_featured {
  margin: 0;
}
.woocommerce ul.products.products_style_hovered li.product .post_data {
  display: none;
}
.woocommerce ul.products.products_style_hovered li.product .price {
  margin: 9px 0 0 0;
}
.woocommerce ul.products.products_style_hovered li.product .onsale,
.woocommerce ul.products.products_style_hovered li.product .outofstock_label {
  display: none !important;
}
.woocommerce ul.products.products_style_hovered li.product .post_featured.hover_shop .icons {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
}
.woocommerce ul.products.products_style_hovered li.product .post_featured.hover_shop .icons .item-hovered-info {
  display: block;
  width: 100%;
  text-align: center;
  opacity: 0;
  padding: 0 10px;
  margin: 0 0 7px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce ul.products.products_style_hovered li.product .post_featured.hover_shop .icons .tinvwl_add_to_wishlist_button,
.woocommerce ul.products.products_style_hovered li.product .post_featured.hover_shop .icons > a .icon-anim {
  -webkit-box-shadow: 0 3px 36px rgba(0, 0, 0, 0.11);
  -ms-box-shadow: 0 3px 36px rgba(0, 0, 0, 0.11);
  box-shadow: 0 3px 36px rgba(0, 0, 0, 0.11);
}
.woocommerce ul.products.products_style_hovered li.product .post_featured.hover_shop:hover .item-hovered-info {
  opacity: 1;
}
.woocommerce ul.products.products_style_hovered li.product .price del:before {
  background-color: #0C0F26 !important;
}
.woocommerce ul.products.products_style_hovered li.product .woocommerce-loop-product__title a,
.woocommerce ul.products.products_style_hovered li.product .price del,
.woocommerce ul.products.products_style_hovered li.product .price span.amount,
.woocommerce ul.products.products_style_hovered li.product .price del > span.amount *,
.woocommerce ul.products.products_style_hovered li.product .price del > span.amount,
.woocommerce ul.products.products_style_hovered li.product .price * {
  color: #0C0F26 !important;
}
.woocommerce ul.products.products_style_hovered li.product .price del {
  opacity: 0.5 !important;
}
.woocommerce ul.products.products_style_hovered li.product .post_featured.hover_shop .mask {
  display: block;
  background-color: #ffffff !important;
  opacity: 0;
  z-index: 1;
}
.woocommerce ul.products.products_style_hovered li.product .post_featured.hover_shop:hover .mask {
  opacity: 0.9;
}

/* Extended Info */
.woocommerce ul.products.products_style_info li.product {
  padding-bottom: 55px;
}
.woocommerce ul.products.products_style_info li.product .post_featured {
  margin-bottom: 22px;
}
.woocommerce ul.products.products_style_info li.product .woocommerce-loop-category__title,
.woocommerce ul.products.products_style_info li.product .woocommerce-loop-product__title,
.woocommerce ul.products.products_style_info li.product h3 {
  font-size: 19px;
  line-height: 1.3em;
}
.woocommerce ul.products.products_style_info li.product .post_featured.hover_shop .icons {
  flex-direction: column;
  align-items: flex-end;
  justify-content: flex-start;
  top: 22px;
  right: 17px;
}
.woocommerce ul.products.products_style_info li.product .post_featured.hover_shop .icons > a .icon-anim,
.woocommerce ul.products.products_style_info li.product .post_featured.hover_shop .icons .tinv-wraper > .tinvwl_add_to_wishlist_button {
  margin: 3px !important;
}
.woocommerce ul.products.products_style_info li.product .post_featured.hover_shop .icons .tinv-wraper > .tinvwl_add_to_wishlist_button:hover,
.woocommerce ul.products.products_style_info li.product .post_featured.hover_shop .icons > a:hover .icon-anim {
  top: 0 !important;
}

.woocommerce ul.columns-5.products.products_style_info li.product,
.woocommerce ul.columns-6.products.products_style_info li.product,
.woocommerce ul.columns-7.products.products_style_info li.product,
.woocommerce ul.columns-8.products.products_style_info li.product {
  padding-bottom: 45px;
}

/* Extended Info 2 */
.woocommerce ul.products.products_style_info_2 li.product {
  padding-bottom: 55px;
}
.woocommerce ul.products.products_style_info_2 li.product .post_featured {
  margin-bottom: 22px;
}
.woocommerce ul.products.products_style_info_2 li.product .woocommerce-loop-category__title,
.woocommerce ul.products.products_style_info_2 li.product .woocommerce-loop-product__title,
.woocommerce ul.products.products_style_info_2 li.product h3 {
  font-size: 19px;
  line-height: 1.3em;
  font-weight: 700;
}
.woocommerce ul.products.products_style_info_2 li.product .price {
  margin: 14px 0 0 0;
}
.woocommerce ul.products.products_style_info_2 li.product .star-rating {
  margin: 8px 0 0;
}

.woocommerce ul.columns-5.products.products_style_info_2 li.product,
.woocommerce ul.columns-6.products.products_style_info_2 li.product,
.woocommerce ul.columns-7.products.products_style_info_2 li.product,
.woocommerce ul.columns-8.products.products_style_info_2 li.product {
  padding-bottom: 40px;
}

/* pswp */
.pswp__button--arrow--left:before,
.pswp__button--arrow--right:before {
  top: 30px;
  background: none !important;
  height: 30px;
  width: 30px;
  line-height: 30px;
  font-family: "fontello";
  color: var(--theme-color-text_link);
  font-size: 14px;
}

.pswp__button--arrow--right:before {
  content: '\e9df';
  right: 10px;
}

.pswp__button--arrow--left:before {
  left: 10px;
  content: '\ea07';
}

/* Widget Woocommerce Title */
.widget_woocommerce_title .woocommerce-breadcrumb {
  margin-bottom: 0.5em;
}
.widget_woocommerce_title .term-description {
  margin-top: 1em;
}

/* checkout in place order */
.woocommerce-checkout-payment .place-order label.checkbox {
  font-size: 14px !important;
  line-height: 18px !important;
  margin-bottom: 0;
  vertical-align: top;
  padding-top: 1px;
}
.woocommerce-checkout-payment .place-order label.checkbox .woocommerce-terms-and-conditions-checkbox-text {
  font-size: 14px;
  line-height: 22px;
  font-weight: 400;
  color: var(--theme-color-text);
}

/* --- Product Style Plain --- */
@media (min-width: 1280px) {
  .woocommerce ul.products .product_style_plain:not(.product-category) .post_item:hover {
    z-index: 2;
  }
  .woocommerce ul.products .product_style_plain:not(.product-category) .post_item:hover:before,
  .woocommerce ul.products .product_style_plain:not(.product-category) .post_item:hover .wrap-data-hover {
    opacity: 1;
    visibility: visible;
    -webkit-transition: all 0.25s ease;
    -ms-transition: all 0.25s ease;
    transition: all 0.25s ease;
  }
  .woocommerce ul.products .product_style_plain:not(.product-category) .post_item:hover .wrap-data-hover {
    margin-top: 0;
  }
  .woocommerce ul.products .product_style_plain .post_item,
  .woocommerce ul.products .product_style_plain .post_data,
  .woocommerce ul.products .product_style_plain .post_featured {
    position: relative;
    z-index: 1;
  }
  .woocommerce ul.products .product_style_plain .post_item:before,
  .woocommerce ul.products .product_style_plain .wrap-data-hover {
    margin-left: -15px;
    margin-right: -15px;
    background-color: var(--theme-color-bg_color);
    border: 1px solid var(--theme-color-bd_color);
    opacity: 0;
    visibility: hidden;
  }
  .woocommerce ul.products .product_style_plain .post_item:before {
    display: block;
    content: "";
    width: auto;
    height: auto;
    position: absolute;
    z-index: 1;
    top: 0;
    right: -1px;
    bottom: -1px;
    left: -1px;
    margin-top: -15px;
  }
  .woocommerce ul.products .product_style_plain .wrap-data-hover {
    margin-top: -5px;
    padding: 0 15px 15px;
    position: absolute;
    z-index: -1;
    right: -1px;
    left: -1px;
    border-top: none;
  }
}
.woocommerce ul.products.product_style_plain li.product {
  padding-bottom: 50px;
}

.woocommerce ul.products .product_style_plain.product .post_item.post_layout_thumbs {
  height: unset;
}
.woocommerce ul.products .product_style_plain.product .post_data {
  overflow: visible;
}
.woocommerce ul.products .product_style_plain.product .wrap-data-info {
  margin-top: 8px;
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: space-between;
}
.woocommerce ul.products .product_style_plain.product .wrap-data-info .star-rating {
  margin: -1px 0 -3px;
  flex-shrink: 0;
}
.woocommerce ul.products .product_style_plain.product .wrap-data-info .price {
  margin: 0;
}
.woocommerce ul.products .product_style_plain.product .post_featured {
  margin-bottom: 20px;
}
.woocommerce ul.products .product_style_plain.product .post_featured img,
.woocommerce ul.products .product_style_plain.product .post_featured:hover img,
.woocommerce ul.products .product_style_plain.product a img,
.woocommerce ul.products .product_style_plain.product a:hover img {
  -webkit-transform: scale(1, 1);
  -ms-transform: scale(1, 1);
  transform: scale(1, 1);
}
.woocommerce ul.products .product_style_plain.product .outofstock_label,
.woocommerce ul.products .product_style_plain.product .onsale {
  top: 20px;
  left: 20px;
  padding: 0 15px;
  min-width: 50px;
}
.woocommerce ul.products .product_style_plain.product .outofstock_label {
  top: 20px;
  left: 20px;
}
.woocommerce ul.products .product_style_plain.product .outofstock_label + .onsale {
  top: 51px;
  left: 20px;
  right: auto;
}
.woocommerce ul.products .product_style_plain.product .wrap-data-hover .add_to_cart_wrap {
  margin: 25px 0 0 0;
}
.woocommerce ul.products .product_style_plain.product .wrap-data-hover .add_to_cart_wrap [class*="cart"] {
  display: flex !important;
  flex-direction: row;
  align-items: center;
  justify-content: center;
  height: 100%;
  width: 100%;
  pointer-events: auto;
  white-space: normal;
  padding: 10px;
  height: 50px;
  margin: 0;
  font-size: 14px;
  line-height: 16px;
  color: var(--theme-color-bg_color);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  background-color: var(--theme-color-text_dark);
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.woocommerce ul.products .product_style_plain.product .wrap-data-hover .add_to_cart_wrap [class*="cart"]:before {
  margin: 0 5px 0 0;
  font-size: 16px;
  font-weight: 400;
  min-width: 20px;
  text-align: center;
}
.woocommerce ul.products .product_style_plain.product .wrap-data-hover .add_to_cart_wrap [class*="cart"].loading:before {
  font-size: 14px !important;
  content: '\e82e';
  position: relative;
  top: 1px;
  -webkit-animation: spin 2s infinite linear;
  -ms-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
}
.woocommerce ul.products .product_style_plain.product .wrap-data-hover .add_to_cart_wrap [class*="cart"].added_to_cart:before {
  font-family: "fontello";
  content: '\e8ab';
}
.woocommerce ul.products .product_style_plain.product .wrap-data-hover .add_to_cart_wrap [class*="cart"].added {
  display: none !important;
}
.woocommerce ul.products .product_style_plain.product .wrap-data-hover .add_to_cart_wrap [class*="cart"]:hover {
  color: var(--theme-color-inverse_hover);
  background-color: var(--theme-color-text_dark_blend);
}
.product_style_plain .post_featured .top-info {
  pointer-events: none;
  position: absolute;
  z-index: 10;
  top: 20px;
  right: 20px;
  bottom: auto;
  left: auto;
}
.product_style_plain .post_featured .top-info .tinv-wraper > * {
  display: none;
}
.product_style_plain .post_featured .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button {
  display: block;
  overflow: hidden;
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
  letter-spacing: 0 !important;
  margin: 0 !important;
  -webkit-border-radius: 50% !important;
  -ms-border-radius: 50% !important;
  border-radius: 50% !important;
  width: 35px;
  height: 35px;
  line-height: 37px !important;
  -webkit-transition: all 0.2s ease !important;
  -ms-transition: all 0.2s ease !important;
  transition: all 0.2s ease !important;
  visibility: visible !important;
  pointer-events: auto;
}
.product_style_plain .post_featured .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button:before {
  display: block !important;
  content: '\e9cc' !important;
  font-family: "fontello" !important;
  margin: 0 !important;
  font-size: 15px !important;
  line-height: inherit !important;
  padding: 0 !important;
  height: 100% !important;
  width: 100% !important;
  text-align: center !important;
}
.product_style_plain .post_featured .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button.tinvwl-product-in-list:before {
  content: '\ea05' !important;
}
.product_style_plain .post_featured .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button:hover {
  color: var(--theme-color-alter_text);
}
.product_style_plain .post_featured .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button .tinvwl_add_to_wishlist-text {
  display: none;
}

@media (min-width: 1280px) {
  body.body_style_fullwide ul.products.products_style_plain.columns-6 li.product .outofstock_label,
  body.body_style_fullwide ul.products.products_style_plain.columns-6 li.product .onsale, body.body_style_fullwide ul.products.products_style_plain.columns-7 li.product .outofstock_label,
  body.body_style_fullwide ul.products.products_style_plain.columns-7 li.product .onsale, body.body_style_fullwide ul.products.products_style_plain.columns-8 li.product .outofstock_label,
  body.body_style_fullwide ul.products.products_style_plain.columns-8 li.product .onsale, body.body_style_fullscreen ul.products.products_style_plain.columns-6 li.product .outofstock_label,
  body.body_style_fullscreen ul.products.products_style_plain.columns-6 li.product .onsale, body.body_style_fullscreen ul.products.products_style_plain.columns-7 li.product .outofstock_label,
  body.body_style_fullscreen ul.products.products_style_plain.columns-7 li.product .onsale, body.body_style_fullscreen ul.products.products_style_plain.columns-8 li.product .outofstock_label,
  body.body_style_fullscreen ul.products.products_style_plain.columns-8 li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body.body_style_fullwide ul.products.products_style_plain.columns-6 li.product .outofstock_label, body.body_style_fullwide ul.products.products_style_plain.columns-7 li.product .outofstock_label, body.body_style_fullwide ul.products.products_style_plain.columns-8 li.product .outofstock_label, body.body_style_fullscreen ul.products.products_style_plain.columns-6 li.product .outofstock_label, body.body_style_fullscreen ul.products.products_style_plain.columns-7 li.product .outofstock_label, body.body_style_fullscreen ul.products.products_style_plain.columns-8 li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body.body_style_fullwide ul.products.products_style_plain.columns-6 li.product .outofstock_label + .onsale, body.body_style_fullwide ul.products.products_style_plain.columns-7 li.product .outofstock_label + .onsale, body.body_style_fullwide ul.products.products_style_plain.columns-8 li.product .outofstock_label + .onsale, body.body_style_fullscreen ul.products.products_style_plain.columns-6 li.product .outofstock_label + .onsale, body.body_style_fullscreen ul.products.products_style_plain.columns-7 li.product .outofstock_label + .onsale, body.body_style_fullscreen ul.products.products_style_plain.columns-8 li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body.body_style_fullwide ul.products.products_style_plain.columns-6 li.product .top-info, body.body_style_fullwide ul.products.products_style_plain.columns-7 li.product .top-info, body.body_style_fullwide ul.products.products_style_plain.columns-8 li.product .top-info, body.body_style_fullscreen ul.products.products_style_plain.columns-6 li.product .top-info, body.body_style_fullscreen ul.products.products_style_plain.columns-7 li.product .top-info, body.body_style_fullscreen ul.products.products_style_plain.columns-8 li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body.body_style_fullwide ul.products.products_style_plain.columns-6 li.product .wrap-data-info, body.body_style_fullwide ul.products.products_style_plain.columns-7 li.product .wrap-data-info, body.body_style_fullwide ul.products.products_style_plain.columns-8 li.product .wrap-data-info, body.body_style_fullscreen ul.products.products_style_plain.columns-6 li.product .wrap-data-info, body.body_style_fullscreen ul.products.products_style_plain.columns-7 li.product .wrap-data-info, body.body_style_fullscreen ul.products.products_style_plain.columns-8 li.product .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body.body_style_fullwide ul.products.products_style_plain.columns-6 li.product .wrap-data-info .star-rating, body.body_style_fullwide ul.products.products_style_plain.columns-7 li.product .wrap-data-info .star-rating, body.body_style_fullwide ul.products.products_style_plain.columns-8 li.product .wrap-data-info .star-rating, body.body_style_fullscreen ul.products.products_style_plain.columns-6 li.product .wrap-data-info .star-rating, body.body_style_fullscreen ul.products.products_style_plain.columns-7 li.product .wrap-data-info .star-rating, body.body_style_fullscreen ul.products.products_style_plain.columns-8 li.product .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body.body_style_fullwide ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullwide ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullwide ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullscreen ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullscreen ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullscreen ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap {
    margin-top: 17px;
  }
  body.body_style_fullwide ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullwide ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullwide ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullscreen ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullscreen ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullscreen ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"] {
    height: 42px;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label,
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-5 li.product .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label,
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-6 li.product .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label,
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-7 li.product .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label,
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-8 li.product .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label,
  body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-5 li.product .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label,
  body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-6 li.product .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label,
  body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-7 li.product .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label,
  body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-8 li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label + .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label + .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label + .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label + .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label + .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label + .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label + .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-5 li.product .top-info, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-6 li.product .top-info, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-7 li.product .top-info, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-8 li.product .top-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-5 li.product .top-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-6 li.product .top-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-7 li.product .top-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-8 li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-info, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-info, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-info, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-info .star-rating, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-info .star-rating, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-info .star-rating, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-info .star-rating, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-info .star-rating, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-info .star-rating, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-info .star-rating, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap {
    margin-top: 17px;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullwide.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_fullscreen.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"] {
    height: 42px;
  }
  body.body_style_wide ul.products.products_style_plain.columns-5 li.product .outofstock_label,
  body.body_style_wide ul.products.products_style_plain.columns-5 li.product .onsale, body.body_style_wide ul.products.products_style_plain.columns-6 li.product .outofstock_label,
  body.body_style_wide ul.products.products_style_plain.columns-6 li.product .onsale, body.body_style_wide ul.products.products_style_plain.columns-7 li.product .outofstock_label,
  body.body_style_wide ul.products.products_style_plain.columns-7 li.product .onsale, body.body_style_wide ul.products.products_style_plain.columns-8 li.product .outofstock_label,
  body.body_style_wide ul.products.products_style_plain.columns-8 li.product .onsale, body.body_style_boxed ul.products.products_style_plain.columns-5 li.product .outofstock_label,
  body.body_style_boxed ul.products.products_style_plain.columns-5 li.product .onsale, body.body_style_boxed ul.products.products_style_plain.columns-6 li.product .outofstock_label,
  body.body_style_boxed ul.products.products_style_plain.columns-6 li.product .onsale, body.body_style_boxed ul.products.products_style_plain.columns-7 li.product .outofstock_label,
  body.body_style_boxed ul.products.products_style_plain.columns-7 li.product .onsale, body.body_style_boxed ul.products.products_style_plain.columns-8 li.product .outofstock_label,
  body.body_style_boxed ul.products.products_style_plain.columns-8 li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body.body_style_wide ul.products.products_style_plain.columns-5 li.product .outofstock_label, body.body_style_wide ul.products.products_style_plain.columns-6 li.product .outofstock_label, body.body_style_wide ul.products.products_style_plain.columns-7 li.product .outofstock_label, body.body_style_wide ul.products.products_style_plain.columns-8 li.product .outofstock_label, body.body_style_boxed ul.products.products_style_plain.columns-5 li.product .outofstock_label, body.body_style_boxed ul.products.products_style_plain.columns-6 li.product .outofstock_label, body.body_style_boxed ul.products.products_style_plain.columns-7 li.product .outofstock_label, body.body_style_boxed ul.products.products_style_plain.columns-8 li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body.body_style_wide ul.products.products_style_plain.columns-5 li.product .outofstock_label + .onsale, body.body_style_wide ul.products.products_style_plain.columns-6 li.product .outofstock_label + .onsale, body.body_style_wide ul.products.products_style_plain.columns-7 li.product .outofstock_label + .onsale, body.body_style_wide ul.products.products_style_plain.columns-8 li.product .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_plain.columns-5 li.product .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_plain.columns-6 li.product .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_plain.columns-7 li.product .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_plain.columns-8 li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body.body_style_wide ul.products.products_style_plain.columns-5 li.product .top-info, body.body_style_wide ul.products.products_style_plain.columns-6 li.product .top-info, body.body_style_wide ul.products.products_style_plain.columns-7 li.product .top-info, body.body_style_wide ul.products.products_style_plain.columns-8 li.product .top-info, body.body_style_boxed ul.products.products_style_plain.columns-5 li.product .top-info, body.body_style_boxed ul.products.products_style_plain.columns-6 li.product .top-info, body.body_style_boxed ul.products.products_style_plain.columns-7 li.product .top-info, body.body_style_boxed ul.products.products_style_plain.columns-8 li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body.body_style_wide ul.products.products_style_plain.columns-5 li.product .wrap-data-info, body.body_style_wide ul.products.products_style_plain.columns-6 li.product .wrap-data-info, body.body_style_wide ul.products.products_style_plain.columns-7 li.product .wrap-data-info, body.body_style_wide ul.products.products_style_plain.columns-8 li.product .wrap-data-info, body.body_style_boxed ul.products.products_style_plain.columns-5 li.product .wrap-data-info, body.body_style_boxed ul.products.products_style_plain.columns-6 li.product .wrap-data-info, body.body_style_boxed ul.products.products_style_plain.columns-7 li.product .wrap-data-info, body.body_style_boxed ul.products.products_style_plain.columns-8 li.product .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body.body_style_wide ul.products.products_style_plain.columns-5 li.product .wrap-data-info .star-rating, body.body_style_wide ul.products.products_style_plain.columns-6 li.product .wrap-data-info .star-rating, body.body_style_wide ul.products.products_style_plain.columns-7 li.product .wrap-data-info .star-rating, body.body_style_wide ul.products.products_style_plain.columns-8 li.product .wrap-data-info .star-rating, body.body_style_boxed ul.products.products_style_plain.columns-5 li.product .wrap-data-info .star-rating, body.body_style_boxed ul.products.products_style_plain.columns-6 li.product .wrap-data-info .star-rating, body.body_style_boxed ul.products.products_style_plain.columns-7 li.product .wrap-data-info .star-rating, body.body_style_boxed ul.products.products_style_plain.columns-8 li.product .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body.body_style_wide ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_wide ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_wide ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_wide ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_boxed ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_boxed ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_boxed ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_boxed ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap {
    margin-top: 17px;
  }
  body.body_style_wide ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_wide ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_wide ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_wide ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_boxed ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_boxed ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_boxed ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_boxed ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"] {
    height: 42px;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-4 li.product .outofstock_label,
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-4 li.product .onsale, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label,
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-5 li.product .onsale, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label,
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-6 li.product .onsale, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label,
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-7 li.product .onsale, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label,
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-8 li.product .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-4 li.product .outofstock_label,
  body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-4 li.product .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label,
  body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-5 li.product .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label,
  body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-6 li.product .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label,
  body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-7 li.product .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label,
  body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-8 li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-4 li.product .outofstock_label, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-4 li.product .outofstock_label, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-4 li.product .outofstock_label + .onsale, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label + .onsale, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label + .onsale, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label + .onsale, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label + .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-4 li.product .outofstock_label + .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-5 li.product .outofstock_label + .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-6 li.product .outofstock_label + .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-7 li.product .outofstock_label + .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-8 li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-4 li.product .top-info, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-5 li.product .top-info, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-6 li.product .top-info, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-7 li.product .top-info, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-8 li.product .top-info, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-4 li.product .top-info, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-5 li.product .top-info, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-6 li.product .top-info, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-7 li.product .top-info, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-8 li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-4 li.product .wrap-data-info, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-info, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-info, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-info, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-info, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-4 li.product .wrap-data-info, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-info, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-info, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-info, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-4 li.product .wrap-data-info .star-rating, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-info .star-rating, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-info .star-rating, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-info .star-rating, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-info .star-rating, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-4 li.product .wrap-data-info .star-rating, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-info .star-rating, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-info .star-rating, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-info .star-rating, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-4 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-4 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap, body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap {
    margin-top: 17px;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-4 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_wide.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-4 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-5 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-6 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-7 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"], body.body_style_boxed.sidebar_show ul.products.products_style_plain.columns-8 li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"] {
    height: 42px;
  }
}
@media (max-width: 1279px) {
  body[class*="body_style_"] ul.products.products_style_plain:not(.columns-1):not(.columns-2):not(.columns-3) li.product .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_plain:not(.columns-1):not(.columns-2):not(.columns-3) li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"] ul.products.products_style_plain:not(.columns-1):not(.columns-2):not(.columns-3) li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_plain:not(.columns-1):not(.columns-2):not(.columns-3) li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"] ul.products.products_style_plain:not(.columns-1):not(.columns-2):not(.columns-3) li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_plain:not(.columns-1):not(.columns-2):not(.columns-3) li.product .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body[class*="body_style_"] ul.products.products_style_plain:not(.columns-1):not(.columns-2):not(.columns-3) li.product .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body[class*="body_style_"] ul.products.products_style_plain:not(.columns-1):not(.columns-2):not(.columns-3) li.product .wrap-data-hover .add_to_cart_wrap {
    margin-top: 17px;
  }
  body[class*="body_style_"] ul.products.products_style_plain:not(.columns-1):not(.columns-2):not(.columns-3) li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"] {
    height: 42px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_plain:not(.columns-1):not(.columns-2) li.product .outofstock_label,
  body[class*="body_style_"].sidebar_show ul.products.products_style_plain:not(.columns-1):not(.columns-2) li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_plain:not(.columns-1):not(.columns-2) li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_plain:not(.columns-1):not(.columns-2) li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_plain:not(.columns-1):not(.columns-2) li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_plain:not(.columns-1):not(.columns-2) li.product .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_plain:not(.columns-1):not(.columns-2) li.product .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_plain:not(.columns-1):not(.columns-2) li.product .wrap-data-hover .add_to_cart_wrap {
    margin-top: 17px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_plain:not(.columns-1):not(.columns-2) li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"] {
    height: 42px;
  }
}
@media (max-width: 1023px) {
  body[class*="body_style_"] ul.products.products_style_plain li.product .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_plain li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"] ul.products.products_style_plain li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_plain li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"] ul.products.products_style_plain li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_plain li.product .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body[class*="body_style_"] ul.products.products_style_plain li.product .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body[class*="body_style_"] ul.products.products_style_plain li.product .wrap-data-hover .add_to_cart_wrap {
    margin-top: 17px;
  }
  body[class*="body_style_"] ul.products.products_style_plain li.product .wrap-data-hover .add_to_cart_wrap [class*="cart"] {
    height: 42px;
  }
}
/* --- Product Style Creative --- */
.woocommerce ul.products.products_style_creative li.product {
  padding-bottom: 50px;
}

.woocommerce ul.products .product_style_creative.product .post_featured {
  margin-bottom: 18px;
}
.woocommerce ul.products .product_style_creative.product .post_item.post_layout_thumbs {
  height: unset;
}
.woocommerce ul.products .product_style_creative.product .post_data {
  overflow: visible;
}
.woocommerce ul.products .product_style_creative.product .wrap-data-info {
  margin-top: 10px;
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: space-between;
}
.woocommerce ul.products .product_style_creative.product .wrap-data-info .star-rating {
  margin: 0 0 -3px;
  flex-shrink: 0;
}
.woocommerce ul.products .product_style_creative.product .wrap-data-info .price {
  margin: 0;
}
.woocommerce ul.products .product_style_creative.product .post_featured img,
.woocommerce ul.products .product_style_creative.product .post_featured:hover img,
.woocommerce ul.products .product_style_creative.product a img,
.woocommerce ul.products .product_style_creative.product a:hover img {
  -webkit-transform: scale(1, 1);
  -ms-transform: scale(1, 1);
  transform: scale(1, 1);
}
.woocommerce ul.products .product_style_creative.product .outofstock_label,
.woocommerce ul.products .product_style_creative.product .onsale {
  top: 23px;
  left: 23px;
  padding: 0 15px;
  min-width: 50px;
}
.woocommerce ul.products .product_style_creative.product .outofstock_label {
  top: 23px;
  left: 23px;
}
.woocommerce ul.products .product_style_creative.product .outofstock_label + .onsale {
  top: 54px;
  left: 23px;
  right: auto;
}
.product_style_creative .post_featured.hover_shop .mask {
  display: block;
  opacity: 0;
  background-color: rgba(0, 0, 0, 0.1);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.product_style_creative .post_featured.hover_shop .top-info {
  pointer-events: none;
  position: absolute;
  z-index: 10;
  top: 23px;
  right: 23px;
  bottom: auto;
  left: auto;
}
.product_style_creative .post_featured.hover_shop .top-info .tinv-wraper > * {
  display: none;
}
.product_style_creative .post_featured.hover_shop .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button {
  display: block;
  overflow: hidden;
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
  letter-spacing: 0 !important;
  margin: 0 !important;
  -webkit-border-radius: 50% !important;
  -ms-border-radius: 50% !important;
  border-radius: 50% !important;
  width: 35px;
  height: 35px;
  line-height: 37px !important;
  -webkit-transition: all 0.2s ease !important;
  -ms-transition: all 0.2s ease !important;
  transition: all 0.2s ease !important;
  visibility: visible !important;
  pointer-events: auto;
}
.product_style_creative .post_featured.hover_shop .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button:before {
  display: block !important;
  content: '\e9cc' !important;
  font-family: "fontello" !important;
  margin: 0 !important;
  font-size: 15px !important;
  line-height: inherit !important;
  padding: 0 !important;
  height: 100% !important;
  width: 100% !important;
  text-align: center !important;
}
.product_style_creative .post_featured.hover_shop .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button.tinvwl-product-in-list:before {
  content: '\ea05' !important;
}
.product_style_creative .post_featured.hover_shop .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button:hover {
  color: var(--theme-color-alter_text);
}
.product_style_creative .post_featured.hover_shop .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button .tinvwl_add_to_wishlist-text {
  display: none;
}
.product_style_creative .post_featured.hover_shop .bottom-info {
  opacity: 0;
  -webkit-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  transition: all 0.2s ease;
  position: absolute;
  z-index: 10;
  top: auto;
  right: 0;
  bottom: 0;
  left: 0;
  pointer-events: none;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  align-items: center;
  background-color: var(--theme-color-alter_bg_color);
  height: 52px;
}
.product_style_creative .post_featured.hover_shop .bottom-info > div {
  width: 50%;
  padding: 5px;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  height: 100%;
  position: relative;
  bottom: -4px;
  -webkit-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  transition: all 0.2s ease;
}
.product_style_creative .post_featured.hover_shop .bottom-info > div:only-child {
  width: 100%;
}
.product_style_creative .post_featured.hover_shop .bottom-info .add_to_cart_wrap [class*="cart"] {
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  height: 100%;
  width: 100%;
  pointer-events: auto;
  white-space: normal;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  padding: 0;
  margin: 0;
  background: none !important;
  color: var(--theme-color-alter_dark);
  line-height: 16px;
  font-size: 14px;
  font-weight: 700;
}
.product_style_creative .post_featured.hover_shop .bottom-info .add_to_cart_wrap [class*="cart"]:before {
  margin: 0 5px 0 0;
  font-size: 16px;
  font-weight: 400;
  min-width: 20px;
  text-align: center;
}
.product_style_creative .post_featured.hover_shop .bottom-info .add_to_cart_wrap [class*="cart"].loading:before {
  font-size: 14px !important;
  content: '\e82e';
  position: relative;
  top: 1px;
  -webkit-animation: spin 2s infinite linear;
  -ms-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
}
.product_style_creative .post_featured.hover_shop .bottom-info .add_to_cart_wrap [class*="cart"].added_to_cart:before {
  font-family: "fontello";
  content: '\e8ab';
}
.product_style_creative .post_featured.hover_shop .bottom-info .add_to_cart_wrap [class*="cart"].added {
  display: none !important;
}
.product_style_creative .post_featured.hover_shop .bottom-info .add_to_cart_wrap [class*="cart"]:hover {
  color: var(--theme-color-alter_text);
}
.product_style_creative .post_featured.hover_shop .bottom-info .woosq_wrap {
  -webkit-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  transition: all 0.2s ease;
}
.product_style_creative .post_featured.hover_shop .bottom-info .woosq_wrap .woosq-btn {
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  height: 100%;
  width: 100%;
  pointer-events: auto;
  white-space: normal;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  padding: 0;
  margin: 0;
  background: none !important;
  color: var(--theme-color-alter_dark);
  line-height: 16px;
  font-size: 14px;
  font-weight: 700;
}
.product_style_creative .post_featured.hover_shop .bottom-info .woosq_wrap .woosq-btn:before {
  font-family: "fontello" !important;
  content: '\e843';
  margin: 0 8px 0 0;
  font-size: 16px;
  font-weight: 400;
  position: relative;
  top: 0;
}
.product_style_creative .post_featured.hover_shop .bottom-info .woosq_wrap .woosq-btn:hover {
  color: var(--theme-color-alter_text);
}
.product_style_creative .post_item:hover .post_featured.hover_shop .mask {
  opacity: 1;
}
.product_style_creative .post_item:hover .post_featured.hover_shop .bottom-info {
  opacity: 1;
}
.product_style_creative .post_item:hover .post_featured.hover_shop .bottom-info > div {
  bottom: 0;
}

@media (min-width: 1280px) {
  body.body_style_fullwide ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label,
  body.body_style_fullwide ul.products.products_style_creative.columns-6 li.product.product_style_creative .onsale, body.body_style_fullwide ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label,
  body.body_style_fullwide ul.products.products_style_creative.columns-7 li.product.product_style_creative .onsale, body.body_style_fullwide ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label,
  body.body_style_fullwide ul.products.products_style_creative.columns-8 li.product.product_style_creative .onsale, body.body_style_fullscreen ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label,
  body.body_style_fullscreen ul.products.products_style_creative.columns-6 li.product.product_style_creative .onsale, body.body_style_fullscreen ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label,
  body.body_style_fullscreen ul.products.products_style_creative.columns-7 li.product.product_style_creative .onsale, body.body_style_fullscreen ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label,
  body.body_style_fullscreen ul.products.products_style_creative.columns-8 li.product.product_style_creative .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body.body_style_fullwide ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label, body.body_style_fullwide ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label, body.body_style_fullwide ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label, body.body_style_fullscreen ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label, body.body_style_fullscreen ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label, body.body_style_fullscreen ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body.body_style_fullwide ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullwide ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullwide ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullscreen ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullscreen ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullscreen ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body.body_style_fullwide ul.products.products_style_creative.columns-6 li.product.product_style_creative .top-info, body.body_style_fullwide ul.products.products_style_creative.columns-7 li.product.product_style_creative .top-info, body.body_style_fullwide ul.products.products_style_creative.columns-8 li.product.product_style_creative .top-info, body.body_style_fullscreen ul.products.products_style_creative.columns-6 li.product.product_style_creative .top-info, body.body_style_fullscreen ul.products.products_style_creative.columns-7 li.product.product_style_creative .top-info, body.body_style_fullscreen ul.products.products_style_creative.columns-8 li.product.product_style_creative .top-info {
    top: 15px;
    right: 15px;
  }
  body.body_style_fullwide ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info, body.body_style_fullwide ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info, body.body_style_fullwide ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info, body.body_style_fullscreen ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info, body.body_style_fullscreen ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info, body.body_style_fullscreen ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body.body_style_fullwide ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullwide ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullwide ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullscreen ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullscreen ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullscreen ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body.body_style_fullwide ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info, body.body_style_fullwide ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info, body.body_style_fullwide ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info, body.body_style_fullscreen ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info, body.body_style_fullscreen ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info, body.body_style_fullscreen ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info {
    height: 40px;
  }
  body.body_style_fullwide ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullwide ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullwide ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullscreen ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullscreen ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullscreen ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a {
    text-indent: -1000px;
    overflow: hidden;
    font-size: 0 !important;
  }
  body.body_style_fullwide ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullwide ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullwide ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullscreen ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullscreen ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullscreen ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a:before {
    text-indent: 0;
    margin: 0;
    font-size: 18px;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label,
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label,
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label,
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label,
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label,
  body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label,
  body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label,
  body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label,
  body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .top-info, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .top-info, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .top-info, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .top-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .top-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .top-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .top-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .top-info {
    top: 15px;
    right: 15px;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info {
    height: 40px;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a {
    text-indent: -1000px;
    overflow: hidden;
    font-size: 0 !important;
  }
  body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullwide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_fullscreen.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a:before {
    text-indent: 0;
    margin: 0;
    font-size: 18px;
  }
  body.body_style_wide ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label,
  body.body_style_wide ul.products.products_style_creative.columns-5 li.product.product_style_creative .onsale, body.body_style_wide ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label,
  body.body_style_wide ul.products.products_style_creative.columns-6 li.product.product_style_creative .onsale, body.body_style_wide ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label,
  body.body_style_wide ul.products.products_style_creative.columns-7 li.product.product_style_creative .onsale, body.body_style_wide ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label,
  body.body_style_wide ul.products.products_style_creative.columns-8 li.product.product_style_creative .onsale, body.body_style_boxed ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label,
  body.body_style_boxed ul.products.products_style_creative.columns-5 li.product.product_style_creative .onsale, body.body_style_boxed ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label,
  body.body_style_boxed ul.products.products_style_creative.columns-6 li.product.product_style_creative .onsale, body.body_style_boxed ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label,
  body.body_style_boxed ul.products.products_style_creative.columns-7 li.product.product_style_creative .onsale, body.body_style_boxed ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label,
  body.body_style_boxed ul.products.products_style_creative.columns-8 li.product.product_style_creative .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body.body_style_wide ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label, body.body_style_wide ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label, body.body_style_wide ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label, body.body_style_wide ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label, body.body_style_boxed ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label, body.body_style_boxed ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label, body.body_style_boxed ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label, body.body_style_boxed ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body.body_style_wide ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_wide ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_wide ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_wide ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body.body_style_wide ul.products.products_style_creative.columns-5 li.product.product_style_creative .top-info, body.body_style_wide ul.products.products_style_creative.columns-6 li.product.product_style_creative .top-info, body.body_style_wide ul.products.products_style_creative.columns-7 li.product.product_style_creative .top-info, body.body_style_wide ul.products.products_style_creative.columns-8 li.product.product_style_creative .top-info, body.body_style_boxed ul.products.products_style_creative.columns-5 li.product.product_style_creative .top-info, body.body_style_boxed ul.products.products_style_creative.columns-6 li.product.product_style_creative .top-info, body.body_style_boxed ul.products.products_style_creative.columns-7 li.product.product_style_creative .top-info, body.body_style_boxed ul.products.products_style_creative.columns-8 li.product.product_style_creative .top-info {
    top: 15px;
    right: 15px;
  }
  body.body_style_wide ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info, body.body_style_wide ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info, body.body_style_wide ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info, body.body_style_wide ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info, body.body_style_boxed ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info, body.body_style_boxed ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info, body.body_style_boxed ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info, body.body_style_boxed ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body.body_style_wide ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_wide ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_wide ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_wide ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_boxed ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_boxed ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_boxed ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_boxed ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body.body_style_wide ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info, body.body_style_wide ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info, body.body_style_wide ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info, body.body_style_wide ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info, body.body_style_boxed ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info, body.body_style_boxed ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info, body.body_style_boxed ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info, body.body_style_boxed ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info {
    height: 40px;
  }
  body.body_style_wide ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a, body.body_style_wide ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a, body.body_style_wide ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a, body.body_style_wide ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a, body.body_style_boxed ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a, body.body_style_boxed ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a, body.body_style_boxed ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a, body.body_style_boxed ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a {
    text-indent: -1000px;
    overflow: hidden;
    font-size: 0 !important;
  }
  body.body_style_wide ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_wide ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_wide ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_wide ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_boxed ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_boxed ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_boxed ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_boxed ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a:before {
    text-indent: 0;
    margin: 0;
    font-size: 18px;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .outofstock_label,
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .onsale, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label,
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .onsale, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label,
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .onsale, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label,
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .onsale, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label,
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .outofstock_label,
  body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label,
  body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label,
  body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label,
  body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label,
  body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .outofstock_label, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .outofstock_label, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label + .onsale, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .top-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .top-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .top-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .top-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .top-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .top-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .top-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .top-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .top-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .top-info {
    top: 15px;
    right: 15px;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .wrap-data-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .wrap-data-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info .star-rating, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .bottom-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .bottom-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info {
    height: 40px;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .bottom-info > div > a, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .bottom-info > div > a, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a {
    text-indent: -1000px;
    overflow: hidden;
    font-size: 0 !important;
  }
  body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_wide.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a:before, body.body_style_boxed.sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a:before {
    text-indent: 0;
    margin: 0;
    font-size: 18px;
  }
}
@media (max-width: 1679px) {
  body[class*="body_style_"] ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_creative.columns-5 li.product.product_style_creative .onsale, body[class*="body_style_"] ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_creative.columns-6 li.product.product_style_creative .onsale, body[class*="body_style_"] ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_creative.columns-7 li.product.product_style_creative .onsale, body[class*="body_style_"] ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_creative.columns-8 li.product.product_style_creative .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"] ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label, body[class*="body_style_"] ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label, body[class*="body_style_"] ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label, body[class*="body_style_"] ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label + .onsale, body[class*="body_style_"] ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label + .onsale, body[class*="body_style_"] ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label + .onsale, body[class*="body_style_"] ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"] ul.products.products_style_creative.columns-5 li.product.product_style_creative .top-info, body[class*="body_style_"] ul.products.products_style_creative.columns-6 li.product.product_style_creative .top-info, body[class*="body_style_"] ul.products.products_style_creative.columns-7 li.product.product_style_creative .top-info, body[class*="body_style_"] ul.products.products_style_creative.columns-8 li.product.product_style_creative .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info, body[class*="body_style_"] ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info, body[class*="body_style_"] ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info, body[class*="body_style_"] ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body[class*="body_style_"] ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info .star-rating, body[class*="body_style_"] ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info .star-rating, body[class*="body_style_"] ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info .star-rating, body[class*="body_style_"] ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body[class*="body_style_"] ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info, body[class*="body_style_"] ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info, body[class*="body_style_"] ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info, body[class*="body_style_"] ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info {
    height: 40px;
  }
  body[class*="body_style_"] ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a, body[class*="body_style_"] ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a, body[class*="body_style_"] ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a, body[class*="body_style_"] ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a {
    text-indent: -1000px;
    overflow: hidden;
    font-size: 0 !important;
  }
  body[class*="body_style_"] ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a:before, body[class*="body_style_"] ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a:before, body[class*="body_style_"] ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a:before, body[class*="body_style_"] ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a:before {
    text-indent: 0;
    margin: 0;
    font-size: 18px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .onsale, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .onsale, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .onsale, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .onsale, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .outofstock_label, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .outofstock_label + .onsale, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .outofstock_label + .onsale, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .outofstock_label + .onsale, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .outofstock_label + .onsale, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .top-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .top-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .top-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .top-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .wrap-data-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .wrap-data-info .star-rating, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .wrap-data-info .star-rating, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .wrap-data-info .star-rating, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .wrap-data-info .star-rating, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .bottom-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info {
    height: 40px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .bottom-info > div > a, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a {
    text-indent: -1000px;
    overflow: hidden;
    font-size: 0 !important;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-4 li.product.product_style_creative .bottom-info > div > a:before, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-5 li.product.product_style_creative .bottom-info > div > a:before, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-6 li.product.product_style_creative .bottom-info > div > a:before, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-7 li.product.product_style_creative .bottom-info > div > a:before, body[class*="body_style_"].sidebar_show ul.products.products_style_creative.columns-8 li.product.product_style_creative .bottom-info > div > a:before {
    text-indent: 0;
    margin: 0;
    font-size: 18px;
  }
}
@media (max-width: 1439px) {
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2):not(.columns-3) li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2):not(.columns-3) li.product.product_style_creative .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2):not(.columns-3) li.product.product_style_creative .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2):not(.columns-3) li.product.product_style_creative .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2):not(.columns-3) li.product.product_style_creative .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2):not(.columns-3) li.product.product_style_creative .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2):not(.columns-3) li.product.product_style_creative .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2):not(.columns-3) li.product.product_style_creative .bottom-info {
    height: 40px;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2):not(.columns-3) li.product.product_style_creative .bottom-info > div > a {
    text-indent: -1000px;
    overflow: hidden;
    font-size: 0 !important;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2):not(.columns-3) li.product.product_style_creative .bottom-info > div > a:before {
    text-indent: 0;
    margin: 0;
    font-size: 18px;
  }
}
@media (max-width: 1279px) {
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .bottom-info {
    height: 40px;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .bottom-info > div > a {
    text-indent: -1000px;
    overflow: hidden;
    font-size: 0 !important;
  }
  body[class*="body_style_"].sidebar_show ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .bottom-info > div > a:before {
    text-indent: 0;
    margin: 0;
    font-size: 18px;
  }
}
@media (max-width: 1023px) {
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .bottom-info {
    height: 40px;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .bottom-info > div > a {
    text-indent: -1000px;
    overflow: hidden;
    font-size: 0 !important;
  }
  body[class*="body_style_"] ul.products.products_style_creative:not(.columns-1):not(.columns-2) li.product.product_style_creative .bottom-info > div > a:before {
    text-indent: 0;
    margin: 0;
    font-size: 18px;
  }
}
@media (max-width: 767px) {
  body[class*="body_style_"] ul.products.products_style_creative li.product.product_style_creative .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_creative li.product.product_style_creative .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"] ul.products.products_style_creative li.product.product_style_creative .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_creative li.product.product_style_creative .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"] ul.products.products_style_creative li.product.product_style_creative .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_creative li.product.product_style_creative .wrap-data-info {
    flex-direction: column;
    align-items: start;
  }
  body[class*="body_style_"] ul.products.products_style_creative li.product.product_style_creative .wrap-data-info .star-rating {
    margin: 10px 0 0;
  }
  body[class*="body_style_"] ul.products.products_style_creative li.product.product_style_creative .bottom-info {
    height: 40px;
  }
  body[class*="body_style_"] ul.products.products_style_creative li.product.product_style_creative .bottom-info > div > a {
    text-indent: -1000px;
    overflow: hidden;
    font-size: 0 !important;
  }
  body[class*="body_style_"] ul.products.products_style_creative li.product.product_style_creative .bottom-info > div > a:before {
    text-indent: 0;
    margin: 0;
    font-size: 18px;
  }
}
/* --- Product Style Pure --- */
.product_style_pure .woosq-btn {
  display: none;
}
.woocommerce ul.products .product_style_pure.product .post_featured {
  margin-bottom: 18px;
}
.woocommerce ul.products .product_style_pure.product .post_item.post_layout_thumbs {
  height: unset;
  padding-bottom: 10px;
  margin-bottom: -10px;
  overflow: hidden;
}
.woocommerce ul.products .product_style_pure.product .post_data {
  overflow: visible;
}
.woocommerce ul.products .product_style_pure.product .price {
  opacity: 1;
  position: relative;
  top: 0;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce ul.products .product_style_pure.product .price .price {
  margin: 10px 0 0;
}
.woocommerce ul.products .product_style_pure.product .post_featured img,
.woocommerce ul.products .product_style_pure.product .post_featured:hover img,
.woocommerce ul.products .product_style_pure.product a img,
.woocommerce ul.products .product_style_pure.product a:hover img {
  -webkit-transform: scale(1, 1);
  -ms-transform: scale(1, 1);
  transform: scale(1, 1);
}
.woocommerce ul.products .product_style_pure.product .outofstock_label,
.woocommerce ul.products .product_style_pure.product .onsale {
  top: 23px;
  left: 23px;
  padding: 0 15px;
  min-width: 50px;
}
.woocommerce ul.products .product_style_pure.product .outofstock_label {
  top: 23px;
  left: 23px;
}
.woocommerce ul.products .product_style_pure.product .outofstock_label + .onsale {
  top: 54px;
  left: 23px;
  right: auto;
}
.woocommerce ul.products .product_style_pure.product .post_data_inner {
  position: relative;
  z-index: 1;
}
.woocommerce ul.products .product_style_pure.product .wrap-data-hover {
  position: absolute;
  bottom: -10px;
  z-index: 1;
  width: 100%;
  opacity: 0;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.woocommerce ul.products .product_style_pure.product .wrap-data-hover .add_to_cart_wrap {
  margin: 0;
  display: block;
  line-height: 0;
}
.woocommerce ul.products .product_style_pure.product .wrap-data-hover .add_to_cart_wrap [class*="cart"] {
  display: inline-block !important;
  width: auto;
  white-space: normal;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  padding: 0;
  margin: 0;
  background: none !important;
  color: var(--theme-color-text);
  line-height: 17px;
  font-size: 15px;
  font-weight: 700;
}
.woocommerce ul.products .product_style_pure.product .wrap-data-hover .add_to_cart_wrap [class*="cart"]:before {
  margin: 0 5px 0 0;
  font-size: 16px;
  font-weight: 400;
  min-width: 20px;
  text-align: center;
}
.woocommerce ul.products .product_style_pure.product .wrap-data-hover .add_to_cart_wrap [class*="cart"].loading:before {
  content: '\e82e';
  -webkit-animation: spin 2s infinite linear;
  -ms-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
}
.woocommerce ul.products .product_style_pure.product .wrap-data-hover .add_to_cart_wrap [class*="cart"].added_to_cart:before {
  font-family: "fontello";
  content: '\e8ab';
}
.woocommerce ul.products .product_style_pure.product .wrap-data-hover .add_to_cart_wrap [class*="cart"].added {
  display: none !important;
}
.woocommerce ul.products .product_style_pure.product .wrap-data-hover .add_to_cart_wrap [class*="cart"]:hover {
  color: var(--theme-color-text_dark);
}
.woocommerce ul.products .product_style_pure.product .post_header + .wrap-data-hover {
  margin-top: 10px;
  position: relative;
}
.woocommerce ul.products .product_style_pure.product .post_item:hover .wrap-data-hover {
  opacity: 1;
  bottom: 0;
}
.woocommerce ul.products .product_style_pure.product .post_item:hover .price {
  opacity: 0;
  top: -10px;
}
.woocommerce ul.products .product_style_pure.product .post_item:hover .post_featured.hover_shop .mask {
  opacity: 1;
}
.woocommerce ul.products .product_style_pure.product .post_item:hover .post_featured.hover_shop .bottom-info {
  opacity: 1;
}
.woocommerce ul.products .product_style_pure.product .post_item:hover .post_featured.hover_shop .bottom-info .woosq_wrap {
  bottom: 0;
}
.product_style_pure .post_featured.hover_shop .mask {
  display: block;
  opacity: 0;
  background-color: rgba(0, 0, 0, 0.1);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.product_style_pure .post_featured.hover_shop .top-info {
  pointer-events: none;
  position: absolute;
  z-index: 10;
  top: 23px;
  right: 23px;
  bottom: auto;
  left: auto;
}
.product_style_pure .post_featured.hover_shop .top-info .tinv-wraper > * {
  display: none;
}
.product_style_pure .post_featured.hover_shop .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button {
  display: block;
  overflow: hidden;
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
  letter-spacing: 0 !important;
  margin: 0 !important;
  -webkit-border-radius: 50% !important;
  -ms-border-radius: 50% !important;
  border-radius: 50% !important;
  width: 35px;
  height: 35px;
  line-height: 37px !important;
  -webkit-transition: all 0.2s ease !important;
  -ms-transition: all 0.2s ease !important;
  transition: all 0.2s ease !important;
  visibility: visible !important;
  pointer-events: auto;
}
.product_style_pure .post_featured.hover_shop .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button:before {
  display: block !important;
  content: '\e9cc' !important;
  font-family: "fontello" !important;
  margin: 0 !important;
  font-size: 15px !important;
  line-height: inherit !important;
  padding: 0 !important;
  height: 100% !important;
  width: 100% !important;
  text-align: center !important;
}
.product_style_pure .post_featured.hover_shop .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button.tinvwl-product-in-list:before {
  content: '\ea05' !important;
}
.product_style_pure .post_featured.hover_shop .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button:hover {
  color: var(--theme-color-alter_text);
}
.product_style_pure .post_featured.hover_shop .top-info .tinv-wraper > .tinvwl_add_to_wishlist_button .tinvwl_add_to_wishlist-text {
  display: none;
}
.product_style_pure .post_featured.hover_shop .bottom-info {
  opacity: 0;
  -webkit-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  transition: all 0.2s ease;
  position: absolute;
  z-index: 10;
  top: auto;
  right: 0;
  bottom: 0;
  left: 0;
  pointer-events: none;
  background-color: var(--theme-color-alter_bg_color);
  height: 52px;
}
.product_style_pure .post_featured.hover_shop .bottom-info .woosq_wrap {
  width: 100%;
  padding: 5px;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  height: 100%;
  position: relative;
  bottom: -4px;
  -webkit-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  transition: all 0.2s ease;
}
.product_style_pure .post_featured.hover_shop .bottom-info .woosq_wrap .woosq-btn {
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  height: 100%;
  width: 100%;
  pointer-events: auto;
  white-space: normal;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  padding: 0;
  margin: 0;
  background: none !important;
  color: var(--theme-color-alter_dark);
  line-height: 16px;
  font-size: 14px;
  font-weight: 700;
}
.product_style_pure .post_featured.hover_shop .bottom-info .woosq_wrap .woosq-btn:before {
  font-family: "fontello" !important;
  content: '\e843';
  margin: 0 8px 0 0;
  font-size: 16px;
  font-weight: 400;
  position: relative;
  top: 0;
}
.product_style_pure .post_featured.hover_shop .bottom-info .woosq_wrap .woosq-btn:hover {
  color: var(--theme-color-alter_text);
}

@media (min-width: 1280px) {
  body.body_style_fullwide ul.products.products_style_pure.columns-6 li.product .outofstock_label,
  body.body_style_fullwide ul.products.products_style_pure.columns-6 li.product .onsale, body.body_style_fullwide ul.products.products_style_pure.columns-7 li.product .outofstock_label,
  body.body_style_fullwide ul.products.products_style_pure.columns-7 li.product .onsale, body.body_style_fullwide ul.products.products_style_pure.columns-8 li.product .outofstock_label,
  body.body_style_fullwide ul.products.products_style_pure.columns-8 li.product .onsale, body.body_style_fullscreen ul.products.products_style_pure.columns-6 li.product .outofstock_label,
  body.body_style_fullscreen ul.products.products_style_pure.columns-6 li.product .onsale, body.body_style_fullscreen ul.products.products_style_pure.columns-7 li.product .outofstock_label,
  body.body_style_fullscreen ul.products.products_style_pure.columns-7 li.product .onsale, body.body_style_fullscreen ul.products.products_style_pure.columns-8 li.product .outofstock_label,
  body.body_style_fullscreen ul.products.products_style_pure.columns-8 li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body.body_style_fullwide ul.products.products_style_pure.columns-6 li.product .outofstock_label, body.body_style_fullwide ul.products.products_style_pure.columns-7 li.product .outofstock_label, body.body_style_fullwide ul.products.products_style_pure.columns-8 li.product .outofstock_label, body.body_style_fullscreen ul.products.products_style_pure.columns-6 li.product .outofstock_label, body.body_style_fullscreen ul.products.products_style_pure.columns-7 li.product .outofstock_label, body.body_style_fullscreen ul.products.products_style_pure.columns-8 li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body.body_style_fullwide ul.products.products_style_pure.columns-6 li.product .outofstock_label + .onsale, body.body_style_fullwide ul.products.products_style_pure.columns-7 li.product .outofstock_label + .onsale, body.body_style_fullwide ul.products.products_style_pure.columns-8 li.product .outofstock_label + .onsale, body.body_style_fullscreen ul.products.products_style_pure.columns-6 li.product .outofstock_label + .onsale, body.body_style_fullscreen ul.products.products_style_pure.columns-7 li.product .outofstock_label + .onsale, body.body_style_fullscreen ul.products.products_style_pure.columns-8 li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body.body_style_fullwide ul.products.products_style_pure.columns-6 li.product .top-info, body.body_style_fullwide ul.products.products_style_pure.columns-7 li.product .top-info, body.body_style_fullwide ul.products.products_style_pure.columns-8 li.product .top-info, body.body_style_fullscreen ul.products.products_style_pure.columns-6 li.product .top-info, body.body_style_fullscreen ul.products.products_style_pure.columns-7 li.product .top-info, body.body_style_fullscreen ul.products.products_style_pure.columns-8 li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body.body_style_fullwide ul.products.products_style_pure.columns-6 li.product .bottom-info, body.body_style_fullwide ul.products.products_style_pure.columns-7 li.product .bottom-info, body.body_style_fullwide ul.products.products_style_pure.columns-8 li.product .bottom-info, body.body_style_fullscreen ul.products.products_style_pure.columns-6 li.product .bottom-info, body.body_style_fullscreen ul.products.products_style_pure.columns-7 li.product .bottom-info, body.body_style_fullscreen ul.products.products_style_pure.columns-8 li.product .bottom-info {
    height: 40px;
  }
  body.body_style_wide ul.products.products_style_pure.columns-5 li.product .outofstock_label,
  body.body_style_wide ul.products.products_style_pure.columns-5 li.product .onsale, body.body_style_wide ul.products.products_style_pure.columns-6 li.product .outofstock_label,
  body.body_style_wide ul.products.products_style_pure.columns-6 li.product .onsale, body.body_style_wide ul.products.products_style_pure.columns-7 li.product .outofstock_label,
  body.body_style_wide ul.products.products_style_pure.columns-7 li.product .onsale, body.body_style_wide ul.products.products_style_pure.columns-8 li.product .outofstock_label,
  body.body_style_wide ul.products.products_style_pure.columns-8 li.product .onsale, body.body_style_boxed ul.products.products_style_pure.columns-5 li.product .outofstock_label,
  body.body_style_boxed ul.products.products_style_pure.columns-5 li.product .onsale, body.body_style_boxed ul.products.products_style_pure.columns-6 li.product .outofstock_label,
  body.body_style_boxed ul.products.products_style_pure.columns-6 li.product .onsale, body.body_style_boxed ul.products.products_style_pure.columns-7 li.product .outofstock_label,
  body.body_style_boxed ul.products.products_style_pure.columns-7 li.product .onsale, body.body_style_boxed ul.products.products_style_pure.columns-8 li.product .outofstock_label,
  body.body_style_boxed ul.products.products_style_pure.columns-8 li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body.body_style_wide ul.products.products_style_pure.columns-5 li.product .outofstock_label, body.body_style_wide ul.products.products_style_pure.columns-6 li.product .outofstock_label, body.body_style_wide ul.products.products_style_pure.columns-7 li.product .outofstock_label, body.body_style_wide ul.products.products_style_pure.columns-8 li.product .outofstock_label, body.body_style_boxed ul.products.products_style_pure.columns-5 li.product .outofstock_label, body.body_style_boxed ul.products.products_style_pure.columns-6 li.product .outofstock_label, body.body_style_boxed ul.products.products_style_pure.columns-7 li.product .outofstock_label, body.body_style_boxed ul.products.products_style_pure.columns-8 li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body.body_style_wide ul.products.products_style_pure.columns-5 li.product .outofstock_label + .onsale, body.body_style_wide ul.products.products_style_pure.columns-6 li.product .outofstock_label + .onsale, body.body_style_wide ul.products.products_style_pure.columns-7 li.product .outofstock_label + .onsale, body.body_style_wide ul.products.products_style_pure.columns-8 li.product .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_pure.columns-5 li.product .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_pure.columns-6 li.product .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_pure.columns-7 li.product .outofstock_label + .onsale, body.body_style_boxed ul.products.products_style_pure.columns-8 li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body.body_style_wide ul.products.products_style_pure.columns-5 li.product .top-info, body.body_style_wide ul.products.products_style_pure.columns-6 li.product .top-info, body.body_style_wide ul.products.products_style_pure.columns-7 li.product .top-info, body.body_style_wide ul.products.products_style_pure.columns-8 li.product .top-info, body.body_style_boxed ul.products.products_style_pure.columns-5 li.product .top-info, body.body_style_boxed ul.products.products_style_pure.columns-6 li.product .top-info, body.body_style_boxed ul.products.products_style_pure.columns-7 li.product .top-info, body.body_style_boxed ul.products.products_style_pure.columns-8 li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body.body_style_wide ul.products.products_style_pure.columns-5 li.product .bottom-info, body.body_style_wide ul.products.products_style_pure.columns-6 li.product .bottom-info, body.body_style_wide ul.products.products_style_pure.columns-7 li.product .bottom-info, body.body_style_wide ul.products.products_style_pure.columns-8 li.product .bottom-info, body.body_style_boxed ul.products.products_style_pure.columns-5 li.product .bottom-info, body.body_style_boxed ul.products.products_style_pure.columns-6 li.product .bottom-info, body.body_style_boxed ul.products.products_style_pure.columns-7 li.product .bottom-info, body.body_style_boxed ul.products.products_style_pure.columns-8 li.product .bottom-info {
    height: 40px;
  }
}
@media (max-width: 1279px) {
  body[class*="body_style_"] ul.products.products_style_pure:not(.columns-1):not(.columns-2) li.product .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_pure:not(.columns-1):not(.columns-2) li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"] ul.products.products_style_pure:not(.columns-1):not(.columns-2) li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_pure:not(.columns-1):not(.columns-2) li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"] ul.products.products_style_pure:not(.columns-1):not(.columns-2) li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_pure:not(.columns-1):not(.columns-2) li.product .bottom-info {
    height: 40px;
  }
}
@media (max-width: 767px) {
  body[class*="body_style_"] ul.products.products_style_pure li.product .outofstock_label,
  body[class*="body_style_"] ul.products.products_style_pure li.product .onsale {
    top: 15px;
    left: 15px;
    padding: 0 10px;
    min-width: 30px;
  }
  body[class*="body_style_"] ul.products.products_style_pure li.product .outofstock_label {
    top: 15px;
    left: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_pure li.product .outofstock_label + .onsale {
    top: 46px;
    left: 15px;
    right: auto;
  }
  body[class*="body_style_"] ul.products.products_style_pure li.product .top-info {
    top: 15px;
    right: 15px;
  }
  body[class*="body_style_"] ul.products.products_style_pure li.product .bottom-info {
    height: 40px;
  }
}
/* Widget "WooCommerce Search"
------------------------------------------------------ */
.trx_addons_woocommerce_tools {
  border-bottom: 1px solid var(--theme-color-bd_color);
}

/* Type: Filter */
.trx_addons_woocommerce_search_type_filter {
  font-size: 17px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title_caption {
  font-size: 19px;
  line-height: 22px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title:hover .sc_form_field_title_caption {
  color: var(--theme-color-text);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title.sc_form_field_title_filled .sc_form_field_title_caption {
  font-weight: inherit;
  color: var(--theme-color-text_link2);
  font-weight: 700;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_arrow:before {
  content: '\e9ea';
  font-family: "fontello";
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_opened .sc_form_field_arrow:before {
  content: '\e9d4';
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_selected_items {
  color: var(--theme-color-text);
  font-size: 15px;
  line-height: 18px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected {
  margin-top: 20px;
  padding-top: 15px;
  font-size: 15px;
  line-height: 18px;
  color: var(--theme-color-text);
  border-top: 1px solid var(--theme-color-bd_color);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_clear,
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_select_all {
  text-decoration: none;
  color: var(--theme-color-text);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_clear:hover,
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_select_all:hover {
  color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_item {
  padding: 0;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_item .sc_form_field_item_total {
  margin: -0.5em -0.5em 0 0.5em;
  margin-top: -0.5em;
  font-size: 0.75em;
  color: inherit;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_item:hover, .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_item:focus {
  background-color: transparent;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_buttons .sc_button {
  padding: 0.6em 2em;
  text-transform: inherit;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items {
  margin: -3px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item {
  width: auto;
  max-width: 100%;
  padding: 0;
  margin: 3px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item .sc_form_field_item_label {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  width: auto;
  height: auto;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  font-size: 16px;
  line-height: 18px;
  padding: 10px 20px;
  color: var(--theme-color-alter_text);
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bg_color);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item .sc_form_field_item_label:hover {
  background-color: var(--theme-color-bg_color);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_label {
  color: var(--theme-color-alter_dark);
  border-color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items {
  margin: -3px;
  color: var(--theme-color-text);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item {
  margin: 3px;
  padding: 10px 5px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  width: auto;
  height: auto;
  min-width: calc(20% - 6px);
  max-width: 100%;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item .sc_form_field_item_image {
  width: 26px;
  height: 26px;
  line-height: 26px;
  text-align: center;
  border: 1px solid rgba(0, 0, 0, 0.09);
  position: relative;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item .sc_form_field_item_image:after {
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  position: absolute;
  z-index: 1;
  top: -4px;
  right: -4px;
  bottom: -4px;
  left: -4px;
  border: 1px solid transparent;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  content: '';
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item:hover, .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item:focus {
  background-color: transparent;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item:hover .sc_form_field_item_image:after, .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item:focus .sc_form_field_item_image:after {
  border-color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked {
  background-color: var(--theme-color-alter_bg_color);
  color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_image {
  border: 1px solid rgba(0, 0, 0, 0.09);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_image:before {
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  border: none;
  content: '\e8ab';
  font-size: 14px;
  font-family: "fontello";
  color: #fff;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item .sc_form_field_item_label {
  font-size: 14px;
  line-height: 16px;
  margin-top: 6px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item .sc_form_field_item_total {
  margin-right: 0;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item {
  margin: 0;
  padding-right: 6px;
  color: var(--theme-color-text_dark);
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item:hover {
  color: var(--theme-color-text);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item + .sc_form_field_item {
  margin-top: 5px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item .sc_form_field_item_total {
  position: absolute;
  z-index: 1;
  top: 50%;
  right: 0;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  margin-top: 1px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item .star-rating {
  top: 2px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select:not([data-multiple="1"]) .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_checked {
  font-weight: inherit;
  text-decoration: none;
  color: var(--theme-color-text_link2);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select[data-multiple="1"] .sc_form_field_wrap .sc_form_field_item {
  padding-left: 30px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select[data-multiple="1"] .sc_form_field_wrap .sc_form_field_item:before {
  left: 0;
  font-family: "fontello";
  display: block;
  font-size: 14px;
  width: 22px;
  height: 22px;
  line-height: 21px;
  -webkit-border-radius: 6px;
  -ms-border-radius: 6px;
  border-radius: 6px;
  border: 1px solid var(--theme-color-bd_color);
  background-color: var(--theme-color-alter_bg_color);
  margin-top: -10px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select[data-multiple="1"] .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_checked:before {
  content: '\e8a6';
  border-color: var(--theme-color-bd_color);
  background-color: var(--theme-color-alter_bg_color);
  color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items {
  margin: -3px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item {
  width: calc(25% - 6px);
  height: auto;
  max-width: 100%;
  margin: 3px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item .sc_form_field_item_image {
  width: 100%;
  height: 100%;
  max-height: 60px;
  -webkit-border-radius: 10px;
  -ms-border-radius: 10px;
  border-radius: 10px;
  border: 1px solid var(--theme-color-bd_color);
  background-size: cover;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item .sc_form_field_item_image:before {
  content: '';
  display: block;
  width: 0;
  height: 0;
  padding-top: 100%;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item:hover .sc_form_field_item_image, .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_image {
  border-color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked {
  color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item .sc_form_field_item_label {
  font-size: 14px;
  line-height: 16px;
  margin-top: 6px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider .ui-slider-handle,
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider .ui-slider-range {
  background-color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider {
  background-color: var(--theme-color-bd_color);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider-horizontal {
  height: 3px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price .trx_addons_range_slider_label {
  font-size: 15px;
  line-height: 1em;
  font-weight: inherit;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price .trx_addons_range_slider_label_cur {
  font-size: 14px;
  background: none;
  color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price .trx_addons_range_slider_label_cur + .trx_addons_range_slider_label_cur {
  margin-left: -4px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider .ui-slider-handle {
  width: 6px;
  height: 9px;
  line-height: 9px;
  border: none;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider-horizontal .ui-slider-handle {
  top: -3px;
  margin-left: -3px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price .sc_form_field_wrap .trx_addons_range_result {
  margin-top: 0;
  padding-top: 10px;
  font-size: 16px;
  line-height: 1em;
  color: var(--theme-color-text);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price .trx_addons_range_slider_label_min {
  left: -3px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price .trx_addons_range_slider_label_max {
  right: -3px;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_slider .sc_form_field_wrap, .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_range .sc_form_field_wrap {
  margin: 0;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_slider .sc_form_field_wrap .trx_addons_range_slider, .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_range .sc_form_field_wrap .trx_addons_range_slider {
  display: block;
  margin: 0.5em 4px 1.5em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_slider .sc_form_field_wrap .trx_addons_range_result, .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_range .sc_form_field_wrap .trx_addons_range_result {
  margin-top: 8px;
  font-size: 16px;
  line-height: 1em;
  color: var(--theme-color-text);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_slider .sc_form_field_wrap .trx_addons_range_result .trx_addons_range_result_value, .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_range .sc_form_field_wrap .trx_addons_range_result .trx_addons_range_result_value {
  color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_text .sc_form_field_wrap .sc_form_field_input {
  padding: 0 0 10px 0;
  border: none;
  background-color: transparent;
  border-bottom: 1px solid var(--theme-color-input_bd_color);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_text .sc_form_field_wrap .sc_form_field_buttons {
  margin-top: 1em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item .star-rating span:before {
  color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all {
  color: var(--theme-color-text);
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all:hover {
  color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all:before {
  display: none;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all:after {
  content: '\e9e1';
  font-family: "fontello";
  margin-left: 10px;
  font-size: 8px;
  position: relative;
  top: 1px;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap.trx_addons_woocommerce_search_form_fields_filled .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all {
  display: flex;
  align-items: center;
  flex-direction: row;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_button_show .trx_addons_woocommerce_search_button_show_total {
  margin: -3px 0 0 0.5em;
  font-size: 11px;
  font-weight: 400;
  width: 22px;
  height: 22px;
  line-height: 20px;
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-inverse_dark);
}
.sidebar .trx_addons_woocommerce_search_type_filter {
  margin-top: -20px;
}
.sidebar .trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all {
  padding: 20px 0;
  margin-bottom: 10px;
  font-size: 16px;
  line-height: 20px;
  border-color: var(--theme-color-bd_color);
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field {
  border: none;
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap {
  padding-bottom: 30px;
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title {
  padding: 20px 0;
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title .sc_form_field_title_caption {
  color: var(--theme-color-text_dark);
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title:hover .sc_form_field_title_caption {
  color: var(--theme-color-text);
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title.sc_form_field_title_filled .sc_form_field_title_caption {
  color: var(--theme-color-text_link2);
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title .sc_form_field_arrow {
  position: absolute;
  z-index: 1;
  top: 21px;
  right: 0;
  margin-left: 0;
}
.sidebar .trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_button_show {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  z-index: 9;
  margin-top: 1em;
}
@media (max-width: 1023px) {
  .sidebar .trx_addons_woocommerce_search_type_filter.trx_addons_woocommerce_search_apply .trx_addons_woocommerce_search_button_show {
    bottom: -30px;
  }
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap {
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bg_color);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_buttons .sc_button {
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_arrow {
  font-size: 13px;
  top: -2px;
  position: relative;
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title:hover .sc_form_field_title_caption {
  text-decoration: none;
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_selected_items, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_selected_items {
  color: var(--theme-color-alter_text);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title_caption, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title_caption {
  color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title:hover .sc_form_field_title_caption, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title:hover .sc_form_field_title_caption {
  color: var(--theme-color-alter_text);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected {
  border-color: var(--theme-color-alter_bd_color);
  color: var(--theme-color-alter_text);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_clear,
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_select_all, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_clear,
[class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_select_all {
  color: var(--theme-color-alter_text);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_clear:hover,
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_select_all:hover, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_clear:hover,
[class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_select_all:hover {
  color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item .sc_form_field_item_label, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item .sc_form_field_item_label {
  color: var(--theme-color-text);
  border-color: var(--theme-color-bd_color);
  background-color: var(--theme-color-bg_color);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item .sc_form_field_item_label:hover, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item .sc_form_field_item_label:hover {
  background-color: var(--theme-color-alter_bg_color);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_label, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_label {
  color: var(--theme-color-text_dark);
  border-color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items {
  color: var(--theme-color-alter_text);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item:hover .sc_form_field_item_image:after, .trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item:focus .sc_form_field_item_image:after, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item:hover .sc_form_field_item_image:after, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item:focus .sc_form_field_item_image:after {
  border-color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked {
  background-color: var(--theme-color-bg_color);
  color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item {
  color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item:hover, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item:hover {
  color: var(--theme-color-alter_text);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select:not([data-multiple="1"]) .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_checked, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select:not([data-multiple="1"]) .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_checked {
  color: var(--theme-color-alter_link2);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select[data-multiple="1"] .sc_form_field_wrap .sc_form_field_item:before, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select[data-multiple="1"] .sc_form_field_wrap .sc_form_field_item:before {
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-bg_color);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select[data-multiple="1"] .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_checked:before, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select[data-multiple="1"] .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_checked:before {
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-bg_color);
  color: var(--theme-color-text_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item .sc_form_field_item_image, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item .sc_form_field_item_image {
  border-color: var(--theme-color-alter_bd_color);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item:hover .sc_form_field_item_image, .trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_image, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item:hover .sc_form_field_item_image, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_image {
  border-color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked {
  color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider .ui-slider-handle,
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider .ui-slider-range, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider .ui-slider-handle,
[class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider .ui-slider-range {
  background-color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price div.ui-slider {
  background-color: var(--theme-color-alter_bd_color);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price .trx_addons_range_slider_label_cur, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price .trx_addons_range_slider_label_cur {
  color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price .sc_form_field_wrap .trx_addons_range_result, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price .sc_form_field_wrap .trx_addons_range_result {
  color: var(--theme-color-alter_text);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_slider .sc_form_field_wrap .trx_addons_range_result, .trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_range .sc_form_field_wrap .trx_addons_range_result, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_slider .sc_form_field_wrap .trx_addons_range_result, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_range .sc_form_field_wrap .trx_addons_range_result {
  color: var(--theme-color-alter_text);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_slider .sc_form_field_wrap .trx_addons_range_result .trx_addons_range_result_value, .trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_range .sc_form_field_wrap .trx_addons_range_result .trx_addons_range_result_value, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_slider .sc_form_field_wrap .trx_addons_range_result .trx_addons_range_result_value, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_price.sc_form_field_range .sc_form_field_wrap .trx_addons_range_result .trx_addons_range_result_value {
  color: var(--theme-color-alter_dark);
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all, [class*="scheme_"].sidebar .trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all {
  border-color: var(--theme-color-alter_bd_color);
}

/* Type: Form */
.trx_addons_woocommerce_search_type_form .sc_form_field input[type="text"] {
  padding-left: 0;
  padding-right: 0;
}

/* Type: Inline */
.trx_addons_woocommerce_search_type_inline {
  font-size: 1.3rem;
  line-height: 1.6em;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field_list {
  color: var(--theme-color-alter_text);
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bg_color);
  top: 3em;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field_list li + li {
  margin-top: 0;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field_list li:hover {
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_hover);
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field input[type="text"] {
  font-size: inherit;
  width: 5em;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_options {
  width: 75%;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_button {
  width: 25%;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_button .trx_addons_woocommerce_search_button {
  padding: 16px 30px;
  white-space: normal;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_button .trx_addons_woocommerce_search_button:before {
  font-family: "fontello";
  content: '\e9a6';
  font-weight: 400;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field input[type="text"],
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field .trx_addons_woocommerce_search_form_field_label {
  line-height: 1;
  border-color: var(--theme-color-text_link);
  color: var(--theme-color-text_link);
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field input[type="text"]:hover, .trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field input[type="text"]:focus,
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field .trx_addons_woocommerce_search_form_field_label:hover,
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field .trx_addons_woocommerce_search_form_field_label:focus {
  border-color: var(--theme-color-text_hover);
  color: var(--theme-color-text_hover);
}
.sidebar .trx_addons_woocommerce_search_type_inline {
  font-size: 1.1rem;
  line-height: 1.7em;
}
.sidebar .trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_options {
  width: 100%;
}
.sidebar .trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_button {
  width: 100%;
  margin-top: 1.3em;
  text-align: center;
}

/* BG search loading for woo filter */
.trx_addons_woocommerce_search_loading .trx_addons_loading {
  background-color: var(--theme-color-bg_color_07);
  min-height: 35px;
}

/* WooCommerce Additional attributes for Variations */
.trx_addons_attrib_button + .trx_addons_attrib_extended {
  margin-bottom: -4px;
}

.trx_addons_attrib_image + .trx_addons_attrib_extended {
  margin-bottom: -4px;
}

.trx_addons_attrib_color + .trx_addons_attrib_extended {
  margin-bottom: -9px;
}

div.product form.cart .variations .value > .select_container {
  margin-top: -0.7em;
}

.trx_addons_attrib_item[data-tooltip-text]:before, .trx_addons_attrib_item[data-tooltip-text]:after {
  display: none;
}
.trx_addons_attrib_item.trx_addons_attrib_disabled span:before, .trx_addons_attrib_item.trx_addons_attrib_disabled span:after {
  background-color: var(--theme-color-alter_hover);
}
.trx_addons_attrib_item.trx_addons_attrib_color {
  margin: 0 9px 9px 0;
  padding: 0;
  background: none;
  border: none;
  position: relative;
  overflow: visible;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.trx_addons_attrib_item.trx_addons_attrib_color:after {
  content: '';
  display: block;
  padding: 0;
  position: absolute;
  top: -3px;
  left: -3px;
  z-index: 1;
  opacity: 1;
  background: none;
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  -webkit-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  transition: all 0.2s ease;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  border: 1px solid transparent;
  width: calc(100% + 6px);
  height: calc(100% + 6px);
  line-height: 1;
  pointer-events: auto;
}
.trx_addons_attrib_item.trx_addons_attrib_color span {
  width: 15px;
  height: 15px;
  line-height: 15px;
  border: 1px solid rgba(0, 0, 0, 0.09);
  -webkit-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  transition: all 0.2s ease;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.trx_addons_attrib_item.trx_addons_attrib_color.trx_addons_attrib_selected span, .trx_addons_attrib_item.trx_addons_attrib_color:hover span {
  border-color: transparent;
}
.trx_addons_attrib_item.trx_addons_attrib_color.trx_addons_attrib_selected:after, .trx_addons_attrib_item.trx_addons_attrib_color:hover:after {
  border-color: var(--theme-color-text_dark);
}
.trx_addons_attrib_item.trx_addons_attrib_button {
  margin: 0 4px 4px 0;
  padding: 4px 7px;
  min-width: 26px;
  text-align: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  font-size: 14px;
  line-height: 17px;
  -webkit-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  transition: all 0.2s ease;
  border: 1px solid var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bg_color);
  color: var(--theme-color-alter_text);
}
.trx_addons_attrib_item.trx_addons_attrib_button span {
  padding: 0;
}
.trx_addons_attrib_item.trx_addons_attrib_button.trx_addons_attrib_selected, .trx_addons_attrib_item.trx_addons_attrib_button:hover {
  color: var(--theme-color-alter_text);
  border-color: var(--theme-color-alter_dark);
}
.trx_addons_attrib_item.trx_addons_attrib_image {
  margin: 0 4px 4px 0;
  padding: 0;
  width: 57px;
  height: 57px;
  line-height: 1;
  -webkit-border-radius: 5px;
  -ms-border-radius: 5px;
  border-radius: 5px;
  -webkit-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  transition: all 0.2s ease;
  position: relative;
  z-index: 1;
  overflow: hidden;
  border: 1px solid var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bg_color);
  cursor: pointer;
}
.trx_addons_attrib_item.trx_addons_attrib_image.trx_addons_attrib_selected, .trx_addons_attrib_item.trx_addons_attrib_image:hover {
  border-color: var(--theme-color-alter_dark);
}
.trx_addons_attrib_item.trx_addons_attrib_image img {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  border: none;
  -webkit-transform: scale(1, 1);
  -ms-transform: scale(1, 1);
  transform: scale(1, 1);
}

/*# sourceMappingURL=woocommerce.css.map */
